@@ -75,14 +75,14 @@ struct map_t
 
 static void convertPt2M(map_t& map, double& u, double& v)
 {
-    u = map.xref1 + u * map.xscale * map.level;
-    v = map.yref1 + v * map.yscale * map.level;
+    u = map.xref1 + u * map.xscale/* * map.level*/;
+    v = map.yref1 + v * map.yscale/* * map.level*/;
 }
 
 static void convertM2Pt(map_t& map, double& u, double& v)
 {
-    u = (u - map.xref1) / (map.xscale * map.level);
-    v = (v - map.yref1) / (map.yscale * map.level);
+    u = (u - map.xref1) / (map.xscale/* * map.level*/);
+    v = (v - map.yref1) / (map.yscale/* * map.level*/);
 }
 
 
@@ -215,11 +215,6 @@ static void printProgress(int current, int total)
 
 static int exportTMS(int level, double lon1, double lat1, double lon2, double lat2, const QString infile, const QString& outfile, CDiskCache& diskCache);
 static int exportWMS(int level, double lon1, double lat1, double lon2, double lat2, const QString infile, const QString& outfile, CDiskCache& diskCache);
-//bin/cache2gtiff -a 1 12.021501 49.064661 12.160464 48.975336 -c /tmp/qlandkarteqt-oeichler/cache -i /home/oeichler/dateien/Maps/bayern_dop_wms.xml -o test.tiff
-//bin/cache2gtiff -a 1 12.051988 49.050000 12.151614 48.998211 -c /tmp/qlandkarteqt-oliver/cache -i /home/oliver/data/Maps/bayern_dop_wms.xml -o test.tif
-
-//bin/cache2gtiff -a 1 12.080746 49.044661 12.124606 49.015901 -c /tmp/qlandkarteqt-oliver/cache -i "http://mt.google.com/vt/lyrs=s&x=%2&y=%3&z=%1" -o test.tif
-
 
 int main(int argc, char ** argv)
 {
@@ -336,10 +331,15 @@ static int exportTMS(int level, double lon1, double lat1, double lon2, double la
     double x1   = lon1;
     double y1   = lat1;
     convertRad2Pt(map, x1, y1);
+    x1 = x1/map.level;
+    y1 = y1/map.level;
 
     double x2   = lon2;
     double y2   = lat2;
     convertRad2Pt(map, x2, y2);
+    x2 = x2/map.level;
+    y2 = y2/map.level;
+
 
     int w       = int(x2 - x1);
     int h       = int(y2 - y1);
@@ -349,9 +349,11 @@ static int exportTMS(int level, double lon1, double lat1, double lon2, double la
     x1  = tile2lon(idxx, z) * DEG_TO_RAD;
     y1  = tile2lat(idxy, z) * DEG_TO_RAD;
     convertRad2Pt(map, x1, y1);
+    x1 = x1/map.level;
+    y1 = y1/map.level;
 
 
-    int total       = ceil((x2 - x1)/(map.blockSizeX*map.level)) * ceil((y2 - y1)/(map.blockSizeY*map.level));
+    int total       = ceil((x2 - x1)/(map.blockSizeX)) * ceil((y2 - y1)/(map.blockSizeY));
     int prog        = 1;
     int badTiles    = 0;
 
@@ -415,6 +417,9 @@ static int exportTMS(int level, double lon1, double lat1, double lon2, double la
     double xx1 = lon1;
     double yy1 = lat1;
     convertRad2Pt(map, xx1, yy1);
+    xx1 = xx1/map.level;
+    yy1 = yy1/map.level;
+
 
     double tx1; // tile pixel left
     double ty1; // tile pixel top
@@ -611,16 +616,14 @@ static int exportWMS(int level, double lon1, double lat1, double lon2, double la
     double y2 = lat2;
     convertRad2Pt(map, x2, y2);
 
-    int w = int(x2 - x1);
-    int h = int(y2 - y1);
+    int w = int(x2 - x1)/map.level;
+    int h = int(y2 - y1)/map.level;
+
 
     // quantify to smalles multiple of blocksize
     x1 = floor(x1/(map.blockSizeX * map.level)) * map.blockSizeX * map.level;
     y1 = floor(y1/(map.blockSizeY * map.level)) * map.blockSizeY * map.level;
 
-    int n = 0;
-    int m = 0;
-
 
     int total       = ceil((x2 - x1)/(map.blockSizeX*map.level)) * ceil((y2 - y1)/(map.blockSizeY*map.level));
     int prog        = 1;
@@ -698,6 +701,10 @@ static int exportWMS(int level, double lon1, double lat1, double lon2, double la
     double yy1 = lat1;
     convertRad2Pt(map, xx1, yy1);
 
+
+    int n = 0;
+    int m = 0;
+
     double tx1; // tile pixel left
     double ty1; // tile pixel top
     double tx2; // tile pixel right
@@ -709,14 +716,15 @@ static int exportWMS(int level, double lon1, double lat1, double lon2, double la
         {
             printProgress(prog++, total);
 
-            double p1x = tx1 = x1 + n * map.blockSizeX;
-            double p1y = ty1 = y1 + m * map.blockSizeY;
-            double p2x = tx2 = x1 + (n + 1) * map.blockSizeX;
-            double p2y = ty2 = y1 + (m + 1) * map.blockSizeY;
+            double p1x = tx1 = x1 + n * map.blockSizeX * map.level;
+            double p1y = ty1 = y1 + m * map.blockSizeY * map.level;
+            double p2x = tx2 = x1 + (n + 1) * map.blockSizeX * map.level;
+            double p2y = ty2 = y1 + (m + 1) * map.blockSizeY * map.level;
 
             convertPt2M(map, p1x, p1y);
             convertPt2M(map, p2x, p2y);
 
+
             QString bbox;
             if(pj_is_latlong(map.pjsrc))
             {
@@ -748,8 +756,9 @@ static int exportWMS(int level, double lon1, double lat1, double lon2, double la
                 continue;
             }
 
-            int xoff    = tx1 - xx1;
-            int yoff    = ty1 - yy1;
+            int xoff    = (tx1 - xx1)/map.level;
+            int yoff    = (ty1 - yy1)/map.level;
+
 
             if(xoff < 0)
             {
@@ -775,6 +784,8 @@ static int exportWMS(int level, double lon1, double lat1, double lon2, double la
             int width   = img.width();
             int height  = img.height();
 
+            img.save(QString("%1_%2.png").arg(tx1).arg(ty1));
+
             if(img.format() != QImage::Format_ARGB32)
             {
                 img = img.convertToFormat(QImage::Format_ARGB32);
