@@ -58,10 +58,12 @@
 #include "CMapUndoCommandMove.h"
 #include "CPlot.h"
 #include "CGridDB.h"
+#include "CMapDEMSlopeSetup.h"
 
 #include <QtGui>
 
 #include <stdio.h>
+#include <tzdata.h>
 
 QPen CCanvas::penBorderBlue(QColor(10,10,150,220),3);
 QPen CCanvas::penBorderBlack(QColor(0,0,0,200),3);
@@ -101,8 +103,15 @@ CCanvas::CCanvas(QWidget * parent)
     timerFadingMessage = new QTimer(this);
     timerFadingMessage->setSingleShot(true);
     connect(timerFadingMessage, SIGNAL(timeout()), this, SLOT(slotFadingMessage()));
+
+    timerClock = new QTimer(this);
+    timerClock->setSingleShot(false);
+    timerClock->start(1000);
+    connect(timerClock, SIGNAL(timeout()), this, SLOT(slotTime()));
+
 }
 
+
 CCanvas::~CCanvas()
 {
 }
@@ -114,9 +123,14 @@ void CCanvas::setupDelayed()
     profile->resize(300,120);
     profile->hide();
 
+    slopeSetup = new CMapDEMSlopeSetup(this);
+    slopeSetup->adjustSize();
+    slopeSetup->hide();
+
     connect(&CTrackDB::self(), SIGNAL(sigPointOfFocus(int)), this, SLOT(slotPointOfFocus(int)));
 }
 
+
 QColor CCanvas::getSelectedColor()
 {
     return mouseColorPicker->getSelectedColor();
@@ -240,6 +254,8 @@ void CCanvas::resizeEvent(QResizeEvent * e)
 
     profile->move(20, s.height() - profile->height() - 20);
 
+    slopeSetup->move(s.width() - slopeSetup->width() - 10, s.height() - slopeSetup->height() - 200);
+
     emit sigResize(e->size());
 }
 
@@ -285,17 +301,20 @@ void CCanvas::mouseReleaseEvent(QMouseEvent * e)
     mouse->mouseReleaseEvent(e);
 }
 
+
 void CCanvas::mouseDoubleClickEvent(QMouseEvent * e)
 {
     posMouse = e->pos();
     mouse->mouseDoubleClickEvent(e);
 }
 
+
 void CCanvas::keyPressEvent(QKeyEvent * e)
 {
     mouse->keyPressEvent(e);
 }
 
+
 void CCanvas::keyReleaseEvent(QKeyEvent * e)
 {
     mouse->keyReleaseEvent(e);
@@ -313,6 +332,7 @@ void CCanvas::leaveEvent(QEvent * )
 {
     QApplication::restoreOverrideCursor();
     setMouseTracking(false);
+    if (mouse) mouse->setSelTrackPt(0);
 }
 
 
@@ -369,6 +389,7 @@ void CCanvas::print(QImage& img)
 
 }
 
+
 void CCanvas::print(QImage& img, const QSize& pagesize)
 {
 
@@ -416,6 +437,7 @@ void CCanvas::draw(QPainter& p)
     drawRefPoints(p);
     drawScale(p);
     drawCompass(p);
+    drawClock(p);
     drawFadingMessage(p);
 
     mouse->draw(p);
@@ -445,6 +467,25 @@ void CCanvas::drawRefPoints(QPainter& p)
 
         ++refpt;
     }
+
+    QRect r1 = dlg->getSelArea();
+
+    double x1 = r1.left();
+    double y1 = r1.top();
+    double x2 = r1.right();
+    double y2 = r1.bottom();
+
+    map.convertM2Pt(x1,y1);
+    map.convertM2Pt(x2,y2);
+
+    r1 = QRect(QPoint(x1,y1), QPoint(x2,y2));
+
+    if(rect().intersects(r1))
+    {
+        p.setBrush(Qt::NoBrush);
+        p.setPen(QPen(QColor("#FF8000"),3));
+        p.drawRect(r1);
+    }
 }
 
 
@@ -557,7 +598,6 @@ void CCanvas::drawCompass(QPainter& p)
     }
     QPolygon arrow;
 
-
     arrow << QPoint(0, -COMPASS_H/2) << QPoint(-COMPASS_W/2, COMPASS_H/2) << QPoint(0, COMPASS_H/3) << QPoint(COMPASS_W/2, COMPASS_H/2);
 
     p.save();
@@ -579,6 +619,27 @@ void CCanvas::drawCompass(QPainter& p)
     p.restore();
 }
 
+void CCanvas::drawClock(QPainter& p)
+{
+    if(!CResources::self().showClock())
+    {
+        return;
+    }
+    TimeStamp tstamp = TimeStamp::now().toUTC();
+    QString strDateTime = tstamp.toZone(timezone).toDateTime().toString() + " (" + timezone + ")";
+#ifdef WIN32
+    strDateTime = " "+strDateTime+" ";
+#endif
+
+    QFontMetrics fm(CResources::self().getMapFont());
+
+    QRect r = fm.boundingRect(strDateTime);
+
+    r.moveBottomRight(QPoint(size().width() - 10, size().height() - 10));
+
+    drawText(strDateTime,p,r);
+
+}
 
 void CCanvas::drawText(const QString& str, QPainter& p, const QPoint& center, const QColor& color)
 {
@@ -703,7 +764,6 @@ void CCanvas::move(move_direction_e dir)
             p2.ry() -= height() / 50;
             break;
 
-
         case eMoveCenter:
         {
             double lon1 = 0, lat1 = 0, lon2 = 0, lat2 = 0;
@@ -750,10 +810,12 @@ void CCanvas::mouseMoveEventCoord(QMouseEvent * e)
     {
         map.convertPt2M(x,y);
         info += QString(" (%1 %2)").arg(x,0,'f',0).arg(y,0,'f',0);
-//        qDebug() << "--" << info;
+        //        qDebug() << "--" << info;
     }
     else
     {
+        timezone = GPS_Timezone(x*RAD_TO_DEG, y*RAD_TO_DEG);
+
 
         float ele = CMapDB::self().getDEM().getElevation(x,y);
         if(ele != WPT_NOFLOAT)
@@ -773,7 +835,7 @@ void CCanvas::mouseMoveEventCoord(QMouseEvent * e)
         }
         else
         {
-            info += tr("[Grid: %1m, %2m] ").arg(x_m,0,'f',0).arg(y_m,0,'f',0);
+            info += tr("[Grid: N %1m, E %2m] ").arg(y_m,0,'f',0).arg(x_m,0,'f',0);
         }
 
         x *= RAD_TO_DEG;
@@ -783,7 +845,7 @@ void CCanvas::mouseMoveEventCoord(QMouseEvent * e)
         GPS_Math_Deg_To_Str(x,y, str);
         info += str + " ";
                                  //add plain degrees
-        //         info += QString(", %1\260 %2\260 ").arg(y,0,'f',7).arg(x,0,'f',7);
+        //info += QString(", %1\260 %2\260 ").arg(y,0,'f',7).arg(x,0,'f',7);
     }
     //     qDebug() << "------" << info;
     theMainWindow->setPositionInfo(info);
@@ -803,7 +865,7 @@ void CCanvas::raiseContextMenu(const QPoint& pos)
         }
         menu.addSeparator();
     }
-//    menu.addAction(QIcon(":/icons/iconClipboard16x16.png"),tr("Copy Position"),this,SLOT(slotCopyPosition()));
+    //    menu.addAction(QIcon(":/icons/iconClipboard16x16.png"),tr("Copy Position"),this,SLOT(slotCopyPosition()));
     mouse->contextMenu(menu);
 
     QPoint p = mapToGlobal(pos);
@@ -821,12 +883,14 @@ void CCanvas::showEvent ( QShowEvent * event )
     map.resize(size());
 }
 
+
 void CCanvas::slotTrackChanged()
 {
     CTrack * trk = CTrackDB::self().highlightedTrack();
     slotHighlightTrack(trk);
 }
 
+
 void CCanvas::slotPointOfFocus(const int idx)
 {
     CTrack * track = CTrackDB::self().highlightedTrack();
@@ -847,12 +911,13 @@ void CCanvas::slotPointOfFocus(const int idx)
     }
 }
 
+
 void CCanvas::slotHighlightTrack(CTrack * track)
 {
     if(track && CResources::self().showTrackProfilePreview())
     {
         QPolygonF lineElev;
-        QPointF   focusElev;
+        QList<QPointF> focusElev;
         float basefactor = IUnit::self().basefactor;
 
         profile->clear();
@@ -873,7 +938,7 @@ void CCanvas::slotHighlightTrack(CTrack * track)
 
             if(trkpt->flags & CTrack::pt_t::eFocus)
             {
-                focusElev  = QPointF(trkpt->distance, trkpt->ele * basefactor);
+                focusElev << QPointF(trkpt->distance, trkpt->ele * basefactor);
             }
 
             trkpt++;
@@ -896,6 +961,15 @@ void CCanvas::slotHighlightTrack(CTrack * track)
     }
 }
 
+
+void CCanvas::slotTime()
+{
+    if(CResources::self().showClock())
+    {
+        update();
+    }
+}
+
 void CCanvas::setFadingMessage(const QString& msg)
 {
     fadingMessage = msg;
@@ -903,6 +977,7 @@ void CCanvas::setFadingMessage(const QString& msg)
     timerFadingMessage->start(1000);
 }
 
+
 void CCanvas::slotFadingMessage()
 {
     fadingMessage.clear();
