@@ -54,7 +54,7 @@ CCreateMapGeoTiff::CCreateMapGeoTiff(QWidget * parent)
     helpStep1->setHelp(tr("Load Raster Map"),
         tr("This dialog allows you to georeference raster map files. As pre-requisite you need a set of reference points and the projection for those points. You will get best results if the projection of the points is also the projection of the map. In most cases this is mercator. It is recommended to shift the reference point to WGS84 datum, right from the beginning."));
     helpStep2->setHelp(tr("Add Reference Points"),
-        trUtf8("The next stage is to add known reference points. Simply add reference points to the map and enter their latitude / longitude (WGS84) or the easting and northing [m] in the table. Next you move the point to the correct location on the map.\n\ncoordinate formats:\n\xe2\x80\xa2 \"N49\xc2\xb0 10.234 E12\xc2\xb0 01.456\"\n\xe2\x80\xa2 \"46.575377   12.193172\"\n\xe2\x80\xa2 \"285000 5162000\""));
+        trUtf8("The next stage is to add known reference points. Simply add reference points to the map and enter their latitude / longitude (WGS84) or the easting and northing [m] in the table. Next you move the point to the correct location on the map.\n\ncoordinate formats:\n\xe2\x80\xa2 \"N49\xc2\xb0 10.234 E12\xc2\xb0 01.456\" (dd mm.mmm)\n\xe2\x80\xa2 \"46.575377   12.193172\"  (dd.dddddd)\n\xe2\x80\xa2 \"285000 5162000\""));
     helpStep3->setHelp(tr("Reference Map"),
         tr("Now QLandkarte GT will reference your file with the help of the GDAL tools. Watch the progress in the output browser."));
 
@@ -105,6 +105,7 @@ CCreateMapGeoTiff::CCreateMapGeoTiff(QWidget * parent)
     tabWidget->setCurrentIndex(0);
 }
 
+
 CCreateMapGeoTiff::~CCreateMapGeoTiff()
 {
     if(closemap) CMapDB::self().closeMap();
@@ -120,6 +121,7 @@ CCreateMapGeoTiff::~CCreateMapGeoTiff()
 
 }
 
+
 bool CCreateMapGeoTiff::eventFilter(QObject * watched, QEvent * event)
 {
     if(watched == theMainWindow->getCanvas())
@@ -151,7 +153,6 @@ bool CCreateMapGeoTiff::eventFilter(QObject * watched, QEvent * event)
                 idx--;
             }
 
-
             if(idx < 0)
             {
                 return QWidget::eventFilter(watched, event);
@@ -173,6 +174,7 @@ bool CCreateMapGeoTiff::eventFilter(QObject * watched, QEvent * event)
     return QWidget::eventFilter(watched, event);
 }
 
+
 void CCreateMapGeoTiff::selRefPointByKey(const quint32 key)
 {
     if(refpts.contains(key))
@@ -254,10 +256,12 @@ void CCreateMapGeoTiff::slotOpenFile()
 
     theMainWindow->getCanvas()->move(CCanvas::eMoveCenter);
 
+
     GDALDataset * dataset = (GDALDataset*)GDALOpen(filename.toLocal8Bit(),GA_ReadOnly);
     if(dataset == 0) return;
 
-    sizeOfInputFile = QSize(dataset->GetRasterXSize(), dataset->GetRasterYSize());
+    sizeMap = QSize(dataset->GetRasterXSize(), dataset->GetRasterYSize());
+    rectSelArea = QRect(QPoint(0,0),sizeMap);
 
     QString proj = dataset->GetGCPProjection();
     if(!proj.isEmpty())
@@ -304,7 +308,7 @@ void CCreateMapGeoTiff::slotReload()
     GDALDataset * dataset = (GDALDataset*)GDALOpen(filename.toLocal8Bit(),GA_ReadOnly);
     if(dataset == 0) return;
 
-    sizeOfInputFile = QSize(dataset->GetRasterXSize(), dataset->GetRasterYSize());
+    rectSelArea     = QRect(0,0,dataset->GetRasterXSize(), dataset->GetRasterYSize());
 
     QString proj = dataset->GetGCPProjection();
     if(!proj.isEmpty())
@@ -686,9 +690,10 @@ void CCreateMapGeoTiff::saveTAB(const QString& filename)
 
 
 void CCreateMapGeoTiff::slotGridTool()
-{
+{    
+    rectSelArea = QRect(QPoint(0,0),sizeMap);
     CCreateMapGridTool * tool = new CCreateMapGridTool(this, parentWidget());
-    theMainWindow->setTempWidget(tool, tr("Grid Tool"));
+    theMainWindow->setTempWidget(tool, tr("Grid Tool"));    
 }
 
 
@@ -729,8 +734,6 @@ void CCreateMapGeoTiff::slotGoOn()
     tabWidget->setTabEnabled(2,true);
     tabWidget->setCurrentIndex(2);
 
-
-
     // get / store target projection
     QString gcpproj = lineGCPProjection->text();
     QString mapproj = lineMapProjection->text();
@@ -740,8 +743,6 @@ void CCreateMapGeoTiff::slotGoOn()
     }
     islonlat = mapproj.contains("longlat");
 
-
-
     SETTINGS;
     cfg.setValue("create/mapproj",mapproj);
 
@@ -768,7 +769,7 @@ void CCreateMapGeoTiff::slotGoOn()
             {
                 return;
             }
-//            qDebug() << "islonlat" << lon << lat;
+            //            qDebug() << "islonlat" << lon << lat;
         }
         else
         {
@@ -777,11 +778,9 @@ void CCreateMapGeoTiff::slotGoOn()
                 return;
             }
 
-//            qDebug() << "!islonlat" << lon << lat;
+            //            qDebug() << "!islonlat" << lon << lat;
         }
 
-
-
         u1 = u2; u2 = lon;
         v1 = v2; v2 = lat;
 
@@ -1033,6 +1032,7 @@ void CCreateMapGeoTiff::slotProjWizard()
     dlg.exec();
 }
 
+
 void CCreateMapGeoTiff::slotGCPProjWizard()
 {
     CDlgProjWizzard dlg(*lineGCPProjection, this);
