@@ -34,14 +34,14 @@ CDeviceGPSD::~CDeviceGPSD()
 
 void CDeviceGPSD::setLiveLog(bool on)
 {
-//    qDebug() << "void CDeviceGPSD::setLiveLog() " << on;
+    //    qDebug() << "void CDeviceGPSD::setLiveLog() " << on;
     if(on)
     {
         log.fix = CLiveLog::eNoFix;
         emit sigLiveLog(log);
 
         // connect to gpsd
-//        qDebug() << "starting thread";
+        //        qDebug() << "starting thread";
         thread->start();
 
         if(!timer->isActive())
@@ -77,7 +77,7 @@ void CDeviceGPSD::slotTimeout()
         timer->stop();
         log.fix = CLiveLog::eOff;
         emit sigLiveLog(log);
-//        qDebug() << "stopped thread detected.";
+        //        qDebug() << "stopped thread detected.";
     }
 
     if( thread->log(log) )
@@ -162,10 +162,10 @@ void CGPSDThread::run()
     if( !gpsdata )
     {
         // TODO: message box (from other thread)
-//        qDebug() << "gps_open failed.";
+        //        qDebug() << "gps_open failed.";
         return;
     }                            // if
-//    qDebug() << "connected to gpsd.";
+    //    qDebug() << "connected to gpsd.";
 
     gps_stream( gpsdata, WATCH_NEWSTYLE, NULL );
 
@@ -189,7 +189,7 @@ void CGPSDThread::run()
         {
             if( FD_ISSET( pipe_fd, &fds ) )
             {
-//                qDebug() << "stop command received";
+                //                qDebug() << "stop command received";
                 char s;
                 read( pipe_fd, &s, 1 );
                 break;
@@ -210,7 +210,7 @@ void CGPSDThread::run()
 #if GPSD_API_MAJOR_VERSION >= 5
     delete gpsdata;
 #endif
-//    qDebug() << "thread done";
+    //    qDebug() << "thread done";
 }
 
 
@@ -221,7 +221,7 @@ bool CGPSDThread::decodeData()
         return true;
     static const gps_mask_t interesting_mask = TIME_SET | LATLON_SET
         | ALTITUDE_SET | SPEED_SET | TRACK_SET | STATUS_SET | MODE_SET
-        | HERR_SET | VERR_SET | ONLINE_SET;
+        | HERR_SET | VERR_SET | SATELLITE_SET | ONLINE_SET;
 
     if( (gpsdata->set & interesting_mask) == 0 )
         return true;
@@ -255,6 +255,8 @@ bool CGPSDThread::decodeData()
     current_log.heading = gpsdata->fix.track;
     current_log.velocity = gpsdata->fix.speed;
 
+    current_log.sat_used = gpsdata->satellites_used;
+
     changed = true;
 
     return true;
