@@ -17,7 +17,6 @@
 
 **********************************************************************************************/
 
-
 #include "CDiaryEdit.h"
 #include "CGeoDB.h"
 #include "CDiary.h"
@@ -46,7 +45,6 @@ class CDiaryEditLock
         CDiaryEdit * d;
 };
 
-
 CDiaryEdit::CDiaryEdit(CDiary& diary, QWidget * parent)
 : QWidget(parent)
 , isInternalEdit(0)
@@ -172,6 +170,7 @@ CDiaryEdit::CDiaryEdit(CDiary& diary, QWidget * parent)
 
 }
 
+
 CDiaryEdit::~CDiaryEdit()
 {
     collectData();
@@ -183,7 +182,6 @@ CDiaryEdit::~CDiaryEdit()
 }
 
 
-
 void CDiaryEdit::mergeFormatOnWordOrSelection(const QTextCharFormat &format)
 {
     QTextCursor cursor = textEdit->textCursor();
@@ -195,6 +193,7 @@ void CDiaryEdit::mergeFormatOnWordOrSelection(const QTextCharFormat &format)
     textEdit->mergeCurrentCharFormat(format);
 }
 
+
 void CDiaryEdit::fontChanged(const QFont &f)
 {
     actionTextBold->setChecked(f.bold());
@@ -202,6 +201,7 @@ void CDiaryEdit::fontChanged(const QFont &f)
     actionTextUnderline->setChecked(f.underline());
 }
 
+
 void CDiaryEdit::resizeEvent(QResizeEvent * e)
 {
     QWidget::resizeEvent(e);
@@ -214,6 +214,7 @@ void CDiaryEdit::resizeEvent(QResizeEvent * e)
     draw(*textEdit->document());
 }
 
+
 void CDiaryEdit::closeEvent(QCloseEvent * e)
 {
     if(diary.isModified())
@@ -226,15 +227,16 @@ void CDiaryEdit::closeEvent(QCloseEvent * e)
         }
     }
 
-
     QWidget::closeEvent(e);
 }
 
+
 void CDiaryEdit::setWindowModified()
 {
     setWindowModified(true);
 }
 
+
 void CDiaryEdit::setWindowModified(bool yes)
 {
     if(isInternalEdit || !yes) return;
@@ -250,6 +252,7 @@ void CDiaryEdit::setWindowModified(bool yes)
 
 }
 
+
 void CDiaryEdit::slotSave()
 {
     collectData();
@@ -265,11 +268,13 @@ void CDiaryEdit::slotSave()
     setTabTitle();
 }
 
+
 void CDiaryEdit::slotReload()
 {
     slotReload(true);
 }
 
+
 void CDiaryEdit::slotReload(bool fromDB)
 {
     CDiaryEditLock lock(this);
@@ -293,6 +298,7 @@ void CDiaryEdit::slotReload(bool fromDB)
     QApplication::restoreOverrideCursor();
 }
 
+
 void CDiaryEdit::slotPrintPreview()
 {
     CDiaryEditLock lock(this);
@@ -322,11 +328,13 @@ void CDiaryEdit::slotPrintPreview()
     draw(*textEdit->document());
 }
 
+
 void CDiaryEdit::slotClipboardDataChanged()
 {
     actionPaste->setEnabled(!QApplication::clipboard()->text().isEmpty());
 }
 
+
 void CDiaryEdit::slotTextBold()
 {
     QTextCharFormat fmt;
@@ -350,6 +358,7 @@ void CDiaryEdit::slotTextItalic()
     mergeFormatOnWordOrSelection(fmt);
 }
 
+
 void CDiaryEdit::slotTextColor()
 {
     QColor col = QColorDialog::getColor(textEdit->textColor(), this);
@@ -363,6 +372,7 @@ void CDiaryEdit::slotTextColor()
     colorChanged(col);
 }
 
+
 void CDiaryEdit::slotTextStyle(int styleIndex)
 {
     QTextCursor cursor = textEdit->textCursor();
@@ -433,11 +443,13 @@ void CDiaryEdit::slotCurrentCharFormatChanged(const QTextCharFormat &format)
     colorChanged(format.foreground().color());
 }
 
+
 void CDiaryEdit::slotIntReload()
 {
     slotReload(false);
 }
 
+
 void CDiaryEdit::colorChanged(const QColor &c)
 {
     QPixmap pix(16, 16);
@@ -526,6 +538,7 @@ void CDiaryEdit::setTabTitle()
     }
 }
 
+
 static bool qSortWptLessName(CWpt * p1, CWpt * p2)
 {
 
@@ -546,11 +559,13 @@ static bool qSortWptLessTime(CWpt * p1, CWpt * p2)
     return p1->getTimestamp() < p2->getTimestamp();
 }
 
+
 static bool qSortTrkLessTime(CTrack * t1, CTrack * t2)
 {
     return t1->getStartTimestamp() < t2->getStartTimestamp();
 }
 
+
 #define CHAR_PER_LINE 100
 #define ROOT_FRAME_MARGIN 5
 
@@ -648,7 +663,6 @@ void CDiaryEdit::draw(QTextDocument& doc)
         cursor.setPosition(cursor1.position()+1);
     }
 
-
     if(!diary.getWpts().isEmpty())
     {
         QList<CWpt*>& wpts = diary.getWpts();
@@ -669,7 +683,6 @@ void CDiaryEdit::draw(QTextDocument& doc)
         foreach(CWpt * wpt, wpts)
         {
 
-
             table->cellAt(cnt,eSym).firstCursorPosition().insertImage(wpt->getIcon().toImage().scaledToWidth(16, Qt::SmoothTransformation));
             table->cellAt(cnt,eInfo).firstCursorPosition().insertText(wpt->getInfo(), fmtCharStandard);
 
@@ -766,9 +779,8 @@ void CDiaryEdit::getTrackProfile(CTrack * track, QImage& image)
     plot.hide();
     plot.clear();
 
-
     QPolygonF lineElev;
-    QPointF   focusElev;
+    QList<QPointF> focusElev;
     float basefactor = IUnit::self().basefactor;
 
     QList<CTrack::pt_t>& trkpts = track->getTrackPoints();
@@ -798,35 +810,7 @@ void CDiaryEdit::getTrackProfile(CTrack * track, QImage& image)
 
 }
 
-//static QString toPlainText(const QTextTableCell& cell)
-//{
-//    QString str;
-//    for (QTextFrame::iterator frm = cell.begin(); frm != cell.end(); ++frm)
-//    {
-//        const QTextBlock& blk = frm.currentBlock();
-//        for(QTextBlock::iterator frgm = blk.begin(); frgm != blk.end(); ++frgm)
-//        {
-//            str += frgm.fragment().text() + "\n";
-//        }
-//    }
 
-//    return str;
-//}
-
-//static QString toPlainText(const QTextFrame& frame)
-//{
-//    QString str;
-//    for (QTextFrame::iterator frm = frame.begin(); frm != frame.end(); ++frm)
-//    {
-//        const QTextBlock& blk = frm.currentBlock();
-//        for(QTextBlock::iterator frgm = blk.begin(); frgm != blk.end(); ++frgm)
-//        {
-//            str += frgm.fragment().text() + "\n";
-//        }
-//    }
-
-//    return str;
-//}
 
 void CDiaryEdit::collectData()
 {
@@ -869,5 +853,3 @@ void CDiaryEdit::collectData()
         }
     }
 }
-
-
