@@ -25,6 +25,7 @@
 #include "CUnitMetric.h"
 #include "CMapTDB.h"
 #include "CDlgSetupGarminIcons.h"
+#include "GeoMath.h"
 
 #include <QtGui>
 #include <QNetworkProxy>
@@ -51,6 +52,13 @@ CDlgConfig::CDlgConfig(QWidget * parent)
 
     connect(toolPathMapCache, SIGNAL(clicked()), this, SLOT(slotSelectPathMapCache()));
 
+    const char ** tz = tblTimezone;
+    while(*tz)
+    {
+        comboTimeZone->addItem(*tz);
+        tz++;
+    }
+
 }
 
 
@@ -68,6 +76,11 @@ void CDlgConfig::exec()
     lineProxyURL->setText(resources.m_httpProxy);
     lineProxyPort->setText(QString("%1").arg(resources.m_httpProxyPort));
 
+    /*
+    lineProxyUser->setText(resources.m_httpProxyUser);
+    lineProxyPwd->setText(resources.m_httpProxyPwd);
+    */
+
     labelFont->setFont(resources.m_mapfont);
     if(resources.unit->type == "metric")
     {
@@ -85,7 +98,9 @@ void CDlgConfig::exec()
     checkPlaySound->setChecked(resources.m_playSound);
     checkFlipMouseWheel->setChecked(resources.m_flipMouseWheel);
     checkShowProfilePreview->setChecked(resources.m_showTrackProfile);
+    checkShowTrackEleInfo->setChecked(resources.m_showTrackEleInfo);
     checkShowNorth->setChecked(resources.m_showNorth);
+    checkShowClock->setChecked(resources.m_showClock);
     checkShowScale->setChecked(resources.m_showScale);
     checkTooltip->setChecked(resources.m_showToolTip);
     checkShowZoomLevel->setChecked(resources.m_showZoomLevel);
@@ -98,12 +113,11 @@ void CDlgConfig::exec()
     spinGeoDBMinutes->setValue(resources.m_saveGeoDBMinutes);
     labelPathGeoDB->setText(resources.m_pathGeoDB.absolutePath());
 
-
-
     comboDevice->addItem(tr(""),"");
     comboDevice->addItem(tr("QLandkarte M"), "QLandkarteM");
     comboDevice->addItem(tr("Garmin"), "Garmin");
     comboDevice->addItem(tr("Garmin Mass Storage"), "Garmin Mass Storage");
+    comboDevice->addItem(tr("Magellan"), "Magellan");
     comboDevice->addItem(tr("TwoNav"), "TwoNav");
     comboDevice->addItem(tr("NMEA"), "NMEA");
 
@@ -148,6 +162,24 @@ void CDlgConfig::exec()
     spinSizeMapCache->setValue(resources.m_sizeMapCache);
     spinExpireMapCache->setValue(resources.m_expireMapCache);
 
+    comboTimeZone->setCurrentIndex(comboTimeZone->findText(resources.m_timezone));
+    if(resources.m_tzMode == resources.eTZUtc)
+    {
+        radioTimeUtc->setChecked(true);
+    }
+    else if(resources.m_tzMode == resources.eTZLocal)
+    {
+        radioTimeLocal->setChecked(true);
+    }
+    else if(resources.m_tzMode == resources.eTZAuto)
+    {
+        radioTimeAuto->setChecked(true);
+    }
+    else if(resources.m_tzMode == resources.eTZSelected)
+    {
+        radioTimeZone->setChecked(true);
+    }
+
     QDialog::exec();
 }
 
@@ -160,10 +192,15 @@ void CDlgConfig::accept()
     resources.m_httpProxy       = lineProxyURL->text();
     resources.m_httpProxyPort   = lineProxyPort->text().toUInt();
 
+    /*
+    resources.m_httpProxyUser   = lineProxyUser->text();
+    resources.m_httpProxyPwd    = lineProxyPwd->text();
+    */
+
     if(resources.m_useHttpProxy)
-      QNetworkProxy::setApplicationProxy(QNetworkProxy(QNetworkProxy::HttpProxy,resources.m_httpProxy,resources.m_httpProxyPort));
+        QNetworkProxy::setApplicationProxy(QNetworkProxy(QNetworkProxy::HttpProxy,resources.m_httpProxy,resources.m_httpProxyPort));
     else
-      QNetworkProxy::setApplicationProxy(QNetworkProxy(QNetworkProxy::NoProxy));
+        QNetworkProxy::setApplicationProxy(QNetworkProxy(QNetworkProxy::NoProxy));
 
     resources.m_mapfont         = labelFont->font();
 
@@ -181,8 +218,10 @@ void CDlgConfig::accept()
     }
 
     resources.m_flipMouseWheel  = checkFlipMouseWheel->isChecked();
-    resources.m_showTrackProfile  = checkShowProfilePreview->isChecked();
+    resources.m_showTrackProfile = checkShowProfilePreview->isChecked();
+    resources.m_showTrackEleInfo = checkShowTrackEleInfo->isChecked();
     resources.m_showNorth       = checkShowNorth->isChecked();
+    resources.m_showClock       = checkShowClock->isChecked();
     resources.m_showScale       = checkShowScale->isChecked();
     resources.m_showToolTip     = checkTooltip->isChecked();
     resources.m_showZoomLevel   = checkShowZoomLevel->isChecked();
@@ -225,6 +264,24 @@ void CDlgConfig::accept()
     resources.m_sizeMapCache    = spinSizeMapCache->value();
     resources.m_expireMapCache  = spinExpireMapCache->value();
 
+    resources.m_timezone        = comboTimeZone->currentText();
+    if(radioTimeUtc->isChecked())
+    {
+        resources.m_tzMode = resources.eTZUtc;
+    }
+    else if(radioTimeLocal->isChecked())
+    {
+        resources.m_tzMode = resources.eTZLocal;
+    }
+    else if(radioTimeAuto->isChecked())
+    {
+        resources.m_tzMode = resources.eTZAuto;
+    }
+    else if(radioTimeZone->isChecked())
+    {
+        resources.m_tzMode = resources.eTZSelected;
+    }
+
     QDialog::accept();
 }
 
@@ -351,14 +408,13 @@ void CDlgConfig::fillCharsetCombo()
 }
 
 
-
-
 void CDlgConfig::slotSetupGarminIcons()
 {
     CDlgSetupGarminIcons dlg;
     dlg.exec();
 }
 
+
 void CDlgConfig::slotSelectPathGeoDB()
 {
     QString path = QFileDialog::getExistingDirectory(this, tr("Open Directory"), labelPathGeoDB->text(), QFileDialog::ShowDirsOnly);
@@ -368,6 +424,7 @@ void CDlgConfig::slotSelectPathGeoDB()
     }
 }
 
+
 void CDlgConfig::slotSelectWptTextColor()
 {
     QPalette palette = labelWptTextColor->palette();
@@ -383,6 +440,7 @@ void CDlgConfig::slotSelectWptTextColor()
 
 }
 
+
 void CDlgConfig::slotSelectPathMapCache()
 {
     QString path = QFileDialog::getExistingDirectory(this, tr("Open Directory"), labelPathMapCache->text(), QFileDialog::ShowDirsOnly);
@@ -391,4 +449,3 @@ void CDlgConfig::slotSelectPathMapCache()
         labelPathMapCache->setText(path);
     }
 }
-
