@@ -20,24 +20,51 @@
 
 #include <QtGui>
 
-CDlgDeviceExportPath::CDlgDeviceExportPath(const QString& what, QDir &dir, QString& subdir, QWidget * parent)
-    : QDialog(parent)
-    , subdir(subdir)
+CDlgDeviceExportPath::CDlgDeviceExportPath(const QString& what, QDir &dir, QString& subdir, mode_e mode, QWidget * parent)
+: QDialog(parent)
+, subdir(subdir)
 {
     setupUi(this);
 
     labelHead->setText(tr("Where should I place all %1?").arg(what));
 
-    QStringList dirs = dir.entryList(QStringList("*"), QDir::AllDirs|QDir::NoDotAndDotDot);
-
-    foreach(const QString& d, dirs)
+    if(mode == eDirectory)
     {
-        QListWidgetItem * item = new QListWidgetItem(listWidget);
-        item->setText(d);
-        item->setIcon(QIcon(":/icons/iconFolderBlue16x16.png"));
+        QStringList dirs = dir.entryList(QStringList("*"), QDir::AllDirs|QDir::NoDotAndDotDot);
+        foreach(const QString& d, dirs)
+        {
+            QListWidgetItem * item = new QListWidgetItem(listWidget);
+            item->setText(d);
+            item->setIcon(QIcon(":/icons/iconFolderBlue16x16.png"));
+        }
+    }
+    else
+    {
+        QSet<QString> knownPrefix;
+        qDebug() << dir;
+        QStringList files = dir.entryList(QStringList("*.gpx"), QDir::Files|QDir::NoDotAndDotDot);
+        foreach(const QString& f, files)
+        {
+            if(!f.contains('_'))
+            {
+                continue;
+            }
+
+            QString prefix = f.split('_')[0];
+            if(prefix.isEmpty() || knownPrefix.contains(prefix))
+            {
+                continue;
+            }
+            knownPrefix << prefix;
+
+            QListWidgetItem * item = new QListWidgetItem(listWidget);
+            item->setText(prefix);
+            item->setIcon(QIcon(":/icons/iconText16x16.png"));
+
+        }
     }
 
-    lineEdit->setText(QString("Data_%1").arg(QDateTime::currentDateTime().toUTC().toString("yyyy-MM-dd")));
+    lineEdit->setText(QString("Data-%1").arg(QDateTime::currentDateTime().toUTC().toString("yyyy-MM-dd")));
     lineEdit->setFocus();
     lineEdit->selectAll();
 
@@ -45,11 +72,13 @@ CDlgDeviceExportPath::CDlgDeviceExportPath(const QString& what, QDir &dir, QStri
     connect(lineEdit, SIGNAL(returnPressed()), this, SLOT(slotReturnPressed()));
 }
 
+
 CDlgDeviceExportPath::~CDlgDeviceExportPath()
 {
 
 }
 
+
 void CDlgDeviceExportPath::slotItemClicked(QListWidgetItem*item)
 {
     if(item == 0) return;
@@ -58,9 +87,9 @@ void CDlgDeviceExportPath::slotItemClicked(QListWidgetItem*item)
     QDialog::accept();
 }
 
+
 void CDlgDeviceExportPath::slotReturnPressed()
 {
     subdir = lineEdit->text();
     QDialog::accept();
 }
-
