@@ -31,7 +31,10 @@
 
 #include "config.h"
 
+#include "CImageViewer.h"
+
 #include <QtGui>
+#include <QtNetwork>
 
 CDlgEditWpt::CDlgEditWpt(CWpt &wpt, QWidget * parent)
 : QDialog(parent)
@@ -54,6 +57,8 @@ CDlgEditWpt::CDlgEditWpt(CWpt &wpt, QWidget * parent)
     connect(checkHint, SIGNAL(toggled(bool)), this, SLOT(slotToggleHint(bool)));
     connect(pushCreateBuddies, SIGNAL(clicked()), this, SLOT(slotCreateBuddies()));
     connect(checkTransparent, SIGNAL(toggled(bool)), this, SLOT(slotTransparent(bool)));
+    connect(pushSpoiler, SIGNAL(clicked()), this, SLOT(slotCollectSpoiler()));
+    connect(toolEditInfo, SIGNAL(clicked()), this, SLOT(slotEditInfo()));
 
     labelUnitElevation->setText(IUnit::self().baseunit);
     labelUnitProximity->setText(IUnit::self().baseunit);
@@ -81,15 +86,25 @@ CDlgEditWpt::CDlgEditWpt(CWpt &wpt, QWidget * parent)
     if(wpt.isGeoCache())
     {
         labelSpolerHint->show();
+        pushSpoiler->show();
         imageSelect->hide();
         checkTransparent->hide();
     }
     else
     {
         labelSpolerHint->hide();
+        pushSpoiler->hide();
         imageSelect->show();
         checkTransparent->show();
     }
+
+    labelImage->installEventFilter(this);
+
+    networkAccessManager = new QNetworkAccessManager(this);
+    networkAccessManager->setProxy(QNetworkProxy(QNetworkProxy::DefaultProxy));
+    connect(networkAccessManager, SIGNAL(proxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)),this, SLOT(slotProxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)));
+    connect(networkAccessManager,SIGNAL(finished(QNetworkReply*)),this,SLOT(slotRequestFinished(QNetworkReply*)));
+
 }
 
 
@@ -113,7 +128,6 @@ int CDlgEditWpt::exec()
     toolIcon->setIcon(wpt.getIcon());
     toolIcon->setObjectName(wpt.getIconString());
 
-
     lineName->setText(wpt.getName());
 
     checkSticky->setChecked(wpt.sticky);
@@ -177,14 +191,14 @@ int CDlgEditWpt::exec()
 
     if(wpt.isGeoCache())
     {
-//        checkExportBuddies->setChecked(wpt.geocache.exportBuddies);
+        //        checkExportBuddies->setChecked(wpt.geocache.exportBuddies);
 
         wpt.showBuddies(true);
 
         if(wpt.buddies.isEmpty())
         {
             listBuddies->hide();
-//            checkExportBuddies->hide();
+            //            checkExportBuddies->hide();
             pushCreateBuddies->hide();
         }
         else
@@ -197,7 +211,6 @@ int CDlgEditWpt::exec()
                 item->setToolTip(*buddy.pos.begin());
                 listBuddies->addItem(item);
 
-
                 foreach(const QString& pos, buddy.pos)
                 {
                     html.replace(pos, QString("%1 (<b><i style='color: black;'>%2</i></b>)").arg(pos).arg(buddy.name));
@@ -205,7 +218,7 @@ int CDlgEditWpt::exec()
             }
             listBuddies->sortItems();
             listBuddies->show();
-//            checkExportBuddies->show();
+            //            checkExportBuddies->show();
             pushCreateBuddies->show();
         }
 
@@ -217,7 +230,7 @@ int CDlgEditWpt::exec()
     else
     {
         listBuddies->hide();
-//        checkExportBuddies->hide();
+        //        checkExportBuddies->hide();
         pushCreateBuddies->hide();
         checkHint->hide();
 
@@ -227,9 +240,6 @@ int CDlgEditWpt::exec()
         }
     }
 
-
-
-
     QStringList caches;
     CWptDB::self().getListOfGeoCaches(caches);
     caches.prepend("");
@@ -314,11 +324,10 @@ void CDlgEditWpt::accept()
         float ele = CMapDB::self().getDEM().getElevation(pt2.u, pt2.v);
         if(ele != WPT_NOFLOAT) wpt2->ele = ele;
 
-
         CWptDB::self().addWpt(wpt2,false);
     }
 
-//    wpt.geocache.exportBuddies = checkExportBuddies->isChecked();
+    //    wpt.geocache.exportBuddies = checkExportBuddies->isChecked();
 
     wpt.parentWpt = comboParentWpt->currentText();
 
@@ -344,14 +353,21 @@ void CDlgEditWpt::slotSelectIcon()
 
 void CDlgEditWpt::slotAddImage()
 {
+    SETTINGS;
+    QString path = cfg.value("path/images", "./").toString();
+
     QString filename = QFileDialog::getOpenFileName( 0, tr("Select image file")
-        ,"./"
+        ,path
         ,"Image (*)"
         ,0
         , FILE_DIALOG_FLAGS
         );
     if(filename.isEmpty()) return;
 
+    QFileInfo fi(filename);
+    cfg.setValue("path/images", fi.absolutePath());
+
+
     QString info =  QInputDialog::getText( this, tr("Add comment ..."), tr("comment"), QLineEdit::Normal, QFileInfo(filename).fileName());
 
     CWpt::image_t img;
@@ -420,12 +436,14 @@ void CDlgEditWpt::showImage(int idx)
     }
 }
 
+
 void CDlgEditWpt::slotOpenLink(const QUrl& url)
 {
 
     QDesktopServices::openUrl(url);
 }
 
+
 void CDlgEditWpt::slotOpenLink(const QString& link)
 {
 
@@ -467,6 +485,12 @@ void CDlgEditWpt::slotSaveBarcode()
 
     if(filename.isEmpty()) return;
 
+    QFileInfo fi(filename);
+    if(fi.suffix().toLower() != "png")
+    {
+        filename += ".png";
+    }
+
     labelBarcode->pixmap()->save(filename);
 }
 
@@ -516,6 +540,7 @@ void CDlgEditWpt::slotUpdateBarcode()
 
 }
 
+
 void CDlgEditWpt::slotToggleHint(bool show)
 {
     QString html = wpt.getExtInfo(show);
@@ -539,6 +564,7 @@ void CDlgEditWpt::slotToggleHint(bool show)
     webView->setHtml(html);
 }
 
+
 void CDlgEditWpt::slotSelectImage(const CImageSelect::img_t& src)
 {
     wpt.images.clear();
@@ -557,6 +583,7 @@ void CDlgEditWpt::slotSelectImage(const CImageSelect::img_t& src)
     pushDel->setEnabled(wpt.images.count() != 0);
 }
 
+
 void CDlgEditWpt::slotCreateBuddies()
 {
     IMap& dem = CMapDB::self().getDEM();
@@ -573,7 +600,130 @@ void CDlgEditWpt::slotCreateBuddies()
     wpt.showBuddies(false);
 }
 
+
 void CDlgEditWpt::slotTransparent(bool ok)
 {
     imageSelect->setTransparent(ok);
 }
+
+void CDlgEditWpt::slotEditInfo()
+{
+    CWpt::image_t& img = wpt.images[idxImg];
+
+    QString info =  QInputDialog::getText( this, tr("Add comment ..."), tr("comment"), QLineEdit::Normal, img.info);
+
+    if(info.isEmpty())
+    {
+        return;
+    }
+    img.info = info;
+    labelInfo->setText(info);
+
+}
+
+bool CDlgEditWpt::eventFilter(QObject *obj, QEvent *event)
+{
+    if(obj == labelImage)
+    {
+        if(event->type() == QEvent::MouseButtonPress && !wpt.images.isEmpty())
+        {
+            CImageViewer viewer(wpt.images, idxImg, this);
+            viewer.exec();
+        }
+    }
+
+    return QObject::eventFilter(obj, event);
+}
+
+void CDlgEditWpt::slotCollectSpoiler()
+{
+    if(!wpt.link.isEmpty())
+    {
+        if(!wpt.images.isEmpty())
+        {
+            if(QMessageBox::question(0, tr("Delete images..."), tr("Remove all other images first?"), QMessageBox::Yes|QMessageBox::No, QMessageBox::Yes ) == QMessageBox::Yes)
+            {
+                wpt.images.clear();
+                showImage(0);
+                pushDel->setEnabled(false);
+            }
+        }
+
+        QNetworkRequest request;
+        request.setUrl(wpt.link);
+        networkAccessManager->get(request);
+    }
+}
+
+void CDlgEditWpt::slotProxyAuthenticationRequired(const QNetworkProxy &prox, QAuthenticator *auth)
+{
+    QString user;
+    QString pwd;
+
+    CResources::self().getHttpProxyAuth(user,pwd);
+
+    auth->setUser(user);
+    auth->setPassword(pwd);
+}
+
+void CDlgEditWpt::slotRequestFinished(QNetworkReply * reply)
+{
+    if(reply->error() != QNetworkReply::NoError)
+    {
+        return;
+    }
+
+    if(pendingRequests.contains(reply))
+    {
+        CWpt::image_t img;
+        img.info = pendingRequests[reply];
+        img.pixmap.loadFromData(reply->readAll());
+        wpt.images.push_back(img);
+        showImage(wpt.images.count() - 1);
+        pushDel->setEnabled(true);
+        return;
+    }
+
+    QString asw = reply->readAll();
+    reply->deleteLater();
+
+    if(asw.isEmpty())
+    {
+        return;
+    }
+
+
+    QRegExp re1(".*alt=\"Photos\" title=\"Photos\".*");
+    QRegExp re2("(http://img.geocaching.com/cache/large/.*\\.jpg).*<span>(.*)</span>");
+    re2.setMinimal(true);
+
+
+    bool spoilerFound = false;
+    QStringList lines = asw.split("\n");
+    foreach(const QString& line, lines)
+    {
+        if(re1.exactMatch(line))
+        {
+            int pos = 0;
+            while ((pos = re2.indexIn(line, pos)) != -1)
+            {
+                spoilerFound = true;
+
+                QString url  = re2.cap(1);
+                QString text = re2.cap(2);
+
+                QNetworkRequest request;
+                request.setUrl(url);
+                pendingRequests[networkAccessManager->get(request)] = text;
+
+                pos += re2.matchedLength();
+            }
+        }
+    }
+
+    if(!spoilerFound)
+    {
+        QMessageBox::information(0,tr("No spoilers..."), tr("No spoilers found."), QMessageBox::Ok);
+    }
+
+}
