@@ -27,33 +27,34 @@
 #include <pwd.h>
 #endif
 
-
 const QString CDlgMapTDBConfig::text =  QObject::tr(""
-"<!DOCTYPE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'  'http://www.w3.org/TR/html4/loose.dtd'>"
-"<html>"
-"   <head>"
-"       <title></title>"
-"       <META HTTP-EQUIV='CACHE-CONTROL' CONTENT='NO-CACHE'>"
-"       <meta http-equiv='Content-Type' content='text/html; charset=UTF-8'>"
-"       <style type='text/css'>"
-"           p, li { white-space: pre-wrap; }"
-"           td {padding-top: 10px;}"
-"       </style>"
-"   </head>"
-"   <body style=' font-family:'Sans'; font-size:9pt; font-weight:400; font-style:normal;'>"
-"       <p>${copyright}</p>"
-"       <h1>Map Levels</h1>"
-"       <p>${maplevels}</p>"
-"       <h1>Legend</h1>"
-"       <h2>Lines</h2>"
-"       <p>${legendlines}</p>"
-"       <h2>Areas</h2>"
-"       <p>${legendareas}</p>"
-"       <h2>Points</h2>"
-"       <p>${legendpoints}</p>"
-"   </body>"
-"</html>"
-"");
+                                                    "<!DOCTYPE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'  'http://www.w3.org/TR/html4/loose.dtd'>"
+                                                    "<html>"
+                                                    "   <head>"
+                                                    "       <title></title>"
+                                                    "       <META HTTP-EQUIV='CACHE-CONTROL' CONTENT='NO-CACHE'>"
+                                                    "       <meta http-equiv='Content-Type' content='text/html; charset=UTF-8'>"
+                                                    "       <style type='text/css'>"
+                                                    "           p, li { white-space: pre-wrap;}"
+                                                    "           td {padding-top: 3px;}"
+                                                    "           th {background-color: darkBlue; color: white;}"
+
+                                                    "       </style>"
+                                                    "   </head>"
+                                                    "   <body style=' font-family: sans-serif; font-size: 9pt; font-weight:400; font-style:normal;'>"
+                                                    "       <p>${copyright}</p>"
+                                                    "       <h1>Map Levels</h1>"
+                                                    "       <p>${maplevels}</p>"
+                                                    "       <h1>Legend</h1>"
+                                                    "       <h2>Lines</h2>"
+                                                    "       <p>${legendlines}</p>"
+                                                    "       <h2>Areas</h2>"
+                                                    "       <p>${legendareas}</p>"
+                                                    "       <h2>Points</h2>"
+                                                    "       <p>${legendpoints}</p>"
+                                                    "   </body>"
+                                                    "</html>"
+                                                    "");
 
 CDlgMapTDBConfig::CDlgMapTDBConfig(CMapTDB * map)
 : map(map)
