@@ -49,15 +49,16 @@ class CGpx : public QObject, public QDomDocument
         {
             qlVer_foreign,       // file was not created by QLandkarteGT
             qlVer_1_0,           // file uses old, non XSD-compatible extensions
-            qlVer_1_1,           // file uses new, XSD-compatible extensions
+            qlVer_1_1            // file uses new, XSD-compatible extensions
         };
 
         enum exportMode_e
         {
-              eQlgtExport
+            eQlgtExport
             , eCleanExport
             , eOcmExport
             , eBackupExport
+            , eMagellan
         };
 
     public:
