@@ -67,9 +67,9 @@
 CMainWindow * theMainWindow = 0;
 
 CMainWindow::CMainWindow()
-    : geodb(0)
-    , modified(false)
-    , crashed(false)
+: geodb(0)
+, modified(false)
+, crashed(false)
 {
     theMainWindow = this;
     groupProvidedMenu = 0;
@@ -97,6 +97,12 @@ CMainWindow::CMainWindow()
     canvasTab = new CTabWidget(this);
     rightSplitter->addWidget(canvasTab);
 
+#ifdef DO_PROFILING
+    Q_INIT_RESOURCE(Conan);
+    conanWidget = new conan::ConanWidget(this);
+    canvasTab->addTab(conanWidget,tr("Profiling"));
+#endif
+
     canvas = new CCanvas(this);
     canvasTab->addTab(canvas,tr("Map"));
 
@@ -270,7 +276,9 @@ CMainWindow::CMainWindow()
     diarydb     = new CDiaryDB(canvasTab, this);
     searchdb    = new CSearchDB(tabbar, this);
 
-
+#ifdef DO_PROFILING
+    conanWidget->AddRootObject(this);
+#endif
 
     if(resources->useGeoDB())
     {
@@ -400,6 +408,7 @@ CMainWindow::CMainWindow()
     connect(&CTrackDB::self(), SIGNAL(sigHighlightTrack(CTrack *)), canvas, SLOT(slotHighlightTrack(CTrack*)));
     connect(&CTrackDB::self(), SIGNAL(sigChanged()), canvas, SLOT(slotTrackChanged()));
     connect(&soapHttp, SIGNAL(responseReady(const QtSoapMessage &)),this, SLOT(slotGetResponse(const QtSoapMessage &)));
+
 }
 
 
@@ -496,10 +505,12 @@ void CMainWindow::setTitleBar()
 
 void CMainWindow::clearAll()
 {
-    QMessageBox::StandardButton res = QMessageBox::question(0, tr("Clear all..."), tr("This will erase all project data like waypoints and tracks."), QMessageBox::Ok|QMessageBox::Cancel, QMessageBox::Ok);
+    QMessageBox::StandardButton res = QMessageBox::question(0, tr("Clear all..."), tr("This will erase all workspace data like waypoints and tracks."), QMessageBox::Ok|QMessageBox::Cancel, QMessageBox::Ok);
 
     if(res == QMessageBox::Ok)
     {
+        IDB::signalsOff();
+
         CSearchDB::self().clear();
         CMapDB::self().clear();
         CWptDB::self().clear();
@@ -508,6 +519,8 @@ void CMainWindow::clearAll()
         COverlayDB::self().clear();
         CRouteDB::self().clear();
         clear();
+
+        IDB::signalsOn();
     }
 }
 
@@ -641,7 +654,6 @@ void CMainWindow::setupMenuBar()
     menu->addSeparator();
     slotUpdate();
     menu->addAction(QIcon(":/icons/iconGlobe16x16.png"),tr("About &QLandkarte GT"),this,SLOT(slotCopyright()));
-
 #endif
     menuBar()->addMenu(menu);
 }
@@ -680,11 +692,11 @@ void CMainWindow::slotLoadMapSet()
     QString filter   = cfg.value("maps/filter","").toString();
     QString filename = QFileDialog::getOpenFileName( 0, tr("Select map...")
         ,CResources::self().pathMaps
-#ifdef HAS_RMAP
-        ,"All (*.*);;Map Collection (*.qmap);;Garmin (*.tdb);;BirdsEye (*.jnx);;TwoNav (*.rmap)"
-#else
-        ,"All (*.*);;Map Collection (*.qmap);;Garmin (*.tdb);;BirdsEye (*.jnx)"
-#endif
+    #ifdef HAS_RMAP
+        ,"All (*.*);;Map Collection (*.qmap);;Garmin (*.tdb);;BirdsEye (*.jnx);;TwoNav (*.rmap);;Magellan (*.rmp)"
+    #else
+        ,"All (*.*);;Map Collection (*.qmap);;Garmin (*.tdb);;BirdsEye (*.jnx);;Magellan (*.rmp)"
+    #endif
         , &filter
         , FILE_DIALOG_FLAGS
         );
@@ -696,6 +708,7 @@ void CMainWindow::slotLoadMapSet()
     cfg.setValue("maps/filter",filter);
 }
 
+
 void CMainWindow::slotLoadOnlineMapSet()
 {
     CDlgLoadOnlineMap dlg;
@@ -730,6 +743,7 @@ void CMainWindow::slotConfig()
     dlg.exec();
 }
 
+
 void CMainWindow::slotLoadData()
 {
     QString formats = getGeoDataFormats();
@@ -753,6 +767,8 @@ void CMainWindow::slotLoadData()
         }
     }
 
+    IDB::signalsOff();
+
     CMapDB::self().clear();
     CWptDB::self().clear();
     CTrackDB::self().clear();
@@ -763,10 +779,11 @@ void CMainWindow::slotLoadData()
     QString filename;
     foreach(filename, filenames)
     {
-        loadData(filename, filter);
-        addRecent(filename);
+        if (loadData(filename, filter)) addRecent(filename);
     }
 
+    IDB::signalsOn();
+
     wksFile = filename;
 
     modified = false;
@@ -797,8 +814,7 @@ void CMainWindow::slotAddData()
         if(filename.isEmpty()) return;
 
         QString tmp = wksFile;
-        loadData(filename, filter);
-        addRecent(filename);
+        if (loadData(filename, filter)) addRecent(filename);
 
         wksFile = tmp;
 
@@ -811,9 +827,10 @@ void CMainWindow::slotAddData()
 }
 
 
-void CMainWindow::loadData(const QString& filename, const QString& filter)
+bool CMainWindow::loadData(const QString& filename, const QString& filter)
 {
     QTemporaryFile tmpfile;
+    bool success = false;
     bool loadGPXData = false;
     QFileInfo fileInfo(filename);
     QString ext = fileInfo.suffix().toUpper();
@@ -899,7 +916,6 @@ void CMainWindow::loadData(const QString& filename, const QString& filter)
                 loadGPXData = convertData("unicsv", filename, "gpx", tmpfile.fileName());
             }
 
-
             if (!loadGPXData)
             {
                 QMessageBox::critical(0,tr("Convert error"),"Error in data conversion?",QMessageBox::Ok,QMessageBox::NoButton);
@@ -914,15 +930,16 @@ void CMainWindow::loadData(const QString& filename, const QString& filter)
             CDiaryDB::self().loadGPX(gpx);
             COverlayDB::self().loadGPX(gpx);
 
-
         }
         wksFile = filename;
+        success = true;
     }
     catch(const QString& msg)
     {
         wksFile.clear();
         QMessageBox:: critical(this,tr("Error"), msg, QMessageBox::Cancel, QMessageBox::Cancel);
     }
+    return success;
 }
 
 
@@ -1065,7 +1082,7 @@ void CMainWindow::saveData(QString& fn, const QString& filter, bool exportFlag)
             {
                 filename += ".qlb";
             }
-        ext = "QLB";
+            ext = "QLB";
         }
     }
     else
@@ -1179,7 +1196,6 @@ void CMainWindow::exportToOcm()
         return;
     }
 
-
     CGpx gpx(this, CGpx::eOcmExport);
     CWptDB::self().saveGPX(gpx, keysWpt);
     CTrackDB::self().saveGPX(gpx, keysTrk);
@@ -1187,7 +1203,6 @@ void CMainWindow::exportToOcm()
     gpx.makeExtensions();
     COverlayDB::self().saveGPX(gpx, QStringList());
 
-
     QDBusConnection dbus = QDBusConnection::sessionBus();
     QStringList serviceNames = dbus.interface()->registeredServiceNames();
     while(!serviceNames.contains("org.ocm.dbus"))
@@ -1198,7 +1213,7 @@ void CMainWindow::exportToOcm()
             return;
         }
 
-//        qDebug() << "start ocm-gtk";
+        //        qDebug() << "start ocm-gtk";
         ocm.startDetached("ocm-gtk");
         sleep(3);
         cnt++;
@@ -1212,16 +1227,17 @@ void CMainWindow::exportToOcm()
     msg = QDBusMessage::createMethodCall("org.ocm.dbus", "/org/ocm/dbus", "org.ocm.dbus", "ShowOCM");
     msg = dbus.call(msg);
 
-//    qDebug() << msg.errorName()  << msg.errorMessage();
+    //    qDebug() << msg.errorName()  << msg.errorMessage();
 
     msg = QDBusMessage::createMethodCall("org.ocm.dbus", "/org/ocm/dbus", "org.ocm.dbus", "ImportGPX");
     msg << file.fileName();
     msg = dbus.call(msg);
 
-//    qDebug() << msg.errorName()  << msg.errorMessage();
+    //    qDebug() << msg.errorName()  << msg.errorMessage();
 #endif
 }
 
+
 void CMainWindow::slotPrint()
 {
     QPrinter printer;
@@ -1287,13 +1303,11 @@ void CMainWindow::slotModified()
 }
 
 
-
-
 void CMainWindow::slotDataChanged()
 {
 
     int c;
-    QString str = tr("<div style='float: left;'><b>Project Summary (<a href='Clear'>clear</a> project):</b></div>");
+    QString str = tr("<div style='float: left;'><b>Workspace Summary (<a href='Clear'>clear</a> workspace):</b></div>");
 
     str += "<p>";
     c = CWptDB::self().count();
@@ -1364,15 +1378,15 @@ void CMainWindow::slotDataChanged()
         str += tr("no overlays. ");
     }
 
-//    c = CDiaryDB::self().count();
-//    if(c > 0)
-//    {
-//        str += tr("A <a href='Diary'>diary</a> is loaded.");
-//    }
-//    else
-//    {
-//        str += tr("The diary (<a href='Diary'>new</a>) is empty.");
-//    }
+    //    c = CDiaryDB::self().count();
+    //    if(c > 0)
+    //    {
+    //        str += tr("A <a href='Diary'>diary</a> is loaded.");
+    //    }
+    //    else
+    //    {
+    //        str += tr("The diary (<a href='Diary'>new</a>) is empty.");
+    //    }
 
     str += "</p>";
 
@@ -1385,7 +1399,7 @@ void CMainWindow::slotOpenLink(const QString& link)
 {
     if(link == "Diary")
     {
-//        CDiaryDB::self().openEditWidget();
+        //        CDiaryDB::self().openEditWidget();
     }
     else if(link == "Clear")
     {
@@ -1413,6 +1427,7 @@ void CMainWindow::slotDeviceChanged()
     comboDevice->addItem(tr("QLandkarte M"), "QLandkarteM");
     comboDevice->addItem(resources->m_devType, "Garmin");
     comboDevice->addItem(tr("Garmin Mass Storage"), "Garmin Mass Storage");
+    comboDevice->addItem(tr("Magellan"), "Magellan");
     comboDevice->addItem(tr("TwoNav"), "TwoNav");
     comboDevice->addItem(tr("NMEA"), "NMEA");
 #ifdef HS_MIKROKOPTER
@@ -1457,7 +1472,7 @@ void CMainWindow::slotLoadRecent()
         CDiaryDB::self().clear();
         COverlayDB::self().clear();
 
-        loadData(filename,"");
+        if (loadData(filename,"")) addRecent(filename);
 
         wksFile = filename;
 
@@ -1469,26 +1484,31 @@ void CMainWindow::slotLoadRecent()
 
 void CMainWindow::addRecent(const QString& filename)
 {
-    QString recent;
-    foreach(recent, mostRecent)
+    int recentpos = mostRecent.indexOf(filename);
+    if (recentpos > -1)
     {
-        if(recent == filename) return;
+        if (!recentpos) return;
+        mostRecent.move(recentpos, 0);
+    }
+    else
+    {
+        mostRecent.prepend(filename);
     }
 
     if(mostRecent.count() >= 10)
     {
         mostRecent.removeLast();
     }
-    mostRecent.prepend(filename);
 
     menuMostRecent->clear();
+    QString recent;
     foreach(recent, mostRecent)
     {
         menuMostRecent->addAction(recent, this, SLOT(slotLoadRecent()));
     }
-
 }
 
+
 void CMainWindow::setTempWidget(QWidget * w, const QString& label)
 {
     tmpTabWidget->addTab(w, label);
@@ -1498,6 +1518,7 @@ void CMainWindow::setTempWidget(QWidget * w, const QString& label)
     connect(w, SIGNAL(destroyed(QObject*)), this, SLOT(slotItemDestroyed(QObject*)));
 }
 
+
 void CMainWindow::slotItemDestroyed(QObject *)
 {
     if(tmpTabWidget->count() < 2)
@@ -1506,6 +1527,7 @@ void CMainWindow::slotItemDestroyed(QObject *)
     }
 }
 
+
 void CMainWindow::slotTabCloseRequest(int i)
 {
     QWidget * w = tmpTabWidget->widget(i);
@@ -1515,26 +1537,31 @@ void CMainWindow::slotTabCloseRequest(int i)
     }
 }
 
+
 void CMainWindow::slotFAQ()
 {
     QDesktopServices::openUrl(QUrl("http://sourceforge.net/apps/mediawiki/qlandkartegt/index.php?title=FAQ"));
 }
 
+
 void CMainWindow::slotHelp()
 {
-    QDesktopServices::openUrl(QUrl("http://sourceforge.net/apps/mediawiki/qlandkartegt/index.php?title=Help_for_QLandkarte_GT"));
+    QDesktopServices::openUrl(QUrl("http://sourceforge.net/apps/mediawiki/qlandkartegt/index.php?title=QLandkarte_GT"));
 }
 
+
 void CMainWindow::slotSupport()
 {
-    QDesktopServices::openUrl(QUrl("http://www.qlandkarte.org/index.php?option=com_content&view=article&id=17&Itemid=19"));
+    QDesktopServices::openUrl(QUrl("http://www.qlandkarte.org/530747a0730821603/index.html"));
 }
 
+
 void CMainWindow::slotDownload()
 {
-    QDesktopServices::openUrl(QUrl("http://www.qlandkarte.org/index.php?option=com_content&view=article&id=17&Itemid=19"));
+    QDesktopServices::openUrl(QUrl("http://www.qlandkarte.org/530747a0720dfbb0d/index.html"));
 }
 
+
 void CMainWindow::slotUpdate()
 {
     QtSoapMessage request;
@@ -1544,6 +1571,7 @@ void CMainWindow::slotUpdate()
     soapHttp.submitRequest(request, "/webservice/qlandkartegt.php");
 }
 
+
 void CMainWindow::slotGetResponse(const QtSoapMessage &message)
 {
     if (message.isFault())
@@ -1563,6 +1591,7 @@ void CMainWindow::slotGetResponse(const QtSoapMessage &message)
     }
 }
 
+
 void CMainWindow::slotToggleToolView()
 {
     qDebug() << "CMainWindow::slotToggleToolView()";
@@ -1576,6 +1605,7 @@ void CMainWindow::slotToggleToolView()
     }
 }
 
+
 bool CMainWindow::isGPSBabel()
 {
     bool haveGPSBabel = false;
@@ -1586,7 +1616,9 @@ bool CMainWindow::isGPSBabel()
     return haveGPSBabel;
 }
 
-QString CMainWindow::getGeoDataFormats() {
+
+QString CMainWindow::getGeoDataFormats()
+{
 
     bool haveGPSBabel = isGPSBabel();
 
