@@ -49,6 +49,10 @@ class CDBus;
 class CGridDB;
 class QCheckBox;
 
+#ifdef DO_PROFILING
+#include <Conan.h>
+#endif
+
 class CMainWindow : public QMainWindow
 {
     Q_OBJECT;
@@ -72,7 +76,7 @@ class CMainWindow : public QMainWindow
         CMenus *getActionGroupProvider() { return actionGroupProvider;}
 
         void exportToOcm();
-        void loadData(const QString& filename, const QString& filter);
+        bool loadData(const QString& filename, const QString& filter);
 
         bool didCrash(){return crashed;}
 
@@ -205,7 +209,9 @@ class CMainWindow : public QMainWindow
 
         QtSoapHttpTransport soapHttp;
 
-
+#ifdef DO_PROFILING
+        conan::ConanWidget * conanWidget;
+#endif
 };
 
 extern CMainWindow * theMainWindow;
