@@ -28,10 +28,9 @@
 #define MAX_IDX_ZOOM 26
 #define MIN_IDX_ZOOM 0
 
-
 CMapJnx::scale_t CMapJnx::scales[] =
 {
-     {80000,  2083334 }
+    {80000,  2083334 }
     ,{5000,   1302084 }
     ,{3000,   781250  }
     ,{2000,   520834  }
@@ -75,178 +74,43 @@ void readCString(QDataStream& stream, QByteArray& ba)
 
 }
 
+
 CMapJnx::CMapJnx(const QString& key, const QString& fn, CCanvas * parent)
 : IMap(eRaster,key,parent)
+, lon1(180.0)
+, lat1(-90)
+, lon2(-180)
+, lat2(90)
 , xscale(1.0)
 , yscale(-1.0)
 {
-    hdr_t hdr;
+    qint32 productId = -1;
 
     filename = fn;
 
     QFileInfo fi(fn);
-    name = fi.fileName();
-    name = name.left(name.size() - 4);
+    name = fi.baseName();
 
-    QFile file(filename);
-    file.open(QIODevice::ReadOnly);
+    readFile(filename, productId);
 
-    QDataStream stream(&file);
-    stream.setByteOrder(QDataStream::LittleEndian);
+    // find submaps in same directory
+    QDir dir(fi.absoluteDir());
+    QStringList subMaps = dir.entryList(QStringList("*.jnx"), QDir::Files);
 
-    info  = "<h1>" + name + "</h1>";
-
-    stream >> hdr.version;            // byte 00000000..00000003
-    stream >> hdr.devid;              // byte 00000004..00000007
-    stream >> hdr.top;              // byte 00000008..0000000B
-    stream >> hdr.right;              // byte 0000000C..0000000F
-    stream >> hdr.bottom;              // byte 00000010..00000013
-    stream >> hdr.left;              // byte 00000014..00000017
-    stream >> hdr.details;            // byte 00000018..0000001B
-    stream >> hdr.expire;             // byte 0000001C..00000023
-    stream >> hdr.crc;                // byte 00000024..00000027
-    stream >> hdr.signature;          // byte 00000028..0000002B
-    stream >> hdr.signature_offset;   // byte 0000002C..0000002F
-
-    if(hdr.version > 3)
+    if(!files.isEmpty())
     {
-        stream >> hdr.zorder;
-    }
-
-    lat1 = hdr.top * 180.0 / 0x7FFFFFFF;
-    lat2 = hdr.bottom * 180.0 / 0x7FFFFFFF;
-    lon1 = hdr.left * 180.0 / 0x7FFFFFFF;
-    lon2 = hdr.right * 180.0 / 0x7FFFFFFF;
-
-    qDebug() << filename;
-    qDebug() << hex << "Version:" << hdr.version << "DevId" <<  hdr.devid;
-    qDebug() << lon1 << lat1 << lon2 << lat2;
-    qDebug() << hex <<  hdr.top <<  hdr.right <<  hdr.bottom <<  hdr.left;
-    qDebug() << hex << "Details:" <<  hdr.details << "Expire:" <<  hdr.expire << "CRC:" <<  hdr.crc ;
-    qDebug() << hex << "Signature:" <<  hdr.signature << "Offset:" <<  hdr.signature_offset;
-
-
-    QString strTopLeft, strBottomRight;
-    GPS_Math_Deg_To_Str(lon1, lat1, strTopLeft);
-    GPS_Math_Deg_To_Str(lon2, lat2, strBottomRight);
-
-    info += QString("<p><table><tr><th>%1</th><th width='100%'>%2</th></tr>").arg(tr("Parameter")).arg(tr("Value"));
-    info += QString("<tr><td>%1</td><td>%2</td></tr>").arg(tr("Top/Left")).arg(strTopLeft.replace("\260","&#176;"));
-    info += QString("<tr><td>%1</td><td>%2</td></tr>").arg(tr("Bottom/Right")).arg(strBottomRight.replace("\260","&#176;"));
-
-    {
-        projXY p1, p2;
-        double a1,a2, width, height;
-        float u1 = 0, v1 = 0, u2 = 0, v2 = 0;
-        GPS_Math_Str_To_Deg(strTopLeft.replace("&#176;",""), u1, v1);
-        GPS_Math_Str_To_Deg(strBottomRight.replace("&#176;",""), u2, v2);
-
-        p1.u = u1 * DEG_TO_RAD;
-        p1.v = v1 * DEG_TO_RAD;
-        p2.u = u2 * DEG_TO_RAD;
-        p2.v = v1 * DEG_TO_RAD;
-        width   = distance(p1,p2,a1,a2)/1000;
-        p1.u = u1 * DEG_TO_RAD;
-        p1.v = v1 * DEG_TO_RAD;
-        p2.u = u1 * DEG_TO_RAD;
-        p2.v = v2 * DEG_TO_RAD;
-        height  = distance(p1,p2,a1,a2)/1000;
-
-        info += QString("<tr><td>%1</td><td>%2 km&#178; (%3 km x %4 km)</td></tr>").arg(tr("Area")).arg(width*height,0,'f',1).arg(width,0,'f',1).arg(height,0,'f',1);
-        info += QString("<tr><td>%1</td><td>%2</td></tr>").arg(tr("Projection")).arg("+proj=merc +lon_0=0 +k=1 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_defs +towgs84=0,0,0");
-        info += QString("<tr><td>%1</td><td>%2</td></tr>").arg(tr("Z-Order")).arg(hdr.zorder);
-    }
-
-    info += "</table></p>";
-
-    qDebug() << "Levels:";
-    levels.resize(hdr.details);
-    for(quint32 i = 0; i < hdr.details; i++)
-    {
-        level_t& level = levels[i];
-        stream >> level.nTiles >> level.offset >> level.scale;
-
-        if(hdr.version > 3)
+        qDebug() << "load maps with product ID:" << productId;
+        foreach(const QString& subMap, subMaps)
         {
-            quint32 dummy;
-            QTextCodec * codec = QTextCodec::codecForName("utf-8");
-            QByteArray ba;
-
-            stream >> dummy;
-            readCString(stream, ba);
-            level.copyright1 = codec->toUnicode(ba);
-
-        }
-        qDebug() << i << hex << level.nTiles << level.offset << level.scale;
-    }
-
-
-
-    quint32 infoBlockVersion;
-    stream >> infoBlockVersion;
-    if(infoBlockVersion == 0x9)
-    {
-        QTextCodec * codec = QTextCodec::codecForName("utf-8");
-        QByteArray ba;
-        quint8 dummy;
-        QString groupId;
-        QString groupName;
-        QString groupTitle;
-
-        readCString(stream, ba);
-        groupId = codec->toUnicode(ba);
-        readCString(stream, ba);
-        groupName = codec->toUnicode(ba);
-
-        stream >> dummy >> dummy >> dummy;
-        readCString(stream, ba);
-        groupTitle = codec->toUnicode(ba);
-        qDebug() << groupId << groupName << groupTitle;
-
-        info += QString("<p><table><tr><th>%1</th><th>%2</th><th>%3</th><th width='100%'>%4</th></tr>").arg(tr("Level")).arg(tr("#Tiles")).arg(tr("Scale")).arg(tr("Info"));
-        for(quint32 i = 0; i < hdr.details; i++)
-        {
-            level_t& level = levels[i];
-
-            stream >> level.level;
-            readCString(stream, ba);
-            level.name1 = codec->toUnicode(ba);
-            readCString(stream, ba);
-            level.name2 = codec->toUnicode(ba);
-            readCString(stream, ba);
-            level.copyright2 = codec->toUnicode(ba);
-
-            info+= QString("<tr><td>%1(%4)</td><td>%2</td><td>%3</td><td>%5</td></tr>").arg(i).arg(level.nTiles).arg(level.scale).arg(level.level).arg(level.name1 + "<br>" + level.name2 + "<br>" + level.copyright2);
-        }
-        info += "</table></p>";
-    }
-
-
-    for(quint32 i = 0; i < hdr.details; i++)
-    {
-
-        level_t& level = levels[i];
-        const quint32 M = level.nTiles;
-        file.seek(level.offset);
-
-        level.tiles.resize(M);
-
-        for(quint32 m = 0; m < M; m++)
-        {
-
-            qint32 top, right, bottom, left;
-            tile_t& tile = level.tiles[m];
-
-            stream >> top >> right >> bottom >> left;
-            stream >> tile.width >> tile.height >> tile.size >> tile.offset;
-
-            tile.area.setTop(top * 180.0 / 0x7FFFFFFF);
-            tile.area.setRight(right * 180.0 / 0x7FFFFFFF);
-            tile.area.setBottom(bottom * 180.0 / 0x7FFFFFFF);
-            tile.area.setLeft(left * 180.0 / 0x7FFFFFFF);
+            if(dir.absoluteFilePath(subMap) == filename)
+            {
+                continue;
+            }
+            readFile(dir.absoluteFilePath(subMap), productId);
         }
     }
 
+
     pjsrc = pj_init_plus("+proj=merc +ellps=WGS84 +datum=WGS84 +units=m +no_defs +towgs84=0,0,0");
     oSRS.importFromProj4(getProjection());
 
@@ -271,9 +135,15 @@ CMapJnx::CMapJnx(const QString& key, const QString& fn, CCanvas * parent)
     theMainWindow->getCheckBoxQuadraticZoom()->hide();
 }
 
+
 CMapJnx::~CMapJnx()
 {
     qDebug() << "CMapJnx::~CMapJnx()";
+
+    midU = rect.center().x();
+    midV = rect.center().y();
+    convertPt2Rad(midU, midV);
+
     if(pjsrc) pj_free(pjsrc);
 
     SETTINGS;
@@ -289,18 +159,210 @@ CMapJnx::~CMapJnx()
 
 }
 
+
+void CMapJnx::readFile(const QString& fn, qint32& productId)
+{
+
+    hdr_t hdr;
+
+    qDebug() << fn;
+
+    QFile file(fn);
+    file.open(QIODevice::ReadOnly);
+
+    QDataStream stream(&file);
+    stream.setByteOrder(QDataStream::LittleEndian);
+
+    stream >> hdr.version;       // byte 00000000..00000003
+    stream >> hdr.devid;         // byte 00000004..00000007
+    stream >> hdr.lat1;          // byte 00000008..0000000B
+    stream >> hdr.lon2;          // byte 0000000C..0000000F
+    stream >> hdr.lat2;          // byte 00000010..00000013
+    stream >> hdr.lon1;          // byte 00000014..00000017
+    stream >> hdr.details;       // byte 00000018..0000001B
+    stream >> hdr.expire;        // byte 0000001C..0000001F
+    stream >> hdr.productId;     // byte 00000020..00000023
+    stream >> hdr.crc;           // byte 00000024..00000027
+    stream >> hdr.signature;     // byte 00000028..0000002B
+                                 // byte 0000002C..0000002F
+    stream >> hdr.signature_offset;
+
+    if(hdr.version > 3)
+    {
+        stream >> hdr.zorder;
+    }
+    else
+    {
+        hdr.zorder = -1;
+    }
+
+    if(productId != -1 && hdr.productId != productId)
+    {
+        return;
+    }
+
+    productId = hdr.productId;
+
+    info  += "<h1>" + QFileInfo(fn).baseName() + "</h1>";
+
+    files.append(file_t());
+    file_t& mapFile = files.last();
+
+    mapFile.filename = fn;
+
+    mapFile.lat1 = hdr.lat1 * 180.0 / 0x7FFFFFFF;
+    mapFile.lat2 = hdr.lat2 * 180.0 / 0x7FFFFFFF;
+    mapFile.lon1 = hdr.lon1 * 180.0 / 0x7FFFFFFF;
+    mapFile.lon2 = hdr.lon2 * 180.0 / 0x7FFFFFFF;
+    mapFile.bbox = QRectF(QPointF(mapFile.lon1, mapFile.lat1), QPointF(mapFile.lon2, mapFile.lat2));
+
+
+    qDebug() << hex << "Version:" << hdr.version << "DevId" <<  hdr.devid;
+    qDebug() << mapFile.lon1 << mapFile.lat1 << mapFile.lon2 << mapFile.lat2;
+    qDebug() << hex <<  hdr.lon1 <<  hdr.lat1 <<  hdr.lon2 <<  hdr.lat2;
+    qDebug() << hex << "Details:" <<  hdr.details << "Expire:" <<  hdr.expire << "CRC:" <<  hdr.crc ;
+    qDebug() << hex << "Signature:" <<  hdr.signature << "Offset:" <<  hdr.signature_offset;
+
+    QString strTopLeft, strBottomRight;
+    GPS_Math_Deg_To_Str(mapFile.lon1, mapFile.lat1, strTopLeft);
+    GPS_Math_Deg_To_Str(mapFile.lon2, mapFile.lat2, strBottomRight);
+
+    info += QString("<p><table>");
+    info += QString("<tr><td style='background-color: blue; color: white;'>%1</td><td>%2</td></tr>").arg(tr("Product ID")).arg(hdr.productId);
+    info += QString("<tr><td style='background-color: blue; color: white;'>%1</td><td>%2</td></tr>").arg(tr("Top/Left")).arg(strTopLeft.replace("\260","&#176;"));
+    info += QString("<tr><td style='background-color: blue; color: white;'>%1</td><td>%2</td></tr>").arg(tr("Bottom/Right")).arg(strBottomRight.replace("\260","&#176;"));
+
+    {
+        projXY p1, p2;
+        double a1,a2, width, height;
+        float u1 = 0, v1 = 0, u2 = 0, v2 = 0;
+        GPS_Math_Str_To_Deg(strTopLeft.replace("&#176;",""), u1, v1);
+        GPS_Math_Str_To_Deg(strBottomRight.replace("&#176;",""), u2, v2);
+
+        p1.u = u1 * DEG_TO_RAD;
+        p1.v = v1 * DEG_TO_RAD;
+        p2.u = u2 * DEG_TO_RAD;
+        p2.v = v1 * DEG_TO_RAD;
+        width   = distance(p1,p2,a1,a2)/1000;
+        p1.u = u1 * DEG_TO_RAD;
+        p1.v = v1 * DEG_TO_RAD;
+        p2.u = u1 * DEG_TO_RAD;
+        p2.v = v2 * DEG_TO_RAD;
+        height  = distance(p1,p2,a1,a2)/1000;
+
+        info += QString("<tr><td style='background-color: blue; color: white;'>%1</td><td>%2 km&#178; (%3 km x %4 km)</td></tr>").arg(tr("Area")).arg(width*height,0,'f',1).arg(width,0,'f',1).arg(height,0,'f',1);
+        info += QString("<tr><td style='background-color: blue; color: white;'>%1</td><td>%2</td></tr>").arg(tr("Projection")).arg("+proj=merc +lon_0=0 +k=1 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_defs +towgs84=0,0,0");
+        info += QString("<tr><td style='background-color: blue; color: white;'>%1</td><td>%2</td></tr>").arg(tr("Z-Order")).arg(hdr.zorder);
+    }
+
+    info += "</table></p>";
+
+    qDebug() << "Levels:";
+    mapFile.levels.resize(hdr.details);
+    for(quint32 i = 0; i < hdr.details; i++)
+    {
+        level_t& level = mapFile.levels[i];
+        stream >> level.nTiles >> level.offset >> level.scale;
+
+        if(hdr.version > 3)
+        {
+            quint32 dummy;
+            QTextCodec * codec = QTextCodec::codecForName("utf-8");
+            QByteArray ba;
+
+            stream >> dummy;
+            readCString(stream, ba);
+            level.copyright1 = codec->toUnicode(ba);
+
+        }
+        qDebug() << i << hex << level.nTiles << level.offset << level.scale;
+    }
+
+    quint32 infoBlockVersion;
+    stream >> infoBlockVersion;
+    if(infoBlockVersion == 0x9)
+    {
+        QTextCodec * codec = QTextCodec::codecForName("utf-8");
+        QByteArray ba;
+        quint8 dummy;
+        QString groupId;
+        QString groupName;
+        QString groupTitle;
+
+        readCString(stream, ba);
+        groupId = codec->toUnicode(ba);
+        readCString(stream, ba);
+        groupName = codec->toUnicode(ba);
+
+        stream >> dummy >> dummy >> dummy;
+        readCString(stream, ba);
+        groupTitle = codec->toUnicode(ba);
+        qDebug() << groupId << groupName << groupTitle;
+
+        info += QString("<p><table><tr><th>%1</th><th>%2</th><th>%3</th><th width='100%'>%4</th></tr>").arg(tr("Level")).arg(tr("#Tiles")).arg(tr("Scale")).arg(tr("Info"));
+        for(quint32 i = 0; i < hdr.details; i++)
+        {
+            level_t& level = mapFile.levels[i];
+
+            stream >> level.level;
+            readCString(stream, ba);
+            level.name1 = codec->toUnicode(ba);
+            readCString(stream, ba);
+            level.name2 = codec->toUnicode(ba);
+            readCString(stream, ba);
+            level.copyright2 = codec->toUnicode(ba);
+
+            info+= QString("<tr><td>%1(%4)</td><td>%2</td><td>%3</td><td>%5</td></tr>").arg(i).arg(level.nTiles).arg(level.scale).arg(level.level).arg(level.name1 + "<br>" + level.name2 + "<br>" + level.copyright2);
+        }
+        info += "</table></p>";
+    }
+
+    for(quint32 i = 0; i < hdr.details; i++)
+    {
+
+        level_t& level = mapFile.levels[i];
+        const quint32 M = level.nTiles;
+        file.seek(level.offset);
+
+        level.tiles.resize(M);
+
+        for(quint32 m = 0; m < M; m++)
+        {
+
+            qint32 top, right, bottom, left;
+            tile_t& tile = level.tiles[m];
+
+            stream >> top >> right >> bottom >> left;
+            stream >> tile.width >> tile.height >> tile.size >> tile.offset;
+
+            tile.area.setTop(top * 180.0 / 0x7FFFFFFF);
+            tile.area.setRight(right * 180.0 / 0x7FFFFFFF);
+            tile.area.setBottom(bottom * 180.0 / 0x7FFFFFFF);
+            tile.area.setLeft(left * 180.0 / 0x7FFFFFFF);
+        }
+    }
+
+    if(mapFile.lon1 < lon1) lon1  = mapFile.lon1;
+    if(mapFile.lat1 > lat1) lat1  = mapFile.lat1;
+    if(mapFile.lon2 > lon2) lon2  = mapFile.lon2;
+    if(mapFile.lat2 < lat2) lat2  = mapFile.lat2;
+
+}
+
 void CMapJnx::convertPt2M(double& u, double& v)
 {
     u = x + u * xscale * zoomFactor;
     v = y + v * yscale * zoomFactor;
 }
 
+
 void CMapJnx::convertM2Pt(double& u, double& v)
 {
     u = floor((u - x) / (xscale * zoomFactor) + 0.5);
     v = floor((v - y) / (yscale * zoomFactor) + 0.5);
 }
 
+
 void CMapJnx::move(const QPoint& old, const QPoint& next)
 {
     projXY p2;
@@ -323,6 +385,7 @@ void CMapJnx::move(const QPoint& old, const QPoint& next)
     setAngleNorth();
 }
 
+
 void CMapJnx::zoom(bool zoomIn, const QPoint& p0)
 {
     projXY p1;
@@ -361,6 +424,7 @@ void CMapJnx::zoom(bool zoomIn, const QPoint& p0)
 
 }
 
+
 void CMapJnx::zoom(double lon1, double lat1, double lon2, double lat2)
 {
 
@@ -407,6 +471,7 @@ void CMapJnx::zoom(double lon1, double lat1, double lon2, double lat2)
     }
 }
 
+
 void CMapJnx::zoom(qint32& level)
 {
     needsRedraw = true;
@@ -419,6 +484,7 @@ void CMapJnx::zoom(qint32& level)
     emit sigChanged();
 }
 
+
 void CMapJnx::dimensions(double& lon1, double& lat1, double& lon2, double& lat2)
 {
     lon1 = this->lon1 * DEG_TO_RAD;
@@ -428,6 +494,7 @@ void CMapJnx::dimensions(double& lon1, double& lat1, double& lon2, double& lat2)
 
 }
 
+
 void CMapJnx::draw(QPainter& p)
 {
     if(pjsrc == 0) return IMap::draw(p);
@@ -437,7 +504,6 @@ void CMapJnx::draw(QPainter& p)
         draw();
     }
 
-
     p.drawPixmap(0,0,pixBuffer);
 
     if(!ovlMap.isNull() && !doFastDraw)
@@ -448,59 +514,53 @@ void CMapJnx::draw(QPainter& p)
     needsRedraw = false;
 }
 
+
 void CMapJnx::getArea_n_Scaling(projXY& p1, projXY& p2, float& my_xscale, float& my_yscale)
 {
+    p1.u = 0;
+    p1.v = 0;
+    convertPt2Rad(p1.u, p1.v);
 
-    p1.u = x;
-    p1.v = y;
-    convertM2Rad(p1.u, p1.v);
-
-    p2.u = x;
-    p2.v = y;
-    convertM2Pt(p2.u, p2.v);
-
-    p2.u += size.width();
-    p2.v += size.height();
-
+    p2.u = size.width();
+    p2.v = size.height();
     convertPt2Rad(p2.u, p2.v);
 
-
     my_xscale   = xscale*zoomFactor;
     my_yscale   = yscale*zoomFactor;
 }
 
 
-qint32 CMapJnx::zlevel2idx(quint32 zl)
+qint32 CMapJnx::zlevel2idx(quint32 zl, const file_t& file)
 {
     qint32 idxLvl   = -1;
     quint32 actScale = scales[zl].jnxScale;
 
-//    qDebug() << "-----------";
-    for(int i = 0; i < levels.size(); i++)
+    for(int i = 0; i < file.levels.size(); i++)
     {
-        level_t& level = levels[i];
+        const level_t& level = file.levels[i];
 
-//        qDebug() << level.scale << actScale;
         if(actScale <= level.scale)
         {
             idxLvl = i;
         }
-
     }
 
     return idxLvl;
 }
 
+
 void CMapJnx::draw()
 {
     if(pjsrc == 0) return IMap::draw();
 
+    QImage image;
+    QRectF viewport;
+
     pixBuffer.fill(Qt::white);
     QPainter p(&pixBuffer);
 
     p.setBrush(Qt::NoBrush);
 
-
     double u1 = 0;
     double v1 = size.height();
     double u2 = size.width();
@@ -514,80 +574,26 @@ void CMapJnx::draw()
     u2 *= RAD_TO_DEG;
     v2 *= RAD_TO_DEG;
 
-
     viewport.setTop(v2);
     viewport.setRight(u2);
     viewport.setBottom(v1);
     viewport.setLeft(u1);
 
-    qint32 level = zlevel2idx(zoomidx);
-
-    qDebug() << "use level" << level << "zoom level" << zoomidx << scales[zoomidx].qlgtScale;
-
-    if(level < 0)
+    foreach(const file_t& mapFile, files)
     {
-        double u1 = lon1 * DEG_TO_RAD;
-        double u2 = lon2 * DEG_TO_RAD;
-        double v2 = lat2 * DEG_TO_RAD;
-        double v1 = lat1 * DEG_TO_RAD;
-
-        convertRad2Pt(u1,v1);
-        convertRad2Pt(u2,v2);
-
-        QRectF r;
-        r.setLeft(u1);
-        r.setRight(u2);
-        r.setTop(v2);
-        r.setBottom(v1);
-
-        p.setPen(QPen(Qt::darkBlue,2));
-        p.setBrush(QBrush(QColor(230,230,255,100) ));
-        p.drawRect(r);
-        return;
-    }
-
-
-    QByteArray data(1024*1024*4,0);
-    //(char) typecast needed to avoid MSVC compiler warning
-    //in MSVC, char is a signed type.
-    //Maybe the QByteArray declaration should be fixed ;-)
-    data[0] = (char) 0xFF;
-    data[1] = (char) 0xD8;
-    char * pData = data.data() + 2;
-
-    QImage image;
-    QFile file(filename);
-    file.open(QIODevice::ReadOnly);
-
-    quint32 cnt = 0;
-    double m_px = 0.0;
-    double d_px = 0.0;
-    QVector<tile_t>& tiles = levels[level].tiles;
-    const quint32 M = tiles.size();
-    for(quint32 m = 0; m < M; m++)
-    {
-        tile_t& tile = tiles[m];
-
-        if(viewport.intersects(tile.area))
+        if(!viewport.intersects(mapFile.bbox))
         {
-            {
-                double u1 = tile.area.left() * DEG_TO_RAD;
-                double u2 = tile.area.right() * DEG_TO_RAD;
-                double v2 = tile.area.top() * DEG_TO_RAD;
-                double v1 = tile.area.bottom() * DEG_TO_RAD;
+            continue;
+        }
 
-                convertRad2M(u1,v1);
-                convertRad2M(u2,v2);
+        qint32 level = zlevel2idx(zoomidx, mapFile);
 
-                m_px += (u2 - u1) / tile.width;
-                d_px += (tile.area.right() - tile.area.left()) / tile.width;
-                cnt++;
-            }
-
-            double u1 = tile.area.left() * DEG_TO_RAD;
-            double u2 = tile.area.right() * DEG_TO_RAD;
-            double v2 = tile.area.top() * DEG_TO_RAD;
-            double v1 = tile.area.bottom() * DEG_TO_RAD;
+        if(level < 0)
+        {
+            double u1 = mapFile.lon1 * DEG_TO_RAD;
+            double u2 = mapFile.lon2 * DEG_TO_RAD;
+            double v2 = mapFile.lat2 * DEG_TO_RAD;
+            double v1 = mapFile.lat1 * DEG_TO_RAD;
 
             convertRad2Pt(u1,v1);
             convertRad2Pt(u2,v2);
@@ -598,20 +604,59 @@ void CMapJnx::draw()
             r.setTop(v2);
             r.setBottom(v1);
 
-            if(!r.isValid() || r.width() > 3000 || r.height() > 3000)
+            p.setPen(QPen(Qt::darkBlue,2));
+            p.setBrush(QBrush(QColor(230,230,255,100) ));
+            p.drawRect(r);
+            continue;
+        }
+
+        QByteArray data(1024*1024*4,0);
+        //(char) typecast needed to avoid MSVC compiler warning
+        //in MSVC, char is a signed type.
+        //Maybe the QByteArray declaration should be fixed ;-)
+        data[0] = (char) 0xFF;
+        data[1] = (char) 0xD8;
+        char * pData = data.data() + 2;
+
+        QFile file(mapFile.filename);
+        file.open(QIODevice::ReadOnly);
+
+        const QVector<tile_t>& tiles = mapFile.levels[level].tiles;
+        const quint32 M = tiles.size();
+        for(quint32 m = 0; m < M; m++)
+        {
+            const tile_t& tile = tiles[m];
+
+            if(viewport.intersects(tile.area))
             {
-                continue;
+
+                double u1 = tile.area.left() * DEG_TO_RAD;
+                double u2 = tile.area.right() * DEG_TO_RAD;
+                double v2 = tile.area.top() * DEG_TO_RAD;
+                double v1 = tile.area.bottom() * DEG_TO_RAD;
+
+                convertRad2Pt(u1,v1);
+                convertRad2Pt(u2,v2);
+
+                QRectF r;
+                r.setLeft(u1);
+                r.setRight(u2);
+                r.setTop(v2);
+                r.setBottom(v1);
+
+                if(!r.isValid() || r.width() > 3000 || r.height() > 3000)
+                {
+                    continue;
+                }
+
+                file.seek(tile.offset);
+                file.read(pData, tile.size);
+                image.loadFromData(data);
+
+                p.drawImage(r.toRect(), image.scaled(r.size().toSize(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation));
             }
-
-            file.seek(tile.offset);
-            file.read(pData, tile.size);
-            image.loadFromData(data);
-
-            p.drawImage(r.toRect(), image.scaled(r.size().toSize(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation));
         }
     }
-    qDebug() << m_px/cnt << "m/px";
-    qDebug() << d_px/cnt << "\260/px";
 }
 
 
