@@ -60,7 +60,6 @@ CMapQMAP::CMapQMAP(const QString& key, const QString& fn, CCanvas * parent)
     quadraticZoom = mapdef.value("main/quadraticZoom",quadraticZoom).toBool();
     info += "<p>" + tr("Quadratic zoom %1").arg(quadraticZoom ? tr("enabled") : tr("disabled")) + "</p>";
     info += QString("<p><table><tr><th>%1</th><th>%2</th><th width='100%'>%3</th></tr>").arg(tr("Map Level")).arg(tr("Zoom Level")).arg(tr("Files"));
-
     // create map level list
     CMapLevel * maplevel = 0;
     for(int n=1; n <= nLevels; ++n)
@@ -88,13 +87,13 @@ CMapQMAP::CMapQMAP(const QString& key, const QString& fn, CCanvas * parent)
     }
     info += "</table></p>";
 
-    info += QString("<p><table><tr><th>%1</th><th width='100%'>%2</th></tr>").arg(tr("Parameter")).arg(tr("Value"));
 
     QString strTopLeft      = mapdef.value("description/topleft").toString();
     QString strBottomRight  = mapdef.value("description/bottomright").toString();
 
-    info += QString("<tr><td>%1</td><td>%2</td></tr>").arg(tr("Top/Left")).arg(strTopLeft.replace("\260","&#176;"));
-    info += QString("<tr><td>%1</td><td>%2</td></tr>").arg(tr("Bottom/Right")).arg(strBottomRight.replace("\260","&#176;"));
+    info += QString("<p><table>");
+    info += QString("<tr><td style='background-color: blue; color: white;'>%1</td><td>%2</td></tr>").arg(tr("Top/Left")).arg(strTopLeft.replace("\260","&#176;"));
+    info += QString("<tr><td style='background-color: blue; color: white;'>%1</td><td>%2</td></tr>").arg(tr("Bottom/Right")).arg(strBottomRight.replace("\260","&#176;"));
 
     if(!maplevels.isEmpty())
     {
@@ -115,14 +114,13 @@ CMapQMAP::CMapQMAP(const QString& key, const QString& fn, CCanvas * parent)
         p2.v = v2 * DEG_TO_RAD;
         height  = distance(p1,p2,a1,a2)/1000;
 
-        info += QString("<tr><td>%1</td><td>%2 km&#178; (%3 km x %4 km)</td></tr>").arg(tr("Area")).arg(width*height,0,'f',1).arg(width,0,'f',1).arg(height,0,'f',1);
+        info += QString("<tr><td style='background-color: blue; color: white;'>%1</td><td>%2 km&#178; (%3 km x %4 km)</td></tr>").arg(tr("Area")).arg(width*height,0,'f',1).arg(width,0,'f',1).arg(height,0,'f',1);
         if(maplevels[0]->begin() != maplevels[0]->end())
         {
-            info += QString("<tr><td>%1</td><td>%2</td></tr>").arg(tr("Projection")).arg((*maplevels[0]->begin())->strProj);
+            info += QString("<tr><td style='background-color: blue; color: white;'>%1</td><td>%2</td></tr>").arg(tr("Projection")).arg((*maplevels[0]->begin())->strProj);
         }
     }
 
-
     info += "</table></p>";
 
     // If no configuration is stored read values from the map definition's "home" section
@@ -176,7 +174,6 @@ const QString& CMapQMAP::getFilename(int u, int v)
 {
     if(pMaplevel.isNull()) return filename;
 
-
     QVector<CMapFile*>::const_iterator it = pMaplevel->begin();
     while(it != pMaplevel->end())
     {
@@ -205,6 +202,7 @@ const QString& CMapQMAP::getFilename(int u, int v)
     return filename;
 }
 
+
 bool CMapQMAP::is32BitRgb()
 {
     return pMaplevel.isNull() ? true : pMaplevel->is32BitRgb();
@@ -446,10 +444,11 @@ void CMapQMAP::draw()
 
                             for (offset = 0; offset < sizeof(testPix) && *(((quint8 *)&testPix) + offset) != pbandColour; offset++);
 
-/// @todo this has to be removed with GDAL 1.8.0
+                            /// @todo this has to be removed with GDAL 1.8.0
 #ifdef WIN32
                             //offset = 3 - b;
-#endif // WIN32
+                                 // WIN32
+#endif
 
                             if(offset < sizeof(testPix))
                             {
@@ -511,6 +510,7 @@ void CMapQMAP::convertM2Pt(double& u, double& v)
     v = floor((v - pt.v) / (map->yscale * zoomFactor) + 0.5);
 }
 
+
 void CMapQMAP::convertPt2Pixel(double& u, double& v)
 {
     QVector<CMapFile*>::const_iterator it = pMaplevel->begin();
@@ -544,6 +544,7 @@ void CMapQMAP::convertPt2Pixel(double& u, double& v)
 
 }
 
+
 void CMapQMAP::move(const QPoint& old, const QPoint& next)
 {
 
@@ -795,6 +796,7 @@ void CMapQMAP::select(IMapSelection& ms, const QRect& rect)
 
 }
 
+
 quint32 CMapQMAP::scalePixelGrid(quint32 nPixel)
 {
     CMapLevel * level       = maplevels[0];
@@ -803,6 +805,7 @@ quint32 CMapQMAP::scalePixelGrid(quint32 nPixel)
     return quint32((nPixel * file1->xscale)/(zoomFactor * file2->xscale) + 0.5);
 }
 
+
 void CMapQMAP::config()
 {
 
@@ -810,4 +813,3 @@ void CMapQMAP::config()
     dlg->show();
 
 }
-
