@@ -38,11 +38,13 @@ static bool tileIndexLessThan(const QPair<int, int> &i1, const QPair<int, int> &
     {
         return i1.first < i2.first;
     }
-    else{
+    else
+    {
         return false;
     }
 }
 
+
 // --------------------------------------------------------------------------------------------
 CMapQMAPExport::CMapQMAPExport(const CMapSelectionRaster& mapsel, QWidget * parent)
 : QDialog(parent)
@@ -61,6 +63,7 @@ CMapQMAPExport::CMapQMAPExport(const CMapSelectionRaster& mapsel, QWidget * pare
     connect(radioJNX, SIGNAL(toggled(bool)), this, SLOT(slotBirdsEyeToggled(bool)));
     connect(radioGCM, SIGNAL(toggled(bool)), this, SLOT(slotGCMToggled(bool)));
     connect(radioRMAP, SIGNAL(toggled(bool)), this, SLOT(slotRMAPToggled(bool)));
+    connect(radioRMP, SIGNAL(toggled(bool)), this, SLOT(slotRMPToggled(bool)));
 
     connect(&cmd, SIGNAL(readyReadStandardError()), this, SLOT(slotStderr()));
     connect(&cmd, SIGNAL(readyReadStandardOutput()), this, SLOT(slotStdout()));
@@ -69,6 +72,8 @@ CMapQMAPExport::CMapQMAPExport(const CMapSelectionRaster& mapsel, QWidget * pare
     connect(toolGeoTiffProjWizard, SIGNAL(clicked()), this, SLOT(slotSetupProj()));
     connect(toolGeoTiffFromMap, SIGNAL(clicked()), this, SLOT(slotSetupProjFromMap()));
 
+    connect(toolMagellanCopyright, SIGNAL(clicked()), this, SLOT(slotSelectCopyright()));
+
     SETTINGS;
     labelPath->setText(cfg.value("path/export","./").toString());
 
@@ -99,6 +104,7 @@ CMapQMAPExport::CMapQMAPExport(const CMapSelectionRaster& mapsel, QWidget * pare
     path_map2gcm        = QCoreApplication::applicationDirPath()+QDir::separator()+"map2gcm.exe";
     path_cache2gtiff    = QCoreApplication::applicationDirPath()+QDir::separator()+"cache2gtiff.exe";
     path_map2rmap       = QCoreApplication::applicationDirPath()+QDir::separator()+"map2rmap.exe";
+    path_map2rmp        = QCoreApplication::applicationDirPath()+QDir::separator()+"map2rmp.exe";
 #else
 #if defined(Q_WS_MAC)
     // MacOS X: applications are stored in the bundle folder
@@ -106,11 +112,13 @@ CMapQMAPExport::CMapQMAPExport(const CMapSelectionRaster& mapsel, QWidget * pare
     path_map2jnx        = QString("%1/Resources/map2jnx").arg(QCoreApplication::applicationDirPath().replace(QRegExp("MacOS$"), ""));
     path_cache2gtiff    = QString("%1/Resources/cache2gtiff").arg(QCoreApplication::applicationDirPath().replace(QRegExp("MacOS$"), ""));
     path_map2rmap       = QString("%1/Resources/map2rmap").arg(QCoreApplication::applicationDirPath().replace(QRegExp("MacOS$"), ""));
+    path_map2rmp        = QString("%1/Resources/map2rmp").arg(QCoreApplication::applicationDirPath().replace(QRegExp("MacOS$"), ""));
 #else
     path_map2gcm        = "map2gcm";
     path_map2jnx        = MAP2JNX;
     path_cache2gtiff    = "cache2gtiff";
     path_map2rmap       = "map2rmap";
+    path_map2rmp        = "map2rmp";
 #endif
     QProcess proc1;
     proc1.start(path_map2jnx, QStringList());
@@ -121,6 +129,7 @@ CMapQMAPExport::CMapQMAPExport(const CMapSelectionRaster& mapsel, QWidget * pare
     groupJPEG->hide();
     groupDevice->hide();
     groupRMAP->hide();
+    groupMagellanRmp->hide();
 
     spinJpegQuality->setValue(cfg.value("map/export/jnx/quality",75).toInt());
     comboJpegSubsampling->setCurrentIndex(comboJpegSubsampling->findText(cfg.value("map/export/jnx/subsampling","411").toString()));
@@ -128,9 +137,15 @@ CMapQMAPExport::CMapQMAPExport(const CMapSelectionRaster& mapsel, QWidget * pare
     lineProductName->setText(cfg.value("map/export/jnx/productname","BirdsEye").toString());
     lineCopyright->setText(cfg.value("map/export/jnx/copyright","None").toString());
 
+    lineMagellanProvider->setText(cfg.value("map/export/rmp/provider", tr("Please enter a string")).toString());
+    lineMagellanProduct->setText(cfg.value("map/export/rmp/product", tr("Please enter a string")).toString());
+    copyright = cfg.value("map/export/rmp/copyright", tr("")).toString();
+    labelMagellanCopyright->setText(QFileInfo(copyright).fileName());
+
     radioQLM->setChecked(cfg.value("map/export/qlm", true).toBool());
     radioGCM->setChecked(cfg.value("map/export/gcm", false).toBool());
     radioRMAP->setChecked(cfg.value("map/export/rmap", false).toBool());
+    radioRMP->setChecked(cfg.value("map/export/rmp", false).toBool());
 
     if (has_map2jnx)
     {
@@ -141,7 +156,6 @@ CMapQMAPExport::CMapQMAPExport(const CMapSelectionRaster& mapsel, QWidget * pare
         radioJNX->hide();
     }
 
-
     checkOverview2x->setChecked(cfg.value("map/export/over2x", true).toBool());
     checkOverview4x->setChecked(cfg.value("map/export/over4x", true).toBool());
     checkOverview8x->setChecked(cfg.value("map/export/over8x", true).toBool());
@@ -183,6 +197,8 @@ CMapQMAPExport::CMapQMAPExport(const CMapSelectionRaster& mapsel, QWidget * pare
         groupStreaming->show();
     }
 
+
+
     QFont f = font();
     f.setFamily("Mono");
     textBrowser->setFont(f);
@@ -191,6 +207,7 @@ CMapQMAPExport::CMapQMAPExport(const CMapSelectionRaster& mapsel, QWidget * pare
 
 }
 
+
 CMapQMAPExport::~CMapQMAPExport()
 {
     SETTINGS;
@@ -200,6 +217,7 @@ CMapQMAPExport::~CMapQMAPExport()
     cfg.setValue("map/export/gcm", radioGCM->isChecked());
     cfg.setValue("map/export/jnx", radioJNX->isChecked());
     cfg.setValue("map/export/rmap", radioRMAP->isChecked());
+    cfg.setValue("map/export/rmp", radioRMP->isChecked());
 
     cfg.setValue("map/export/jnx/quality", spinJpegQuality->value());
     cfg.setValue("map/export/jnx/subsampling", comboJpegSubsampling->currentText());
@@ -207,6 +225,10 @@ CMapQMAPExport::~CMapQMAPExport()
     cfg.setValue("map/export/jnx/productname",lineProductName->text());
     cfg.setValue("map/export/jnx/copyright",lineCopyright->text());
 
+    cfg.setValue("map/export/rmp/provider", lineMagellanProvider->text());
+    cfg.setValue("map/export/rmp/product", lineMagellanProduct->text());
+    cfg.setValue("map/export/rmp/copyright", copyright);
+
     cfg.setValue("map/export/over2x",checkOverview2x->isChecked());
     cfg.setValue("map/export/over4x",checkOverview4x->isChecked());
     cfg.setValue("map/export/over8x",checkOverview8x->isChecked());
@@ -219,6 +241,7 @@ CMapQMAPExport::~CMapQMAPExport()
     cfg.setValue("map/export/hidedetails", textBrowser->isHidden());
 }
 
+
 void CMapQMAPExport::slotSetupProj()
 {
     CDlgProjWizzard dlg(*lineGeoTiffProjection, this);
@@ -226,6 +249,7 @@ void CMapQMAPExport::slotSetupProj()
     lineGeoTiffProjection->setCursorPosition(0);
 }
 
+
 void CMapQMAPExport::slotSetupProjFromMap()
 {
     IMap& map = CMapDB::self().getMap();
@@ -233,11 +257,13 @@ void CMapQMAPExport::slotSetupProjFromMap()
     lineGeoTiffProjection->setCursorPosition(0);
 }
 
+
 void CMapQMAPExport::slotBirdsEyeToggled(bool checked)
 {
     if(checked)
     {
         groupBirdsEye->show();
+        groupMagellanRmp->hide();
         groupJPEG->show();
         groupDevice->show();
         groupOptimization->hide();
@@ -246,6 +272,7 @@ void CMapQMAPExport::slotBirdsEyeToggled(bool checked)
     else
     {
         groupBirdsEye->hide();
+        groupMagellanRmp->hide();
         groupJPEG->hide();
         groupDevice->hide();
         groupOptimization->hide();
@@ -255,11 +282,13 @@ void CMapQMAPExport::slotBirdsEyeToggled(bool checked)
     adjustSize();
 }
 
+
 void CMapQMAPExport::slotGCMToggled(bool checked)
 {
     if(checked)
     {
         groupJPEG->show();
+        groupMagellanRmp->hide();
         groupDevice->show();
         labelTileSelection->hide();
         groupOptimization->hide();
@@ -269,6 +298,7 @@ void CMapQMAPExport::slotGCMToggled(bool checked)
     else
     {
         groupJPEG->hide();
+        groupMagellanRmp->hide();
         groupDevice->hide();
         labelTileSelection->show();
         groupOptimization->hide();
@@ -278,11 +308,13 @@ void CMapQMAPExport::slotGCMToggled(bool checked)
     adjustSize();
 }
 
+
 void CMapQMAPExport::slotQLMToggled(bool checked)
 {
     if(checked)
     {
         groupJPEG->hide();
+        groupMagellanRmp->hide();
         groupDevice->hide();
         labelTileSelection->show();
         groupOptimization->show();
@@ -292,6 +324,7 @@ void CMapQMAPExport::slotQLMToggled(bool checked)
     else
     {
         groupJPEG->hide();
+        groupMagellanRmp->hide();
         groupDevice->hide();
         labelTileSelection->show();
         groupOptimization->hide();
@@ -301,11 +334,13 @@ void CMapQMAPExport::slotQLMToggled(bool checked)
     adjustSize();
 }
 
+
 void CMapQMAPExport::slotRMAPToggled(bool checked)
 {
     if(checked)
     {
         groupJPEG->show();
+        groupMagellanRmp->hide();
         groupDevice->hide();
         labelTileSelection->show();
         groupOptimization->hide();
@@ -315,6 +350,7 @@ void CMapQMAPExport::slotRMAPToggled(bool checked)
     else
     {
         groupJPEG->hide();
+        groupMagellanRmp->hide();
         groupDevice->hide();
         labelTileSelection->show();
         groupOptimization->hide();
@@ -324,6 +360,43 @@ void CMapQMAPExport::slotRMAPToggled(bool checked)
     adjustSize();
 }
 
+void CMapQMAPExport::slotRMPToggled(bool checked)
+{
+    if(checked)
+    {
+        groupJPEG->show();
+        groupMagellanRmp->show();
+        groupDevice->hide();
+        labelTileSelection->show();
+        groupOptimization->hide();
+        groupRMAP->hide();
+
+    }
+    else
+    {
+        groupJPEG->hide();
+        groupMagellanRmp->hide();
+        groupDevice->hide();
+        labelTileSelection->show();
+        groupOptimization->hide();
+        groupRMAP->hide();
+    }
+
+    adjustSize();
+}
+
+void CMapQMAPExport::slotSelectCopyright()
+{
+    copyright = QFileDialog::getOpenFileName(0, tr("Select copyright notice..."),"./", tr("text file (*.txt)"), 0, FILE_DIALOG_FLAGS);
+    if(copyright.isEmpty())
+    {
+        labelMagellanCopyright->clear();
+        return;
+    }
+
+    labelMagellanCopyright->setText(QFileInfo(copyright).fileName());
+
+}
 
 void CMapQMAPExport::slotStderr()
 {
@@ -350,6 +423,7 @@ void CMapQMAPExport::slotStderr()
     tainted = true;
 }
 
+
 void CMapQMAPExport::slotStdout()
 {
     QString str;
@@ -368,13 +442,13 @@ void CMapQMAPExport::slotStdout()
     }
 #endif
 
-
     progress(str);
 
     textBrowser->insertPlainText(str);
     textBrowser->verticalScrollBar()->setValue(textBrowser->verticalScrollBar()->maximum());
 }
 
+
 void CMapQMAPExport::progress(const QString& str)
 {
     QRegExp re("^(0[0-9\\.]*).*$");
@@ -395,6 +469,7 @@ void CMapQMAPExport::progress(const QString& str)
 
 }
 
+
 void CMapQMAPExport::stdOut(const QString& str, bool gui)
 {
     textBrowser->setTextColor(Qt::black);
@@ -409,6 +484,7 @@ void CMapQMAPExport::stdOut(const QString& str, bool gui)
     }
 }
 
+
 void CMapQMAPExport::stdErr(const QString& str, bool gui)
 {
     textBrowser->setTextColor(Qt::red);
@@ -423,6 +499,7 @@ void CMapQMAPExport::stdErr(const QString& str, bool gui)
     }
 }
 
+
 void CMapQMAPExport::slotDetails()
 {
     if(textBrowser->isHidden())
@@ -437,6 +514,7 @@ void CMapQMAPExport::slotDetails()
     adjustSize();
 }
 
+
 void CMapQMAPExport::slotCancel()
 {
     if(cmd.state() != QProcess::NotRunning)
@@ -452,6 +530,7 @@ void CMapQMAPExport::slotCancel()
     }
 }
 
+
 void CMapQMAPExport::slotStart()
 {
     if(!states.isEmpty() || !state.isNull()) return;
@@ -479,6 +558,7 @@ void CMapQMAPExport::slotStart()
     setNextState();
 }
 
+
 void CMapQMAPExport::startExportStreaming()
 {
     QStringList files;
@@ -512,6 +592,7 @@ void CMapQMAPExport::startExportStreaming()
     startExportCommon(files, tarPath, prefix);
 }
 
+
 void CMapQMAPExport::startExportGDAL()
 {
     qDebug() << "CMapQMAPExport::slotStart()";
@@ -634,6 +715,7 @@ void CMapQMAPExport::startExportGDAL()
     startExportCommon(files, tarPath, prefix);
 }
 
+
 void CMapQMAPExport::startExportCommon(QStringList& srcFiles, QDir& tarPath, const QString& prefix)
 {
     // *********************************************
@@ -657,7 +739,10 @@ void CMapQMAPExport::startExportCommon(QStringList& srcFiles, QDir& tarPath, con
     {
         projection = comboRmapProjection->itemData(comboRmapProjection->currentIndex()).toString();
     }
-
+    else if(radioRMP->isChecked())
+    {
+        projection = "+init=epsg:4326";
+    }
 
     CMapExportStateReproject * state4 = new CMapExportStateReproject(projection, this);
     foreach(const QString& srcFile, srcFiles)
@@ -678,7 +763,6 @@ void CMapQMAPExport::startExportCommon(QStringList& srcFiles, QDir& tarPath, con
     }
     states << state4;
 
-
     if(radioQLM->isChecked())
     {
         // *********************************************
@@ -733,7 +817,6 @@ void CMapQMAPExport::startExportCommon(QStringList& srcFiles, QDir& tarPath, con
             tileFile = file.fileName();
         }
 
-
         CMapExportStateGCM * state5 = new CMapExportStateGCM(path_map2gcm, this);
 
         CMapExportStateGCM::job_t job;
@@ -781,7 +864,7 @@ void CMapQMAPExport::startExportCommon(QStringList& srcFiles, QDir& tarPath, con
         states << state5;
     }
 
-    if(radioRMAP->isChecked())
+    else if(radioRMAP->isChecked())
     {
         // *********************************************
         // 5. step: add overview levels
@@ -800,7 +883,6 @@ void CMapQMAPExport::startExportCommon(QStringList& srcFiles, QDir& tarPath, con
         }
         states << state5;
 
-
         // *********************************************
         // 5. step: convert Geotiff to TwoNav RMAP
         // ---------------------------------------------
@@ -822,9 +904,36 @@ void CMapQMAPExport::startExportCommon(QStringList& srcFiles, QDir& tarPath, con
         states << state6;
 
     }
+    else if(radioRMP->isChecked())
+    {
+        // *********************************************
+        // 5. step: convert Geotiff to Garmin JNX Map
+        // ---------------------------------------------
+        CMapExportStateRMP * state5 = new CMapExportStateRMP(path_map2rmp, this);
+
+        CMapExportStateRMP::job_t job;
+
+        job.jpegQuality = QString::number(spinJpegQuality->value());
+        job.jpegSubSmpl = comboJpegSubsampling->currentText();
+        job.provider    = lineMagellanProvider->text();
+        job.product     = lineMagellanProduct->text();
+        job.copyright   = copyright;
+
+        foreach(const CMapExportStateReproject::job_t& j, state4->getJobs())
+        {
+            job.srcFile << j.tarFile;
+
+        }
+        job.tarFile     = tarPath.filePath(QString("%1.rmp").arg(prefix));
+
+        state5->addJob(job);
+        states << state5;
+    }
+
 
 }
 
+
 void CMapQMAPExport::setNextState()
 {
     output.clear();
@@ -853,6 +962,7 @@ void CMapQMAPExport::setNextState()
     }
 }
 
+
 void CMapQMAPExport::slotFinished(int exitCode, QProcess::ExitStatus status)
 {
     output.clear();
@@ -879,6 +989,7 @@ void CMapQMAPExport::slotFinished(int exitCode, QProcess::ExitStatus status)
     labelJob->setText(tr("Job %1/%2 - ").arg(state->getJobIdx()).arg(state->getJobCnt()));
 }
 
+
 void CMapQMAPExport::slotOutputPath()
 {
     QString path = QFileDialog::getExistingDirectory(this, tr("Select output path..."), labelPath->text(), FILE_DIALOG_FLAGS);
@@ -887,7 +998,6 @@ void CMapQMAPExport::slotOutputPath()
 }
 
 
-
 // --------------------------------------------------------------------------------------------
 
 quint32 IMapExportState::tmpFileCnt = 0;
@@ -900,11 +1010,13 @@ IMapExportState::IMapExportState(CMapQMAPExport * parent)
 
 }
 
+
 IMapExportState::~IMapExportState()
 {
 
 }
 
+
 QString IMapExportState::getTempFilename()
 {
     QTemporaryFile * tmp = new QTemporaryFile(QDir::temp().absoluteFilePath(QString("qlgt_%1.XXXXXX.tif").arg(tmpFileCnt++)));
@@ -916,6 +1028,7 @@ QString IMapExportState::getTempFilename()
     return fn;
 }
 
+
 // --------------------------------------------------------------------------------------------
 CMapExportStateCutFiles::CMapExportStateCutFiles(CMapQMAPExport * parent)
 : IMapExportState(parent)
@@ -923,11 +1036,13 @@ CMapExportStateCutFiles::CMapExportStateCutFiles(CMapQMAPExport * parent)
 {
 }
 
+
 CMapExportStateCutFiles::~CMapExportStateCutFiles()
 {
     qDebug() << "~CMapExportStateCutFiles()";
 }
 
+
 void CMapExportStateCutFiles::explain()
 {
     gui->stdOut(   "*************************************");
@@ -935,6 +1050,7 @@ void CMapExportStateCutFiles::explain()
     gui->stdOut(   "-------------------------------------");
 }
 
+
 void CMapExportStateCutFiles::nextJob(QProcess& cmd)
 {
     if(jobIdx < jobs.count())
@@ -973,6 +1089,7 @@ void CMapExportStateCutFiles::nextJob(QProcess& cmd)
     }
 }
 
+
 // --------------------------------------------------------------------------------------------
 CMapExportStateCombineFiles::CMapExportStateCombineFiles(CMapQMAPExport * parent)
 : IMapExportState(parent)
@@ -981,6 +1098,7 @@ CMapExportStateCombineFiles::CMapExportStateCombineFiles(CMapQMAPExport * parent
 
 }
 
+
 CMapExportStateCombineFiles::~CMapExportStateCombineFiles()
 {
     qDebug() << "~CMapExportStateCombineFiles()";
@@ -994,6 +1112,7 @@ CMapExportStateCombineFiles::~CMapExportStateCombineFiles()
     }
 }
 
+
 void CMapExportStateCombineFiles::explain()
 {
     gui->stdOut(   "*************************************");
@@ -1001,6 +1120,7 @@ void CMapExportStateCombineFiles::explain()
     gui->stdOut(   "-------------------------------------");
 }
 
+
 void CMapExportStateCombineFiles::nextJob(QProcess& cmd)
 {
     if(jobIdx < jobs.count())
@@ -1033,6 +1153,7 @@ void CMapExportStateCombineFiles::nextJob(QProcess& cmd)
     }
 }
 
+
 // --------------------------------------------------------------------------------------------
 CMapExportStateConvColor::CMapExportStateConvColor(CMapQMAPExport * parent)
 : IMapExportState(parent)
@@ -1041,6 +1162,7 @@ CMapExportStateConvColor::CMapExportStateConvColor(CMapQMAPExport * parent)
 
 }
 
+
 CMapExportStateConvColor::~CMapExportStateConvColor()
 {
     qDebug() << "~CMapExportStateConvColor()";
@@ -1052,6 +1174,7 @@ CMapExportStateConvColor::~CMapExportStateConvColor()
 
 }
 
+
 void CMapExportStateConvColor::explain()
 {
     gui->stdOut(   "*************************************");
@@ -1059,6 +1182,7 @@ void CMapExportStateConvColor::explain()
     gui->stdOut(   "-------------------------------------");
 }
 
+
 void CMapExportStateConvColor::nextJob(QProcess& cmd)
 {
     if(jobIdx < jobs.count())
@@ -1088,6 +1212,7 @@ void CMapExportStateConvColor::nextJob(QProcess& cmd)
     }
 }
 
+
 // --------------------------------------------------------------------------------------------
 CMapExportStateReproject::CMapExportStateReproject(const QString& proj, CMapQMAPExport * parent)
 : IMapExportState(parent)
@@ -1097,6 +1222,7 @@ CMapExportStateReproject::CMapExportStateReproject(const QString& proj, CMapQMAP
 
 }
 
+
 CMapExportStateReproject::~CMapExportStateReproject()
 {
     qDebug() << "~CMapExportStateReproject()";
@@ -1108,6 +1234,7 @@ CMapExportStateReproject::~CMapExportStateReproject()
 
 }
 
+
 void CMapExportStateReproject::explain()
 {
     gui->stdOut(   "*************************************");
@@ -1115,6 +1242,7 @@ void CMapExportStateReproject::explain()
     gui->stdOut(   "-------------------------------------");
 }
 
+
 void CMapExportStateReproject::nextJob(QProcess& cmd)
 {
     if(jobIdx < jobs.count())
@@ -1131,7 +1259,6 @@ void CMapExportStateReproject::nextJob(QProcess& cmd)
             return;
         }
 
-
         QString width, height;
         {
             CMapFile mapfile(job.srcFile, this);
@@ -1152,7 +1279,6 @@ void CMapExportStateReproject::nextJob(QProcess& cmd)
         gui->stdOut(GDALWARP " " +  args.join(" ") + "\n");
         cmd.start(GDALWARP, args);
 
-
     }
     else
     {
@@ -1160,6 +1286,7 @@ void CMapExportStateReproject::nextJob(QProcess& cmd)
     }
 }
 
+
 // --------------------------------------------------------------------------------------------
 CMapExportStateOptimize::CMapExportStateOptimize(CMapQMAPExport * parent)
 : IMapExportState(parent)
@@ -1168,11 +1295,13 @@ CMapExportStateOptimize::CMapExportStateOptimize(CMapQMAPExport * parent)
 
 }
 
+
 CMapExportStateOptimize::~CMapExportStateOptimize()
 {
     qDebug() << "~CMapExportStateOptimize()";
 }
 
+
 void CMapExportStateOptimize::explain()
 {
     gui->stdOut(   "*************************************");
@@ -1180,6 +1309,7 @@ void CMapExportStateOptimize::explain()
     gui->stdOut(   "-------------------------------------");
 }
 
+
 void CMapExportStateOptimize::nextJob(QProcess& cmd)
 {
     if(jobIdx < jobs.count())
@@ -1212,6 +1342,7 @@ void CMapExportStateOptimize::nextJob(QProcess& cmd)
     }
 }
 
+
 // --------------------------------------------------------------------------------------------
 CMapExportStateGCM::CMapExportStateGCM(const QString& app, CMapQMAPExport * parent)
 : IMapExportState(parent)
@@ -1221,6 +1352,7 @@ CMapExportStateGCM::CMapExportStateGCM(const QString& app, CMapQMAPExport * pare
 
 }
 
+
 CMapExportStateGCM::~CMapExportStateGCM()
 {
     qDebug() << "~CMapExportStateGCM()";
@@ -1235,6 +1367,7 @@ CMapExportStateGCM::~CMapExportStateGCM()
     }
 }
 
+
 void CMapExportStateGCM::explain()
 {
     gui->stdOut(   "*************************************");
@@ -1242,6 +1375,7 @@ void CMapExportStateGCM::explain()
     gui->stdOut(   "-------------------------------------");
 }
 
+
 void CMapExportStateGCM::nextJob(QProcess& cmd)
 {
     if(jobIdx < jobs.count())
@@ -1269,6 +1403,7 @@ void CMapExportStateGCM::nextJob(QProcess& cmd)
     }
 }
 
+
 // --------------------------------------------------------------------------------------------
 CMapExportStateJNX::CMapExportStateJNX(const QString& app, CMapQMAPExport * parent)
 : IMapExportState(parent)
@@ -1278,6 +1413,7 @@ CMapExportStateJNX::CMapExportStateJNX(const QString& app, CMapQMAPExport * pare
 
 }
 
+
 CMapExportStateJNX::~CMapExportStateJNX()
 {
     qDebug() << "~CMapExportStateJNX()";
@@ -1291,6 +1427,7 @@ CMapExportStateJNX::~CMapExportStateJNX()
     }
 }
 
+
 void CMapExportStateJNX::explain()
 {
     gui->stdOut(   "*************************************");
@@ -1298,6 +1435,7 @@ void CMapExportStateJNX::explain()
     gui->stdOut(   "-------------------------------------");
 }
 
+
 void CMapExportStateJNX::nextJob(QProcess& cmd)
 {
     if(jobIdx < jobs.count())
@@ -1326,6 +1464,7 @@ void CMapExportStateJNX::nextJob(QProcess& cmd)
     }
 }
 
+
 // --------------------------------------------------------------------------------------------
 CMapExportStateReadTileCache::CMapExportStateReadTileCache(const QString& app, CMapQMAPExport * parent)
 : IMapExportState(parent)
@@ -1334,12 +1473,14 @@ CMapExportStateReadTileCache::CMapExportStateReadTileCache(const QString& app, C
 
 }
 
+
 CMapExportStateReadTileCache::~CMapExportStateReadTileCache()
 {
     qDebug() << "~CMapExportStateReadTileCache()";
 
 }
 
+
 void CMapExportStateReadTileCache::explain()
 {
     gui->stdOut(   "*************************************");
@@ -1347,6 +1488,7 @@ void CMapExportStateReadTileCache::explain()
     gui->stdOut(   "-------------------------------------");
 }
 
+
 void CMapExportStateReadTileCache::nextJob(QProcess& cmd)
 {
     if(jobIdx < jobs.count())
@@ -1355,10 +1497,10 @@ void CMapExportStateReadTileCache::nextJob(QProcess& cmd)
 
         QStringList args;
         args << "-a" << QString::number(job.level)
-             << QString::number(job.lon1, 'f')
-             << QString::number(job.lat1, 'f')
-             << QString::number(job.lon2, 'f')
-             << QString::number(job.lat2, 'f');
+            << QString::number(job.lon1, 'f', 12)
+            << QString::number(job.lat1, 'f', 12)
+            << QString::number(job.lon2, 'f', 12)
+            << QString::number(job.lat2, 'f', 12);
         args << "-c" << CResources::self().getPathMapCache().absolutePath();
         args << "-i" << job.srcFile;
         args << "-o" << job.tarFile;
@@ -1384,6 +1526,7 @@ CMapExportStateRMAP::CMapExportStateRMAP(const QString& app, CMapQMAPExport * pa
 
 }
 
+
 CMapExportStateRMAP::~CMapExportStateRMAP()
 {
     qDebug() << "~CMapExportStateRMAP()";
@@ -1397,6 +1540,7 @@ CMapExportStateRMAP::~CMapExportStateRMAP()
     }
 }
 
+
 void CMapExportStateRMAP::explain()
 {
     gui->stdOut(   "*************************************");
@@ -1404,6 +1548,7 @@ void CMapExportStateRMAP::explain()
     gui->stdOut(   "-------------------------------------");
 }
 
+
 void CMapExportStateRMAP::nextJob(QProcess& cmd)
 {
     if(jobIdx < jobs.count())
@@ -1426,3 +1571,64 @@ void CMapExportStateRMAP::nextJob(QProcess& cmd)
         gui->setNextState();
     }
 }
+
+// --------------------------------------------------------------------------------------------
+CMapExportStateRMP::CMapExportStateRMP(const QString& app, CMapQMAPExport * parent)
+: IMapExportState(parent)
+
+, app(app)
+{
+
+}
+
+
+CMapExportStateRMP::~CMapExportStateRMP()
+{
+    qDebug() << "~CMapExportStateRMP()";
+
+    foreach(const job_t& job, jobs)
+    {
+        foreach(const QString& file, job.srcFile)
+        {
+            QFile::remove(file);
+        }
+    }
+}
+
+
+void CMapExportStateRMP::explain()
+{
+    gui->stdOut(   "*************************************");
+    gui->stdOut(tr("Create Magellan RMP Map..."), true);
+    gui->stdOut(   "-------------------------------------");
+}
+
+
+void CMapExportStateRMP::nextJob(QProcess& cmd)
+{
+    if(jobIdx < jobs.count())
+    {
+        job_t& job = jobs[jobIdx];
+
+        QStringList args;
+        args << "-q" << job.jpegQuality;
+        args << "-s" << job.jpegSubSmpl;
+        args << "-p" << job.provider;
+        args << "-n" << job.product;
+        if(!job.copyright.isEmpty())
+        {
+            args << "-c" << job.copyright;
+        }
+        args += job.srcFile;
+        args << job.tarFile;
+
+        jobIdx++;
+
+        gui->stdOut(app + " " +  args.join(" ") + "\n");
+        cmd.start(app, args);
+    }
+    else
+    {
+        gui->setNextState();
+    }
+}
