@@ -22,7 +22,6 @@
 #include "CCanvas.h"
 #include "CSettings.h"
 
-
 #include <QtGui>
 
 CMapRmap::CMapRmap(const QString &key, const QString &fn, CCanvas *parent)
@@ -81,7 +80,6 @@ CMapRmap::CMapRmap(const QString &key, const QString &fn, CCanvas *parent)
         levels << level;
     }
 
-
     for(int i=0; i<levels.size(); i++)
     {
         level_t& level = levels[i];
@@ -100,7 +98,6 @@ CMapRmap::CMapRmap(const QString &key, const QString &fn, CCanvas *parent)
         }
     }
 
-
     file.seek(mapDataOffset);
     stream >> tmp32 >> tmp32;
 
@@ -228,7 +225,7 @@ CMapRmap::CMapRmap(const QString &key, const QString &fn, CCanvas *parent)
         }
         else
         {
-//            qDebug() << line;
+            //            qDebug() << line;
         }
         qDebug() << line;
     }
@@ -321,12 +318,17 @@ CMapRmap::CMapRmap(const QString &key, const QString &fn, CCanvas *parent)
     cfg.endGroup();
     cfg.endGroup();
 
-
     zoom(zoomidx);
 }
 
+
 CMapRmap::~CMapRmap()
 {
+
+    midU = rect.center().x();
+    midV = rect.center().y();
+    convertPt2Rad(midU, midV);
+
     if(pjsrc) pj_free(pjsrc);
 
     SETTINGS;
@@ -342,6 +344,7 @@ CMapRmap::~CMapRmap()
 
 }
 
+
 bool CMapRmap::setProjection(const QString& projection, const QString& datum)
 {
 
@@ -372,7 +375,6 @@ bool CMapRmap::setProjection(const QString& projection, const QString& datum)
         projstr += "+proj=tmerc +lat_0=0 +lon_0=9  +k=1 +x_0=3500000 +y_0=0";
     }
 
-
     if(datum == "WGS 84")
     {
         projstr += " +datum=WGS84 +units=m +no_defs";
@@ -391,7 +393,6 @@ bool CMapRmap::setProjection(const QString& projection, const QString& datum)
     char * ptr = pj_get_def(pjsrc,0);
     qDebug() << "rmap:" << ptr;
 
-
     return true;
 }
 
@@ -402,6 +403,7 @@ void CMapRmap::convertPt2M(double& u, double& v)
     v = y + v * yscale * zoomFactor;
 }
 
+
 void CMapRmap::convertM2Pt(double& u, double& v)
 {
     u = floor((u - x) / (xscale * zoomFactor) + 0.5);
@@ -430,6 +432,7 @@ void CMapRmap::move(const QPoint& old, const QPoint& next)
     setAngleNorth();
 }
 
+
 void CMapRmap::zoom(bool zoomIn, const QPoint& p0)
 {
     qDebug() << "zoom" << zoomIn;
@@ -484,6 +487,7 @@ void CMapRmap::zoom(bool zoomIn, const QPoint& p0)
     emit sigChanged();
 }
 
+
 void CMapRmap::zoom(double lon1, double lat1, double lon2, double lat2)
 {
     if(pjsrc == 0) return;
@@ -529,6 +533,7 @@ void CMapRmap::zoom(double lon1, double lat1, double lon2, double lat2)
     qDebug() << "zoom:" << zoomFactor;
 }
 
+
 void CMapRmap::zoom(qint32& level)
 {
     if(pjsrc == 0) return;
@@ -547,6 +552,7 @@ void CMapRmap::zoom(qint32& level)
     qDebug() << "zoom:" << zoomFactor;
 }
 
+
 void CMapRmap::dimensions(double& lon1, double& lat1, double& lon2, double& lat2)
 {
     if(pjsrc == 0) return;
@@ -561,6 +567,7 @@ void CMapRmap::dimensions(double& lon1, double& lat1, double& lon2, double& lat2
 
 }
 
+
 void CMapRmap::getArea_n_Scaling(projXY& p1, projXY& p2, float& my_xscale, float& my_yscale)
 {
     if(pjsrc == 0) return;
@@ -577,6 +584,7 @@ void CMapRmap::getArea_n_Scaling(projXY& p1, projXY& p2, float& my_xscale, float
     my_yscale   = yscale * zoomFactor;
 }
 
+
 CMapRmap::level_t& CMapRmap::findBestLevel(double sx, double sy)
 {
     int i = levels.size() - 1;
@@ -598,6 +606,7 @@ CMapRmap::level_t& CMapRmap::findBestLevel(double sx, double sy)
     return levels[i];
 }
 
+
 void CMapRmap::draw(QPainter& p)
 {
     if(pjsrc == 0) return IMap::draw(p);
@@ -649,6 +658,7 @@ void CMapRmap::draw(QPainter& p)
     }
 }
 
+
 void CMapRmap::draw()
 {
     pixBuffer.fill(Qt::white);
@@ -712,4 +722,3 @@ void CMapRmap::draw()
         }
     }
 }
-
