@@ -27,7 +27,6 @@
 #include "CMapDB.h"
 #include "IMap.h"
 
-
 CMapSelectionRaster::CMapSelectionRaster(subtype_e subtype, QObject * parent)
 : IMapSelection(eRaster, subtype, parent)
 {
@@ -42,6 +41,7 @@ CMapSelectionRaster::~CMapSelectionRaster()
 
 }
 
+
 QDataStream& CMapSelectionRaster::operator>>(QDataStream& s)
 {
     QList<sel_head_entry_t> entries;
@@ -61,10 +61,10 @@ QDataStream& CMapSelectionRaster::operator>>(QDataStream& s)
     s1 << name;
     s1 << comment;
     s1 << description;
-    s1 << lon1;             ///< top left longitude [rad]
-    s1 << lat1;             ///< top left latitude [rad]
-    s1 << lon2;             ///< bottom right longitude [rad]
-    s1 << lat2;             ///< bottom right latitude [rad]
+    s1 << lon1;                  ///< top left longitude [rad]
+    s1 << lat1;                  ///< top left latitude [rad]
+    s1 << lon2;                  ///< bottom right longitude [rad]
+    s1 << lat2;                  ///< bottom right latitude [rad]
     s1 << subtype;
 
     entries << entryBase;
@@ -156,7 +156,7 @@ void CMapSelectionRaster::draw(QPainter& p, const QRect& rect)
     if(rect.intersects(r))
     {
 
-        quint32 gridspace = map.scalePixelGrid(1024);
+        qint32 gridspace = map.scalePixelGrid(1024);
 
         if(gridspace != 0)
         {
@@ -199,6 +199,7 @@ void CMapSelectionRaster::draw(QPainter& p, const QRect& rect)
     }
 }
 
+
 QString CMapSelectionRaster::getDescription() const
 {
     QString pos1, pos2, str;
@@ -216,7 +217,6 @@ QString CMapSelectionRaster::getDescription() const
 
     distance(p1, p2, a1, a2) / 1000.0;
 
-
     p1.u = lon1;
     p1.v = lat1;
 
@@ -236,4 +236,3 @@ QString CMapSelectionRaster::getDescription() const
     return str;
 
 }
-
