@@ -138,6 +138,11 @@ void CMapToolWidget::slotDBChanged()
                     icon = QIcon(":/icons/iconRMAP22x22.png");
                     item->setToolTip(eType, tr("TwoNav/RMAP"));
                 }
+                else if(map->filename.toLower().endsWith("rmp"))
+                {
+                    icon = QIcon(":/icons/iconRMP22x22.png");
+                    item->setToolTip(eType, tr("Magellan/RMP"));
+                }
                 else
                 {
                     icon = QIcon(":/icons/iconQMAP22x22.png");
@@ -198,7 +203,6 @@ void CMapToolWidget::slotDBChanged()
     treeKnownMapsVector->sortItems(eName, Qt::AscendingOrder);
     treeKnownMapsRaster->sortItems(eName, Qt::AscendingOrder);
 
-
     if(selected)
     {
         if(selected->data(eType, Qt::UserRole) == IMap::eGarmin)
@@ -490,7 +494,7 @@ void CMapToolWidget::slotAddDEM()
     SETTINGS;
     path = QDir(cfg.value("path/DEM",path.path()).toString());
 
-    QString filename = QFileDialog::getOpenFileName(0, tr("Select DEM file..."),path.path(), tr("16bit Srtm Data (*.tif *.tiff *.hgt)"), 0, FILE_DIALOG_FLAGS);
+    QString filename = QFileDialog::getOpenFileName(0, tr("Select DEM file..."),path.path(), tr("16bit Srtm Data (*.tif *.tiff *.hgt *.blx)"), 0, FILE_DIALOG_FLAGS);
     if(filename.isEmpty()) return;
 
     QFileInfo fi(filename);
@@ -519,12 +523,14 @@ void CMapToolWidget::slotCfgMap()
     CMapDB::self().getMap().config();
 }
 
+
 void CMapToolWidget::slotAddTmsMap()
 {
     CDlgMapTmsConfig dlg;
     dlg.exec();
 }
 
+
 void CMapToolWidget::slotReload()
 {
     CMapDB::self().reloadMap();
