@@ -30,7 +30,6 @@
 #include <QtXml>
 #include <QtNetwork>
 
-
 CMapWms::CMapWms(const QString &key, const QString &filename, CCanvas *parent)
 : IMap(eWMS,key,parent)
 , xsize_px(0)
@@ -103,7 +102,6 @@ CMapWms::CMapWms(const QString &key, const QString &filename, CCanvas *parent)
         projection = srs;
     }
 
-
     projection = projection.toLower();
     if(projection.startsWith("epsg"))
     {
@@ -117,7 +115,6 @@ CMapWms::CMapWms(const QString &key, const QString &filename, CCanvas *parent)
         qDebug() << "wms:" << projection.toLocal8Bit();
     }
 
-
     if(pjsrc == 0)
     {
         QMessageBox::critical(parent, tr("Error..."), tr("Unknown projection %1").arg(projection.toAscii().data()), QMessageBox::Abort, QMessageBox::Abort);
@@ -156,7 +153,10 @@ CMapWms::CMapWms(const QString &key, const QString &filename, CCanvas *parent)
 
     accessManager = new QNetworkAccessManager(this);
     accessManager->setProxy(QNetworkProxy(QNetworkProxy::DefaultProxy));
+
     connect(accessManager,SIGNAL(finished(QNetworkReply*)),this,SLOT(slotRequestFinished(QNetworkReply*)));
+    connect(accessManager, SIGNAL(proxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)),
+        this, SLOT(slotProxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)));
 
     diskCache = new CDiskCache(false, this);
 
@@ -174,8 +174,14 @@ CMapWms::CMapWms(const QString &key, const QString &filename, CCanvas *parent)
 
 }
 
+
 CMapWms::~CMapWms()
 {
+
+    midU = rect.center().x();
+    midV = rect.center().y();
+    convertPt2Rad(midU, midV);
+
     if(pjsrc) pj_free(pjsrc);
 
     delete status;
@@ -192,18 +198,35 @@ CMapWms::~CMapWms()
 
 }
 
+
+void CMapWms::convertPixel2M(double& u, double& v)
+{
+    u = xref1 + u * xscale;
+    v = yref1 + v * yscale;
+}
+
+
+void CMapWms::convertM2Pixel(double& u, double& v)
+{
+    u = (u - xref1) / (xscale);
+    v = (v - yref1) / (yscale);
+}
+
+
 void CMapWms::convertPt2M(double& u, double& v)
 {
     u = x + u * xscale * zoomFactor;
     v = y + v * yscale * zoomFactor;
 }
 
+
 void CMapWms::convertM2Pt(double& u, double& v)
 {
     u = floor((u - x) / (xscale * zoomFactor) + 0.5);
     v = floor((v - y) / (yscale * zoomFactor) + 0.5);
 }
 
+
 void CMapWms::convertPt2Pixel(double& u, double& v)
 {
     convertPt2M(u,v);
@@ -248,6 +271,7 @@ void CMapWms::move(const QPoint& old, const QPoint& next)
     setAngleNorth();
 }
 
+
 void CMapWms::zoom(bool zoomIn, const QPoint& p0)
 {
     qDebug() << "zoom" << zoomIn;
@@ -303,6 +327,7 @@ void CMapWms::zoom(bool zoomIn, const QPoint& p0)
     emit sigChanged();
 }
 
+
 void CMapWms::zoom(double lon1, double lat1, double lon2, double lat2)
 {
     if(pjsrc == 0) return;
@@ -348,6 +373,7 @@ void CMapWms::zoom(double lon1, double lat1, double lon2, double lat2)
     qDebug() << "zoom:" << zoomFactor;
 }
 
+
 void CMapWms::zoom(qint32& level)
 {
     if(pjsrc == 0) return;
@@ -371,6 +397,7 @@ void CMapWms::zoom(qint32& level)
     qDebug() << "zoom:" << zoomFactor;
 }
 
+
 void CMapWms::dimensions(double& lon1, double& lat1, double& lon2, double& lat2)
 {
     if(pjsrc == 0) return;
@@ -384,6 +411,7 @@ void CMapWms::dimensions(double& lon1, double& lat1, double& lon2, double& lat2)
     pj_transform(pjsrc,pjtar,1,0,&lon2,&lat2,0);
 }
 
+
 void CMapWms::getArea_n_Scaling(projXY& p1, projXY& p2, float& my_xscale, float& my_yscale)
 {
     if(pjsrc == 0) return;
@@ -401,6 +429,7 @@ void CMapWms::getArea_n_Scaling(projXY& p1, projXY& p2, float& my_xscale, float&
 
 }
 
+
 void CMapWms::draw(QPainter& p)
 {
     if(pjsrc == 0) return IMap::draw(p);
@@ -472,27 +501,22 @@ void CMapWms::draw()
     pixBuffer.fill(Qt::white);
     QPainter p(&pixBuffer);
 
+    // convert top/left corner to abs. pixel in map
     double x1 = 0;
     double y1 = 0;
     convertPt2M(x1, y1);
+    convertM2Pixel(x1, y1);
 
-    // convert to abs pixel in map
-    x1 = (x1 - xref1) / (xscale);
-    y1 = (y1 - yref1) / (yscale);
+    // convert bottom/right corner to abs. pixel in map
+    double x2 = rect.width();
+    double y2 = rect.height();
+    convertPt2M(x2, y2);
+    convertM2Pixel(x2, y2);
 
     // quantify to smalles multiple of blocksize
     x1 = floor(x1/(blockSizeX * zoomFactor)) * blockSizeX * zoomFactor;
     y1 = floor(y1/(blockSizeY * zoomFactor)) * blockSizeY * zoomFactor;
 
-    // convert back to meter/rad
-    x1 = x1*xscale + xref1;
-    y1 = y1*yscale + yref1;
-
-    // convert ref1 to point on screen
-    double xx1 = x1;
-    double yy1 = y1;
-    convertM2Pt(xx1, yy1);
-
     int n = 0;
     int m = 0;
 
@@ -503,16 +527,16 @@ void CMapWms::draw()
     {
         do
         {
-            double p1x = xx1 + n * blockSizeX;
-            double p1y = yy1 + m * blockSizeY;
-            double p2x = xx1 + (n + 1) * blockSizeX;
-            double p2y = yy1 + (m + 1) * blockSizeY;
+            double p1x = x1 + n * blockSizeX * zoomFactor;
+            double p1y = y1 + m * blockSizeY * zoomFactor;
+            double p2x = x1 + (n + 1) * blockSizeX * zoomFactor;
+            double p2y = y1 + (m + 1) * blockSizeY * zoomFactor;
 
             cx = p2x;
             cy = p2y;
 
-            convertPt2M(p1x, p1y);
-            convertPt2M(p2x, p2y);
+            convertPixel2M(p1x, p1y);
+            convertPixel2M(p2x, p2y);
 
             QUrl url(urlstr);
             url.addQueryItem("request", "GetMap");
@@ -540,8 +564,6 @@ void CMapWms::draw()
             req.zoomFactor  = zoomFactor;
             convertM2Rad(req.lon,req.lat);
 
-//            qDebug() << url;
-
             diskCache->restore(url.toString(), img);
             if(!img.isNull())
             {
@@ -555,16 +577,17 @@ void CMapWms::draw()
 
             n++;
         }
-        while(cx < rect.width());
+        while(cx < x2);
 
         n = 0;
         m++;
     }
-    while(cy < rect.height());
+    while(cy < y2);
 
     checkQueue();
 }
 
+
 void CMapWms::addToQueue(request_t& req)
 {
     if(!seenRequest.contains(req.url.toString()))
@@ -574,6 +597,7 @@ void CMapWms::addToQueue(request_t& req)
     }
 }
 
+
 void CMapWms::checkQueue()
 {
     while(newRequests.size() && pendRequests.size() < 6)
@@ -604,13 +628,12 @@ void CMapWms::checkQueue()
         status->setText(tr("Wait for %1 tiles.").arg(pendRequests.size() + newRequests.size()));
     }
 
-
 }
 
+
 void CMapWms::slotRequestFinished(QNetworkReply* reply)
 {
 
-
     QString _url_ = reply->url().toString();
     if(pendRequests.contains(_url_))
     {
@@ -672,6 +695,19 @@ void CMapWms::slotRequestFinished(QNetworkReply* reply)
     emit sigChanged();
 }
 
+
+void CMapWms::slotProxyAuthenticationRequired(const QNetworkProxy &prox, QAuthenticator *auth)
+{
+    QString user;
+    QString pwd;
+
+    CResources::self().getHttpProxyAuth(user,pwd);
+
+    auth->setUser(user);
+    auth->setPassword(pwd);
+}
+
+
 void CMapWms::config()
 {
     CDlgMapWmsConfig dlg(*this);
@@ -684,6 +720,7 @@ quint32 CMapWms::scalePixelGrid(quint32 nPixel)
     return double(nPixel) / zoomFactor;
 }
 
+
 void CMapWms::select(IMapSelection& ms, const QRect& rect)
 {
     if(ms.type != IMapSelection::eRaster) return;
