@@ -86,7 +86,7 @@ void CMouseMoveMap::mousePressEvent(QMouseEvent * e)
         }
         else if(track && selTrkPt)
         {
-            track->setPointOfFocus(selTrkPt->idx, true, false);
+            track->setPointOfFocus(selTrkPt->idx, CTrack::e3Way, false);
         }
         else if(!selSearch.isNull())
         {
@@ -133,6 +133,7 @@ void CMouseMoveMap::mouseReleaseEvent(QMouseEvent * e)
     }
 }
 
+
 void CMouseMoveMap::keyPressEvent(QKeyEvent * e)
 {
 #ifdef ALTKEY_MOVES_MAP
@@ -151,6 +152,7 @@ void CMouseMoveMap::keyPressEvent(QKeyEvent * e)
 #endif
 }
 
+
 void CMouseMoveMap::mouseDoubleClickEvent(QMouseEvent * e)
 {
     if(!selWpt.isNull())
@@ -160,6 +162,7 @@ void CMouseMoveMap::mouseDoubleClickEvent(QMouseEvent * e)
     }
 }
 
+
 void CMouseMoveMap::keyReleaseEvent(QKeyEvent * e)
 {
 #ifdef ALTKEY_MOVES_MAP
@@ -179,6 +182,7 @@ void CMouseMoveMap::keyReleaseEvent(QKeyEvent * e)
 #endif
 }
 
+
 void CMouseMoveMap::draw(QPainter& p)
 {
     drawPos1(p);
@@ -218,7 +222,8 @@ void CMouseMoveMap::contextMenu(QMenu& menu)
     if(selTrkPt)
     {
         menu.addSeparator();
-        menu.addAction(QPixmap(":/icons/iconGoogleMaps16x16.png"),tr("Open Pos. with Google Maps"),this,SLOT(slotOpenGoogleMaps())); //TODO: Google Maps right click
+                                 //TODO: Google Maps right click
+        menu.addAction(QPixmap(":/icons/iconGoogleMaps16x16.png"),tr("Open Pos. with Google Maps"),this,SLOT(slotOpenGoogleMaps()));
         menu.addAction(QPixmap(":/icons/iconClipboard16x16.png"),tr("Copy Pos. Trackpoint"),this,SLOT(slotCopyPositionTrack()));
         menu.addAction(QPixmap(":/icons/iconEdit16x16.png"),tr("Edit Track ..."),this,SLOT(slotEditTrack()));
         menu.addAction(QPixmap(":/icons/iconEditCut16x16.png"),tr("Split Track ..."),this,SLOT(slotSplitTrack()));
@@ -240,11 +245,10 @@ void CMouseMoveMap::contextMenu(QMenu& menu)
     }
     else
     {
-        QString posMeter = tr("Grid: N %1m E %2m").arg(u, 0,'f',0).arg(v,0,'f',0);
+        QString posMeter = tr("Grid: N %1m E %2m").arg(v, 0,'f',0).arg(u,0,'f',0);
         menu.addAction(QIcon(":/icons/iconClipboard16x16.png"), posMeter, this, SLOT(slotCopyPosGrid()));
     }
 
-
     IMap& map = CMapDB::self().getMap();
     u = mousePos.x();
     v = mousePos.y();
@@ -252,7 +256,7 @@ void CMouseMoveMap::contextMenu(QMenu& menu)
     map.convertPt2M(u,v);
     if(!map.isLonLat())
     {
-        QString posMeter = tr("Map: N %1m E %2m").arg(u, 0,'f',0).arg(v,0,'f',0);
+        QString posMeter = tr("Map: N %1m E %2m").arg(v, 0,'f',0).arg(u,0,'f',0);
         menu.addAction(QIcon(":/icons/iconClipboard16x16.png"), posMeter, this, SLOT(slotCopyPosMeter()));
     }
 
@@ -267,12 +271,10 @@ void CMouseMoveMap::contextMenu(QMenu& menu)
     v = mousePos.y();
     map.convertPt2Pixel(u,v);
 
-
     if(u >= 0 && v >= 0)
     {
         QString fn = QFileInfo(map.getFilename(mousePos.x(), mousePos.y())).fileName();
 
-
         QString posPixel = tr("Pixel %1x%2 (%3)").arg(u, 0,'f',0).arg(v,0,'f',0).arg(fn);
         menu.addAction(QIcon(":/icons/iconClipboard16x16.png"), posPixel, this, SLOT(slotCopyPosPixel()));
 
@@ -288,8 +290,6 @@ void CMouseMoveMap::contextMenu(QMenu& menu)
             menu.addAction(QIcon(":/icons/iconClipboard16x16.png"), posPixelSize, this, SLOT(slotCopyPosPixelSize()));
         }
 
-
-
     }
 
 }
@@ -312,6 +312,7 @@ void CMouseMoveMap::slotCopyPosDegree()
 
 }
 
+
 void CMouseMoveMap::slotCopyPosGrid()
 {
     QString position;
@@ -334,6 +335,7 @@ void CMouseMoveMap::slotCopyPosGrid()
     clipboard->setText(position);
 }
 
+
 void CMouseMoveMap::slotCopyPosMeter()
 {
     IMap& map = CMapDB::self().getMap();
@@ -347,6 +349,7 @@ void CMouseMoveMap::slotCopyPosMeter()
     clipboard->setText(position);
 }
 
+
 void CMouseMoveMap::slotCopyPosPixel()
 {
     IMap& map = CMapDB::self().getMap();
@@ -362,6 +365,7 @@ void CMouseMoveMap::slotCopyPosPixel()
 
 }
 
+
 void CMouseMoveMap::slotCopyPosPixelSize()
 {
     IMap& map = CMapDB::self().getMap();
@@ -462,14 +466,15 @@ void CMouseMoveMap::slotEditTrack()
 
     CTrackToolWidget * toolview = CTrackDB::self().getToolWidget();
     if(toolview) toolview->slotEdit();
-
-    CTrack * track = CTrackDB::self().highlightedTrack();
-    if(track)
-    {
-        track->setPointOfFocus(selTrkPt->idx, true, false);
-    }
+///@todo oe investigate what this is for
+//    CTrack * track = CTrackDB::self().highlightedTrack();
+//    if(track)
+//    {
+//        track->setPointOfFocus(selTrkPt->idx, true, false);
+//    }
 }
 
+
 void CMouseMoveMap::slotSplitTrack()
 {
     if(selTrkPt)
@@ -478,12 +483,13 @@ void CMouseMoveMap::slotSplitTrack()
     }
 }
 
-void CMouseMoveMap::slotOpenGoogleMaps()	//TODO: Open Google Maps
+
+                                 //TODO: Open Google Maps
+void CMouseMoveMap::slotOpenGoogleMaps()
 {
     QString position;
     GPS_Math_Deg_To_Str(selTrkPt->lon, selTrkPt->lat, position);
 
-
     QDateTime utime = QDateTime::fromTime_t(selTrkPt->timestamp);
     utime.setTimeSpec(Qt::LocalTime);
     QString time = utime.toString();
@@ -491,6 +497,7 @@ void CMouseMoveMap::slotOpenGoogleMaps()	//TODO: Open Google Maps
     QDesktopServices::openUrl(QUrl("http://maps.google.com/maps?t=h&z=18&om=1&q="+position+"("+time+")", QUrl::TolerantMode));
 }
 
+
 void CMouseMoveMap::slotReloadMap()
 {
     CMapDB::self().reloadMap();
