@@ -43,7 +43,6 @@ class CMouseMoveMap : public IMouse
 
         void contextMenu(QMenu& menu);
 
-
     private slots:
         void slotEditWpt();
         void slotCopyPositionWpt();
@@ -53,7 +52,8 @@ class CMouseMoveMap : public IMouse
         void slotCopyPositionTrack();
         void slotEditTrack();
         void slotSplitTrack();
-        void slotOpenGoogleMaps();	//TODO: GOOGLE MAPS
+                                 //TODO: GOOGLE MAPS
+        void slotOpenGoogleMaps();
 
         void slotCopyPosDegree();
         void slotCopyPosGrid();
@@ -73,6 +73,5 @@ class CMouseMoveMap : public IMouse
         /// the initial starting point of the transformation
         QPoint oldPoint;
 
-
 };
 #endif                           //CMOUSEMOVEMAP_H
