@@ -24,7 +24,6 @@
 
 #include <QtGui>
 
-
 CMouseSelMap::CMouseSelMap(CCanvas * canvas)
 : IMouse(canvas)
 , selArea(false)
@@ -41,8 +40,6 @@ CMouseSelMap::~CMouseSelMap()
 }
 
 
-
-
 void CMouseSelMap::draw(QPainter& p)
 {
     drawSelMap(p);
@@ -57,16 +54,16 @@ void CMouseSelMap::drawSelMap(QPainter& p)
         return;
     }
 
-
     p.setPen(QPen(Qt::yellow,2));
     p.setBrush(Qt::NoBrush);
-    QRect r1 = selMap->rect();//u1, v1, u2 - u1, v2 - v1);
+    QRect r1 = selMap->rect();   //u1, v1, u2 - u1, v2 - v1);
     p.drawRect(r1);
 
     rectMoveMapSel.moveTopLeft(r1.center() - QPoint(32,32));
     p.drawPixmap(rectMoveMapSel.topLeft(), QPixmap(":/icons/iconMove64x64.png"));
 }
 
+
 void CMouseSelMap::drawSelArea(QPainter& p)
 {
     if(!selArea)
@@ -74,7 +71,7 @@ void CMouseSelMap::drawSelArea(QPainter& p)
         return;
     }
     IMap& map = CMapDB::self().getMap();
-    quint32 gridspace = selMap.isNull() ? map.scalePixelGrid(TILESIZE) : 0;
+    qint32 gridspace = selMap.isNull() ? map.scalePixelGrid(TILESIZE) : 0;
 
     p.setBrush(QColor(150,150,255,100));
     p.setPen(QPen(Qt::darkBlue,2));
@@ -124,6 +121,7 @@ void CMouseSelMap::drawSelArea(QPainter& p)
     }
 }
 
+
 void CMouseSelMap::mouseMoveEvent(QMouseEvent * e)
 {
     mousePos = e->pos();
@@ -154,7 +152,6 @@ void CMouseSelMap::mouseMoveEvent(QMouseEvent * e)
         moveMapSel = false;
     }
 
-
     if(selArea)
     {
         resizeRect(e->pos());
@@ -195,12 +192,14 @@ void CMouseSelMap::mousePressEvent(QMouseEvent * e)
     }
 }
 
+
 void CMouseSelMap::mousePressEventMapsel(QMouseEvent * e)
 {
     startRect(e->pos());
     selArea = true;
 }
 
+
 void CMouseSelMap::mouseReleaseEvent(QMouseEvent * e)
 {
     if(e->button() == Qt::LeftButton)
@@ -221,7 +220,7 @@ void CMouseSelMap::mouseReleaseEvent(QMouseEvent * e)
 
         // snap grid if parts are too small
         IMap& map = CMapDB::self().getMap();
-        quint32 gridspace = map.scalePixelGrid(TILESIZE);
+        qint32 gridspace = map.scalePixelGrid(TILESIZE);
 
         if(selMap.isNull())
         {
@@ -291,6 +290,7 @@ void CMouseSelMap::contextMenu(QMenu& menu)
     }
 }
 
+
 void CMouseSelMap::slotMapSelAll()
 {
     if(!selMap.isNull())
@@ -310,6 +310,7 @@ void CMouseSelMap::slotMapSelAll()
     }
 }
 
+
 void CMouseSelMap::slotMapSelNone()
 {
     if(!selMap.isNull())
