@@ -22,6 +22,8 @@
 
 #include "IMouse.h"
 
+#include <QPair>
+
 /// select a subarea of the map to export
 class CMouseSelMap : public IMouse
 {
@@ -35,8 +37,26 @@ class CMouseSelMap : public IMouse
         void mouseReleaseEvent(QMouseEvent * e);
 
         void draw(QPainter& p);
+
+        void contextMenu(QMenu& menu);
+    private slots:
+        void slotMapSelAll();
+        void slotMapSelNone();
+
     private:
-        bool selMap;
+        void drawSelArea(QPainter& p);
+        void drawSelMap(QPainter& p);
+
+        void mousePressEventMapsel(QMouseEvent * e);
+
+        bool selArea;
+        bool moveMapSel;
+
+        QPoint oldPoint;
+
+        QMap< QPair<int,int>, bool> selTiles;
+
+        QRect rectMoveMapSel;
 
 };
 #endif                           //CMOUSESELMAP_H
