@@ -40,7 +40,7 @@
 COverlayDB * COverlayDB::m_self = 0;
 
 COverlayDB::COverlayDB(QTabWidget * tb, QObject * parent)
-: IDB(tb,parent)
+: IDB(IDB::eTypeOvl, tb, parent)
 , addOverlaysAsDuplicate(false)
 {
     m_self      = this;
@@ -206,7 +206,7 @@ void COverlayDB::loadGPX(CGpx& gpx)
 
     if(hasItems)
     {
-        emit sigChanged();
+        emitSigChanged();
     }
 }
 
@@ -319,12 +319,11 @@ void COverlayDB::loadQLB(CQlb& qlb, bool newKey)
 
     if(qlb.overlays().size())
     {
-        emit sigChanged();
+        emitSigChanged();
     }
 }
 
 
-
 void COverlayDB::saveQLB(CQlb& qlb)
 {
     IOverlay * overlay;
@@ -337,6 +336,7 @@ void COverlayDB::saveQLB(CQlb& qlb)
 
 void COverlayDB::clear()
 {
+    if(overlays.isEmpty()) return;
     delOverlays(overlays.keys());
     IOverlay::resetKeyCnt();
 }
@@ -351,12 +351,13 @@ void COverlayDB::delOverlays(const QStringList& keys)
     }
     if(!keys.isEmpty())
     {
-        emit sigChanged();
-        emit sigModified();
+        emitSigChanged();
+        emitSigModified();
     }
 
 }
 
+
 void COverlayDB::delOverlay(const QString& key, bool silent)
 {
     if(overlays.contains(key))
@@ -366,12 +367,13 @@ void COverlayDB::delOverlay(const QString& key, bool silent)
 
         if(!silent)
         {
-            emit sigChanged();
-            emit sigModified();
+            emitSigChanged();
+            emitSigModified();
         }
     }
 }
 
+
 COverlayText * COverlayDB::addText(const QString& text, const QRect& rect, const QString& key, bool silent)
 {
     IOverlay * overlay = new COverlayText(text, rect, this);
@@ -396,7 +398,7 @@ COverlayText * COverlayDB::addText(const QString& text, const QRect& rect, const
 
     if(!silent)
     {
-        emit sigChanged();
+        emitSigChanged();
     }
 
     return qobject_cast<COverlayText*>(overlay);
@@ -427,7 +429,7 @@ COverlayTextBox * COverlayDB::addTextBox(const QString& text, double lon, double
 
     if(!silent)
     {
-        emit sigChanged();
+        emitSigChanged();
     }
 
     return qobject_cast<COverlayTextBox*>(overlay);
@@ -458,7 +460,7 @@ COverlayDistance * COverlayDB::addDistance(const QString& name, const QString& c
 
     if(!silent)
     {
-        emit sigChanged();
+        emitSigChanged();
     }
 
     return qobject_cast<COverlayDistance*>(overlay);
@@ -481,11 +483,9 @@ void COverlayDB::copyToClipboard(bool deleteSelection)
         return;
     }
 
-
     QClipboard *clipboard = QApplication::clipboard();
     CQlb qlb(this);
 
-
     COverlayDistance * dist = qobject_cast<COverlayDistance*>(ovl);
     if(dist && dist->selectedPoints.size() > 1)
     {
@@ -498,7 +498,6 @@ void COverlayDB::copyToClipboard(bool deleteSelection)
             pts << dist->points[idx];
         }
 
-
         COverlayDistance dist2("", "", dist->speed, pts, this);
 
         qlb << dist2;
@@ -520,6 +519,7 @@ void COverlayDB::copyToClipboard(bool deleteSelection)
 
 }
 
+
 void COverlayDB::pasteFromClipboard()
 {
     QClipboard *clipboard = QApplication::clipboard();
@@ -535,10 +535,11 @@ void COverlayDB::pasteFromClipboard()
 
         loadQLB(qlb, true);
 
-        emit sigModified();
+        emitSigModified();
     }
 }
 
+
 void COverlayDB::highlightOverlay(const QString& key)
 {
     QMap<QString,IOverlay*>::iterator ovl = overlays.begin();
@@ -566,10 +567,11 @@ void COverlayDB::highlightOverlay(const QString& key)
         ovl->setHighlight(true);
     }
 
-    emit sigChanged();
+    emitSigChanged();
 
 }
 
+
 IOverlay* COverlayDB::highlightedOverlay()
 {
 
@@ -583,6 +585,7 @@ IOverlay* COverlayDB::highlightedOverlay()
 
 }
 
+
 void COverlayDB::combineDistOvl()
 {
     CDlgCombineDistOvl dlg(0);
@@ -590,6 +593,7 @@ void COverlayDB::combineDistOvl()
 
 }
 
+
 QList<COverlayDB::keys_t> COverlayDB::keys()
 {
     QList<keys_t> k;
@@ -629,19 +633,19 @@ QList<COverlayDB::keys_t> COverlayDB::keys()
             k2.icon     = dist->getIcon();
         }
 
-
         k << k2;
     }
 
     return k;
 }
 
+
 void COverlayDB::slotModified()
 {
     IOverlay * ovl = qobject_cast<IOverlay*>(sender());
     if(ovl)
     {
-        emit sigModified(ovl->getKey());
+        emitSigModified(ovl->getKey());
     }
 }
 
