@@ -92,6 +92,7 @@ double CPlot::getXValByPixel(int px)
     return m_pData->x().pt2val(px - left);
 }
 
+
 double CPlot::getYValByPixel(int px)
 {
     if(m_pData->lines.isEmpty())
@@ -136,8 +137,7 @@ void CPlot::setLimits()
     m_pData->setLimits();
 }
 
-
-void CPlot::newLine(const QPolygonF& line, const QPointF& focus, const QString& label)
+void CPlot::newLine(const QPolygonF& line, const QList<QPointF>& focus, const QString& label)
 {
     m_pData->lines.clear();
 
@@ -152,13 +152,47 @@ void CPlot::newLine(const QPolygonF& line, const QPointF& focus, const QString&
     l.points    = line;
     l.label     = label;
 
-    m_pData->point1.point = focus;
+    m_pData->focus = focus;
     m_pData->badData = false;
     m_pData->lines << l;
     setSizes();
     m_pData->x().setScale( rectGraphArea.width() );
     m_pData->y().setScale( rectGraphArea.height() );
 
+    idxHighlight1 = -1;
+    idxHighlight2 = -1;
+
+    if(m_pData->focus.size() > 1)
+    {
+        int idx     = 0;
+        double d    = WPT_NOFLOAT;
+        double x    = m_pData->focus.first().x();
+        QPolygonF& line = m_pData->lines[0].points;
+
+        foreach(const QPointF& point, line)
+        {
+            if(fabs(x - point.x()) < d)
+            {
+                d = fabs(x - point.x());
+                idxHighlight1 = idx;
+            }
+            idx++;
+        }
+
+        idx = 0;
+        d   = WPT_NOFLOAT;
+        x   = m_pData->focus.last().x();
+        foreach(const QPointF& point, line)
+        {
+            if(fabs(x - point.x()) < d)
+            {
+                d = fabs(x - point.x());
+                idxHighlight2 = idx;
+            }
+            idx++;
+        }
+    }
+
     needsRedraw = true;
     update();
 
@@ -241,6 +275,7 @@ void CPlot::setSizes()
     setSizeIconArea();
     setSizeXLabel();
     setSizeYLabel();
+    setSizeTrackInfo();
     setSizeDrawArea();
 
 }
@@ -279,6 +314,11 @@ void CPlot::setLRTB()
     {
         bottom -= deadAreaY;
     }
+
+    if(!m_pData->tags.isEmpty() && CResources::self().showTrackProfileEleInfo())
+    {
+        bottom -= fontHeight;
+    }
 }
 
 
@@ -306,6 +346,11 @@ void CPlot::setSizeXLabel()
         rectX1Label.setWidth( right - left );
         rectX1Label.setHeight( fontHeight );
         y = ( size().height() - rectX1Label.height()) - deadAreaY;
+        if(!m_pData->tags.isEmpty() && CResources::self().showTrackProfileEleInfo())
+        {
+            y -= fontHeight;
+        }
+
         rectX1Label.moveTopLeft( QPoint( left, y ) );
     }
 }
@@ -334,6 +379,21 @@ void CPlot::setSizeYLabel()
 }
 
 
+void CPlot::setSizeTrackInfo()
+{
+    if(m_pData->tags.isEmpty() || !CResources::self().showTrackProfileEleInfo())
+    {
+        rectTrackInfo = QRect();
+        return;
+    }
+
+    rectTrackInfo.setWidth(right - left);
+    rectTrackInfo.setHeight(fontHeight);
+    rectTrackInfo.moveLeft(left);
+    rectTrackInfo.moveTop(size().height() - fontHeight);
+}
+
+
 void CPlot::setSizeDrawArea()
 {
     rectGraphArea.setWidth( right - left );
@@ -344,6 +404,7 @@ void CPlot::setSizeDrawArea()
     m_pData->y().setScale( rectGraphArea.height() );
 }
 
+
 void CPlot::draw(QPainter& p, const QSize& s)
 {
     resize(s);
@@ -353,6 +414,7 @@ void CPlot::draw(QPainter& p, const QSize& s)
     draw(p);
 }
 
+
 void CPlot::draw(QPainter& p)
 {
 
@@ -375,8 +437,7 @@ void CPlot::draw(QPainter& p)
         CTrack * track = CTrackDB::self().highlightedTrack();
         if(selTrkPt && track && (mode != eIcon))
         {
-            QString str = track->getTrkPtInfo(*selTrkPt);
-
+            QString str;
             double y = getYValByPixel(x);
             y = m_pData->y().val2pt(y);
             y = bottom - y;
@@ -386,14 +447,13 @@ void CPlot::draw(QPainter& p)
             p.setBrush(CCanvas::brushBackWhite);
             p.drawEllipse(QRect(x - 5,  y - 5, 11, 11));
 
-
+            str = track->getTrkPtInfo1(*selTrkPt);
             if(!str.isEmpty())
             {
                 QFont           f = CResources::self().getMapFont();
                 QFontMetrics    fm(f);
                 QRect           r1 = fm.boundingRect(QRect(0,0,300,0), Qt::AlignLeft|Qt::AlignTop|Qt::TextWordWrap, str);
 
-
                 if((r1.width() + 45 + x) > right)
                 {
                     x = x - 45 - r1.width();
@@ -408,7 +468,6 @@ void CPlot::draw(QPainter& p)
                     y = y - r1.height();
                 }
 
-
                 r1.moveTopLeft(QPoint(x,y));
 
                 QRect r2 = r1;
@@ -417,7 +476,6 @@ void CPlot::draw(QPainter& p)
                 r2.setHeight(r1.height() + 20);
                 r2.moveTop(r1.top() - 10);
 
-
                 p.setPen(QPen(CCanvas::penBorderBlue));
                 p.setBrush(CCanvas::brushBackWhite);
                 PAINT_ROUNDED_RECT(p,r2);
@@ -426,10 +484,32 @@ void CPlot::draw(QPainter& p)
                 p.setPen(Qt::darkBlue);
                 p.drawText(r1, Qt::AlignLeft|Qt::AlignTop|Qt::TextWordWrap,str);
             }
+
+
+            x   = posMouse.x();
+            str = track->getTrkPtInfo2(*selTrkPt);
+            if(!str.isEmpty() && m_pData->focus.isEmpty())
+            {
+                QFont           f = CResources::self().getMapFont();
+                QFontMetrics    fm(f);
+                QRect           r1 = fm.boundingRect(QRect(0,0,1,1), Qt::AlignLeft|Qt::AlignTop, str);
+                r1.moveCenter(QPoint(x, size().height() - fontHeight/2));
+                if(r1.left() < left)
+                {
+                    r1.moveLeft(left);
+                }
+                if(r1.right() > right)
+                {
+                    r1.moveRight(right);
+                }
+
+                CCanvas::drawText(str, p, r1);
+            }
         }
     }
 }
 
+
 void CPlot::draw()
 {
     buffer.fill(Qt::transparent);
@@ -455,7 +535,6 @@ void CPlot::draw()
             p.setBrush(QColor(255,255,255,150));
         }
 
-
         PAINT_ROUNDED_RECT(p,r);
 
     }
@@ -467,6 +546,7 @@ void CPlot::draw()
     }
 
     p.setFont(CResources::self().getMapFont());
+    drawTags(p);
     p.setClipping(true);
     p.setClipRect(rectGraphArea);
     drawData(p);
@@ -483,7 +563,6 @@ void CPlot::draw()
     drawYTic(p);
     p.setPen(QPen(Qt::black,2));
     p.drawRect(rectGraphArea);
-    drawTags(p);
 
     drawLegend(p);
 }
@@ -773,7 +852,7 @@ void CPlot::drawData(QPainter& p)
     if((idxHighlight1 >= 0) && (idxHighlight2 >= 0) && mode != eIcon)
     {
         QPolygonF background;
-        QPolygonF line              = lines[0].points.mid(idxHighlight1, idxHighlight2 - idxHighlight1);
+        QPolygonF line              = lines[0].points.mid(idxHighlight1, idxHighlight2 - idxHighlight1 + 1);
         QPolygonF::iterator point   = line.begin();
 
         ptx = left   + xaxis.val2pt( point->x() );
@@ -799,9 +878,15 @@ void CPlot::drawData(QPainter& p)
         p.setPen(Qt::NoPen);
         p.setBrush(QColor(255,0,0,150));
         p.drawPolygon(background);
+
+        p.setPen(QPen(Qt::darkRed,5));
+        p.drawPolyline(background.mid(1,line.size()));
         p.restore();
+
+
     }
 
+    if(m_pData->focus.size() < 2)
     {
         QPolygonF& marks                = m_pData->marks.points;
         QPolygonF::const_iterator point = marks.begin();
@@ -818,14 +903,62 @@ void CPlot::drawData(QPainter& p)
             ++point;
         }
     }
+    else if(m_pData->focus.size() > 1 && mode != eIcon)
+    {
+        CTrack * trk = CTrackDB::self().highlightedTrack();
+        if(trk != 0)
+        {
+            QString str = trk->getFocusInfo();
+            if (str != "")
+            {
+                QPointF&        focus = m_pData->focus.last();
+                QFont           f = CResources::self().getMapFont();
+                QFontMetrics    fm(f);
+                QRect           r1 = fm.boundingRect(QRect(0,0,300,0), Qt::AlignLeft|Qt::AlignTop, str);
 
-    if(!m_pData->point1.point.isNull())
+                ptx = left   + xaxis.val2pt( focus.x() );
+                pty = bottom - yaxis.val2pt( focus.y() );
+
+                if((r1.width() + 15 + ptx) > right)
+                {
+                    ptx = ptx - 15 - r1.width();
+                }
+                else
+                {
+                    ptx = ptx + 15;
+                }
+
+                if(r1.height() + pty > bottom)
+                {
+                    pty = pty - r1.height();
+                }
+
+
+                r1.moveTopLeft(QPoint(ptx, pty));
+
+                QRect r2 = r1;
+                r2.setWidth(r1.width() + 20);
+                r2.moveLeft(r1.left() - 10);
+                r2.setHeight(r1.height() + 10);
+                r2.moveTop(r1.top() - 5);
+
+                p.save();
+                p.setPen(QPen(CCanvas::penBorderBlue));
+                p.setBrush(CCanvas::brushBackWhite);
+                PAINT_ROUNDED_RECT(p,r2);
+
+                p.setFont(CResources::self().getMapFont());
+                p.setPen(Qt::darkBlue);
+                p.drawText(r1, Qt::AlignLeft|Qt::AlignTop,str);
+                p.restore();
+            }
+        }
+    }
+
+    foreach(const QPointF& point, m_pData->focus)
     {
         p.setPen(QPen(Qt::red,2));
-        ptx = left   + xaxis.val2pt( m_pData->point1.point.x() );
-        pty = bottom - yaxis.val2pt( m_pData->point1.point.y() );
-
-        p.drawLine(rectGraphArea.left(),pty,rectGraphArea.right(),pty);
+        ptx = left   + xaxis.val2pt( point.x() );
         p.drawLine(ptx,rectGraphArea.top(),ptx,rectGraphArea.bottom());
     }
 }
@@ -861,7 +994,7 @@ void CPlot::drawLegend(QPainter& p)
 
 void CPlot::drawTags(QPainter& p)
 {
-    if(m_pData->tags.isEmpty()) return;
+    if(m_pData->tags.isEmpty() || !CResources::self().showTrackProfileEleInfo()) return;
 
     QRect rect;
     int ptx, pty;
@@ -915,8 +1048,6 @@ void CPlot::contextMenuEvent(QContextMenuEvent *event)
         return ;
     }
 
-
-
     QMenu menu(this);
     menu.addAction(hZoomAct);
     menu.addAction(vZoomAct);
@@ -978,7 +1109,6 @@ void CPlot::slotSave()
     QString pathData = cfg.value("path/data","./").toString();
     QString filter   = cfg.value("trackstat/imagetype","Bitmap (*.png)").toString();
 
-
     QString filename = QFileDialog::getSaveFileName( 0, tr("Select output file")
         ,pathData
         ,"Bitmap (*.png)"
@@ -1016,6 +1146,7 @@ void CPlot::slotAddWpt()
     emit sigSetWaypoint(x);
 }
 
+
 void CPlot::zoom(CPlotAxis &axis, bool in, int curInt)
 {
     axis.zoom(in, curInt);
@@ -1157,6 +1288,7 @@ void CPlot::mousePressEvent(QMouseEvent * e)
 
 }
 
+
 void CPlot::leaveEvent(QEvent * event)
 {
     cursorFocus = false;
@@ -1169,6 +1301,7 @@ void CPlot::leaveEvent(QEvent * event)
     update();
 }
 
+
 void CPlot::enterEvent(QEvent * event)
 {
     cursorFocus = true;
@@ -1177,6 +1310,7 @@ void CPlot::enterEvent(QEvent * event)
     update();
 }
 
+
 void CPlot::slotTrkPt(CTrack::pt_t * pt)
 {
     if(pt == 0)
@@ -1202,6 +1336,7 @@ void CPlot::slotTrkPt(CTrack::pt_t * pt)
     update();
 }
 
+
 void CPlot::slotPointOfFocus(const int idx)
 {
     selTrkPt = 0;
@@ -1228,14 +1363,20 @@ void CPlot::slotPointOfFocus(const int idx)
     }
 }
 
+
 void CPlot::slotHighlightSection(double x1, double x2)
 {
     int idx = 0;
+    // no stages if focus is active
+    if(!m_pData || !m_pData->focus.isEmpty())
+    {
+        return;
+    }
 
     idxHighlight1 = -1;
     idxHighlight2 = -1;
 
-    if(m_pData && m_pData->lines.isEmpty())
+    if(m_pData->lines.isEmpty())
     {
         return;
     }
