@@ -36,7 +36,6 @@ class CPlot : public QWidget
         CPlot(CPlotData::axis_type_e type, mode_e mode, QWidget * parent);
         virtual ~CPlot();
 
-
         void setShowScale(bool show){showScale = show;}
         void setThinLine(bool thin){thinLine = thin;}
         void setYLabel(const QString& str);
@@ -44,7 +43,7 @@ class CPlot : public QWidget
 
         void setSelTrackPoint(CTrack::pt_t * pt){selTrkPt = pt;}
 
-        void newLine(const QPolygonF& line, const QPointF& focus, const QString& label);
+        void newLine(const QPolygonF& line, const QList<QPointF> &focus, const QString& label);
         void addLine(const QPolygonF& line, const QString& label);
         void newMarks(const QPolygonF& line);
         void addTag(CPlotData::point_t& tag);
@@ -58,17 +57,16 @@ class CPlot : public QWidget
         void draw(QPainter& p);
         void draw(QPainter& p, const QSize& s);
 
-    signals:
+        signals:
         void sigActivePoint(double dist);
         void sigSetWaypoint(double dist);
         void sigClicked();
 
-    public slots:        
+    public slots:
         void slotPointOfFocus(const int idx);
         void slotHighlightSection(double x1, double x2);
         void resetZoom();
 
-
     protected slots:
         void slotTrkPt(CTrack::pt_t * pt);
         void slotSave();
@@ -103,6 +101,7 @@ class CPlot : public QWidget
         void setSizeIconArea();
         void setSizeXLabel();
         void setSizeYLabel();
+        void setSizeTrackInfo();
         void setSizeDrawArea();
         void zoom(CPlotAxis &axis, bool in, int cur = 0);
 
@@ -136,6 +135,7 @@ class CPlot : public QWidget
         QRect rectY1Label;
         QRect rectGraphArea;
         QRect rectIconArea;
+        QRect rectTrackInfo;
 
         QFontMetrics fm;
 
