@@ -18,6 +18,7 @@
 **********************************************************************************************/
 
 #include "CResources.h"
+#include "CDeviceMagellan.h"
 #include "CDeviceGarmin.h"
 #include "CDeviceGarminBulk.h"
 #include "CDeviceTwoNav.h"
@@ -36,6 +37,7 @@
 #include "CMapTDB.h"
 #include "config.h"
 #include "CSettings.h"
+#include "CCanvas.h"
 
 #ifndef Q_OS_WIN32
 #include <sys/types.h>
@@ -46,6 +48,9 @@
 
 #include <QtGui>
 
+#include "CMainWindow.h"
+#include "CDlgProxy.h"
+
 CResources * CResources::m_self = 0;
 
 CResources::CResources(QObject * parent)
@@ -66,7 +71,9 @@ CResources::CResources(QObject * parent)
 , m_pathGeoDB(QDir::home().filePath(CONFIGDIR))
 #endif
 , m_showTrackProfile(true)
+, m_showTrackEleInfo(true)
 , m_showNorth(true)
+, m_showClock(true)
 , m_showScale(true)
 , m_showToolTip(true)
 , m_showZoomLevel(true)
@@ -76,12 +83,19 @@ CResources::CResources(QObject * parent)
 , m_pathMapCache(QDir::temp().filePath("qlandkartegt/cache"))
 , m_sizeMapCache(100)
 , m_expireMapCache(8)
+, m_tzMode(eTZAuto)
+, m_timezone("UTC")
 {
     m_self = this;
 
     SETTINGS;
 
+#ifndef Q_WS_MAC
     QString family      = cfg.value("environment/mapfont/family","Arial").toString();
+#else
+    // Qt on Mac OS X 10.6 sometimes fails to render, so use the Mac default font here...
+    QString family      = cfg.value("environment/mapfont/family","Lucida Grande").toString();
+#endif
     int size            = cfg.value("environment/mapfont/size",8).toInt();
     bool bold           = cfg.value("environment/mapfont/bold",false).toBool();
     bool italic         = cfg.value("environment/mapfont/italic",false).toBool();
@@ -101,9 +115,10 @@ CResources::CResources(QObject * parent)
     m_httpProxyPort     = cfg.value("network/proxy/port",m_httpProxyPort).toUInt();
 
     if(m_useHttpProxy)
-      QNetworkProxy::setApplicationProxy(QNetworkProxy(QNetworkProxy::HttpProxy,m_httpProxy,m_httpProxyPort));
+        QNetworkProxy::setApplicationProxy(QNetworkProxy(QNetworkProxy::HttpProxy,m_httpProxy,m_httpProxyPort));
+
     else
-      QNetworkProxy::setApplicationProxy(QNetworkProxy(QNetworkProxy::NoProxy));
+        QNetworkProxy::setApplicationProxy(QNetworkProxy(QNetworkProxy::NoProxy));
 
     m_devKey            = cfg.value("device/key",m_devKey).toString();
     m_devIPAddress      = cfg.value("device/ipAddr",m_devIPAddress).toString();
@@ -143,7 +158,9 @@ CResources::CResources(QObject * parent)
     }
 
     m_showTrackProfile = cfg.value("environment/showTrackProfile",m_showTrackProfile).toBool();
+    m_showTrackEleInfo = cfg.value("environment/showTrackEleInfo",m_showTrackEleInfo).toBool();
     m_showNorth        = cfg.value("environment/showNorth",m_showNorth).toBool();
+    m_showClock        = cfg.value("environment/showClock",m_showClock).toBool();
     m_showScale        = cfg.value("environment/showScale",m_showScale).toBool();
     m_showToolTip      = cfg.value("environment/showToolTip",m_showToolTip).toBool();
     m_showZoomLevel    = cfg.value("environment/showZoomLevel",m_showZoomLevel).toBool();
@@ -166,7 +183,6 @@ CResources::CResources(QObject * parent)
     QPixmap(":/webstuff/frame_bottom_right.png").save(dirWeb.filePath("frame_bottom_right.png"));
     QPixmap(":/webstuff/scale.png").save(dirWeb.filePath("scale.png"));
 
-
     QString cacheFolder;
 #ifndef Q_OS_WIN32
     const char *envCache = getenv("QLGT_CACHE");
@@ -193,6 +209,9 @@ CResources::CResources(QObject * parent)
     m_sizeMapCache = cfg.value("network/mapcache/size", m_sizeMapCache).toInt();
     m_expireMapCache = cfg.value("network/mapcache/expire", m_expireMapCache).toInt();
 
+    m_tzMode = (TimezoneMode_e)cfg.value("timezone/mode", m_tzMode).toInt();
+    m_timezone = cfg.value("timezone/zone", m_timezone).toString();
+
 }
 
 
@@ -216,7 +235,6 @@ CResources::~CResources()
     cfg.setValue("network/proxy/url",m_httpProxy);
     cfg.setValue("network/proxy/port",m_httpProxyPort);
 
-
     cfg.setValue("device/key",m_devKey);
     cfg.setValue("device/ipAddr",m_devIPAddress);
     cfg.setValue("device/ipPort",m_devIPPort);
@@ -235,7 +253,9 @@ CResources::~CResources()
 
     cfg.setValue("environment/unittype",unit->type);
     cfg.setValue("environment/showTrackProfile",m_showTrackProfile);
+    cfg.setValue("environment/showTrackEleInfo",m_showTrackEleInfo);
     cfg.setValue("environment/showNorth",m_showNorth);
+    cfg.setValue("environment/showClock",m_showClock);
     cfg.setValue("environment/showScale",m_showScale);
     cfg.setValue("environment/showToolTip",m_showToolTip);
     cfg.setValue("environment/showZoomLevel",m_showZoomLevel);
@@ -247,6 +267,9 @@ CResources::~CResources()
     cfg.setValue("network/mapcache/path", m_pathMapCache.absolutePath());
     cfg.setValue("network/mapcache/size", m_sizeMapCache);
     cfg.setValue("network/mapcache/expire", m_expireMapCache);
+
+    cfg.setValue("timezone/mode", m_tzMode);
+    cfg.setValue("timezone/zone", m_timezone);
 }
 
 
@@ -271,10 +294,18 @@ bool CResources::getHttpProxy(QString& url, quint16& port)
 
     url  = m_httpProxy;
     port = m_httpProxyPort;
+
     return m_useHttpProxy;
 }
 
 
+void CResources::getHttpProxyAuth(QString& user, QString& pwd)
+{
+    CDlgProxy dlg(user, pwd, theMainWindow->getCanvas());
+    dlg.exec();
+}
+
+
 IDevice * CResources::device()
 {
     // purge device if the key does not match
@@ -321,6 +352,10 @@ IDevice * CResources::device()
         {
             m_device = new CDeviceTwoNav(this);
         }
+        else if(m_devKey == "Magellan")
+        {
+            m_device = new CDeviceMagellan(this);
+        }
 
         connect(m_device, SIGNAL(sigLiveLog(const CLiveLog&)), &CLiveLogDB::self(), SLOT(slotLiveLog(const CLiveLog&)));
     }
@@ -344,5 +379,3 @@ QString CResources::charset()
     else
         return m_devCharset;
 }
-
-
