@@ -45,7 +45,7 @@ bool CRouteDB::keyLessThanTime(keys_t&  s1, keys_t&  s2)
 
 
 CRouteDB::CRouteDB(QTabWidget * tb, QObject * parent)
-: IDB(tb, parent)
+: IDB(IDB::eTypeRte, tb, parent)
 , cnt(0)
 {
     m_self      = this;
@@ -72,8 +72,8 @@ void CRouteDB::addRoute(CRoute * route, bool silent)
     connect(route,SIGNAL(sigChanged()),SIGNAL(sigChanged()));
     if(!silent)
     {
-        emit sigChanged();
-        emit sigModified();
+        emitSigChanged();
+        emitSigModified();
     }
 
 }
@@ -86,8 +86,8 @@ void CRouteDB::delRoute(const QString& key, bool silent)
     rte->deleteLater();
     if(!silent)
     {
-        emit sigChanged();
-        emit sigModified();
+        emitSigChanged();
+        emitSigModified();
     }
 }
 
@@ -101,8 +101,8 @@ void CRouteDB::delRoutes(const QStringList& keys)
     }
     if(!keys.isEmpty())
     {
-        emit sigChanged();
-        emit sigModified();
+        emitSigChanged();
+        emitSigModified();
     }
 }
 
@@ -136,7 +136,7 @@ void CRouteDB::highlightRoute(const QString& key)
 
     }
 
-    emit sigChanged();
+    emitSigChanged();
 
 }
 
@@ -217,7 +217,6 @@ void CRouteDB::loadGPX(CGpx& gpx)
             r->setParentWpt(rte.namedItem("parent").toElement().text());
         }
 
-
         QDomElement rtept = rte.firstChildElement("rtept");
 
         while (!rtept.isNull())
@@ -236,7 +235,6 @@ void CRouteDB::loadGPX(CGpx& gpx)
 
             r->addPosition(pt.u,pt.v, name);
 
-
             if(rtept.namedItem("sym").isElement())
             {
                 QString symname = rtept.namedItem("sym").toElement().text();
@@ -260,7 +258,7 @@ void CRouteDB::loadGPX(CGpx& gpx)
 
     if(hasItems)
     {
-        emit sigChanged();
+        emitSigChanged();
     }
 }
 
@@ -278,7 +276,6 @@ void CRouteDB::saveGPX(CGpx& gpx, const QStringList& keys)
             continue;
         }
 
-
         QDomElement rte = gpx.createElement("rte");
         root.appendChild(rte);
 
@@ -382,7 +379,7 @@ void CRouteDB::loadQLB(CQlb& qlb, bool newKey)
 
     if(qlb.routes().size())
     {
-        emit sigChanged();
+        emitSigChanged();
     }
 }
 
@@ -442,16 +439,17 @@ void CRouteDB::download()
         }
     }
 
-    emit sigChanged();
-    emit sigModified();
+    emitSigChanged();
+    emitSigModified();
 }
 
 
 void CRouteDB::clear()
 {
+    if(routes.isEmpty()) return;
     cnt = 0;
     delRoutes(routes.keys());
-    emit sigChanged();
+    emitSigChanged();
 
 }
 
@@ -473,8 +471,6 @@ void CRouteDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
         QPolygon& points    = (*route)->getPoints();
         bool firstTime      = (*route)->firstTime;
 
-
-
         if ( needsRedraw || firstTime)
         {
             bool isPriRoute = (*route)->secRoute.isEmpty();
@@ -561,6 +557,7 @@ void CRouteDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
 
 }
 
+
 void CRouteDB::drawArrows(const QPolygon& line, const QRect& viewport, QPainter& p)
 {
     QPointF arrow[4] =
@@ -571,7 +568,6 @@ void CRouteDB::drawArrows(const QPolygon& line, const QRect& viewport, QPainter&
         QPointF( 0.0, 15.0)      //lower tail
     };
 
-
     QPoint  pt, pt1, ptt;
 
     // draw direction arrows
@@ -588,10 +584,9 @@ void CRouteDB::drawArrows(const QPolygon& line, const QRect& viewport, QPainter&
     t_paint.drawPolygon(arrow, 4);
     t_paint.end();
 
-
     foreach(pt,line)
     {
-        if(start)        // no arrow on  the first loop
+        if(start)                // no arrow on  the first loop
         {
             start = false;
         }
@@ -599,13 +594,15 @@ void CRouteDB::drawArrows(const QPolygon& line, const QRect& viewport, QPainter&
         {
             if(!viewport.contains(pt))
             {
+                pt1 = pt;
                 continue;
             }
             if((abs(pt.x() - pt1.x()) + abs(pt.y() - pt1.y())) < 7)
             {
+                pt1 = pt;
                 continue;
             }
-                         // keep distance
+            // keep distance
             if((abs(pt.x() - ptt.x()) + abs(pt.y() - ptt.y())) > 100)
             {
                 if(0 != pt.x() - pt1.x() && (pt.y() - pt1.y()))
@@ -618,7 +615,7 @@ void CRouteDB::drawArrows(const QPolygon& line, const QRect& viewport, QPainter&
                     p.rotate(heading);
                     p.drawImage(-11, -7, arrow_pic);
                     p.restore();
-                         //remember last point
+                    //remember last point
                     ptt = pt;
                 }
             }
@@ -711,10 +708,10 @@ QList<CRouteDB::keys_t> CRouteDB::keys()
             break;
     }
 
-
     return k;
 }
 
+
 void CRouteDB::makeVisible(const QStringList& keys)
 {
     QRectF r;
@@ -742,24 +739,26 @@ void CRouteDB::makeVisible(const QStringList& keys)
 
 }
 
+
 void CRouteDB::loadSecondaryRoute(const QString& key, QDomDocument& xml, CRoute::service_e service)
 {
     if(routes.contains(key))
     {
         routes[key]->loadSecondaryRoute(xml, service);
-        emit sigChanged();
-        emit sigModified();
-        emit sigModified(key);
+        emitSigChanged();
+        emitSigModified();
+        emitSigModified(key);
     }
 }
 
+
 void CRouteDB::reset(const QString& key)
 {
     if(routes.contains(key))
     {
         routes[key]->reset();
-        emit sigChanged();
-        emit sigModified();
-        emit sigModified(key);
+        emitSigChanged();
+        emitSigModified();
+        emitSigModified(key);
     }
 }
