@@ -31,7 +31,7 @@
 #include "CMegaMenu.h"
 #include "version.h"
 #include "CSettings.h"
-
+#include "CMainWindow.h"
 
 #include <QtGui>
 #include <QtXml>
@@ -63,6 +63,7 @@ CRouteToolWidget::CRouteToolWidget(QTabWidget * parent)
     {
         m_networkAccessManager->setProxy(QNetworkProxy(QNetworkProxy::DefaultProxy,url,port));
     }
+
     connect(m_networkAccessManager,SIGNAL(finished(QNetworkReply*)),this,SLOT(slotRequestFinished(QNetworkReply*)));
 
     connect(&CRouteDB::self(), SIGNAL(sigChanged()), this, SLOT(slotDBChanged()));
@@ -169,6 +170,9 @@ CRouteToolWidget::CRouteToolWidget(QTabWidget * parent)
 
     m_networkAccessManager->setProxy(QNetworkProxy(QNetworkProxy::DefaultProxy));
 
+    connect(m_networkAccessManager, SIGNAL(proxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)),
+        this, SLOT(slotProxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)));
+
     timer = new QTimer(this);
     timer->setSingleShot(true);
 
@@ -181,7 +185,6 @@ CRouteToolWidget::CRouteToolWidget(QTabWidget * parent)
     toolSortAlpha->setChecked(cfg.value("route/sortAlpha", true).toBool());
     toolSortTime->setChecked(cfg.value("route/sortTime", true).toBool());
 
-
     connect(timer, SIGNAL(timeout()), this, SLOT(slotTimeout()));
 }
 
@@ -198,6 +201,7 @@ CRouteToolWidget::~CRouteToolWidget()
     }
 }
 
+
 void CRouteToolWidget::slotServiceChanged(int idx)
 {
     groupORS->hide();
@@ -213,6 +217,7 @@ void CRouteToolWidget::slotServiceChanged(int idx)
     }
 }
 
+
 void CRouteToolWidget::slotDBChanged()
 {
     if(originator) return;
@@ -355,6 +360,7 @@ void CRouteToolWidget::slotDelete()
     slotDBChanged();
 }
 
+
 void CRouteToolWidget::slotCalcRoute()
 {
 
@@ -409,8 +415,6 @@ void CRouteToolWidget::slotCalcRoute()
 }
 
 
-
-
 const QString CRouteToolWidget::gml_ns = "http://www.opengis.net/gml";
 const QString CRouteToolWidget::xls_ns = "http://www.opengis.net/xls";
 const QString CRouteToolWidget::xsi_ns = "http://www.w3.org/2001/XMLSchema-instance";
@@ -418,7 +422,6 @@ const QString CRouteToolWidget::sch_ns = "http://www.ascc.net/xml/schematron";
 const QString CRouteToolWidget::xlink_ns = "http://www.w3.org/1999/xlink";
 const QString CRouteToolWidget::schemaLocation = "http://www.opengis.net/xls http://schemas.opengis.net/ols/1.1.0/RouteService.xsd";
 
-
 void CRouteToolWidget::startOpenRouteService(CRoute& rte)
 {
     QDomDocument xml;
@@ -444,7 +447,6 @@ void CRouteToolWidget::startOpenRouteService(CRoute& rte)
     Request.setAttribute("requestID", rte.getKey());
     Request.setAttribute("version", "1.1");
 
-
     QDomElement DetermineRouteRequest = xml.createElement("xls:DetermineRouteRequest");
     Request.appendChild(DetermineRouteRequest);
 
@@ -484,8 +486,6 @@ void CRouteToolWidget::startOpenRouteService(CRoute& rte)
         AvoidFeature.appendChild(_AvoidFeature_);
     }
 
-
-
     QDomElement RouteInstructionsRequest = xml.createElement("xls:RouteInstructionsRequest");
     RouteInstructionsRequest.setAttribute("provideGeometry", "1");
     DetermineRouteRequest.appendChild(RouteInstructionsRequest);
@@ -509,6 +509,7 @@ void CRouteToolWidget::startOpenRouteService(CRoute& rte)
 
 }
 
+
 void CRouteToolWidget::addOpenLSWptList(QDomDocument& xml, QDomElement& WayPointList, CRoute& rte)
 {
 
@@ -535,6 +536,7 @@ void CRouteToolWidget::addOpenLSWptList(QDomDocument& xml, QDomElement& WayPoint
     addOpenLSPos(xml, EndPoint, wpts.last());
 }
 
+
 void CRouteToolWidget::addOpenLSPos(QDomDocument& xml, QDomElement& Parent, CRoute::pt_t& pt)
 {
     QString lon, lat;
@@ -556,17 +558,29 @@ void CRouteToolWidget::addOpenLSPos(QDomDocument& xml, QDomElement& Parent, CRou
 }
 
 
+void CRouteToolWidget::slotProxyAuthenticationRequired(const QNetworkProxy &prox, QAuthenticator *auth)
+{
+    QString user;
+    QString pwd;
+
+    CResources::self().getHttpProxyAuth(user,pwd);
+
+    auth->setUser(user);
+    auth->setPassword(pwd);
+}
+
+
 void CRouteToolWidget::slotRequestFinished(QNetworkReply* reply)
 {
     QString key;
     if(pendingRequests.contains(reply))
     {
         key = pendingRequests.take(reply);
-//        qDebug() << "--------------------removed" << key << reply;
+        //        qDebug() << "--------------------removed" << key << reply;
     }
     else
     {
-//        qDebug() << "--------------------reply not found" << reply;
+        //        qDebug() << "--------------------reply not found" << reply;
     }
 
     if(reply->error() != QNetworkReply::NoError)
@@ -589,8 +603,8 @@ void CRouteToolWidget::slotRequestFinished(QNetworkReply* reply)
 
     QDomDocument xml;
     xml.setContent(res);
-//    qDebug() << xml.toString();
-//    qDebug() << "key:" << key;
+    //    qDebug() << xml.toString();
+    //    qDebug() << "key:" << key;
 
     qint32 service = comboService->itemData(comboService->currentIndex()).toInt();
     if(service == CRoute::eOpenRouteService)
@@ -621,6 +635,7 @@ void CRouteToolWidget::slotRequestFinished(QNetworkReply* reply)
     CRouteDB::self().loadSecondaryRoute(key, xml, (CRoute::service_e)service);
 }
 
+
 void CRouteToolWidget::slotResetRoute()
 {
     QListWidgetItem * item;
@@ -633,6 +648,7 @@ void CRouteToolWidget::slotResetRoute()
     }
 }
 
+
 void CRouteToolWidget::slotSelectionChanged()
 {
     if(originator)
@@ -645,6 +661,7 @@ void CRouteToolWidget::slotSelectionChanged()
     }
 }
 
+
 void CRouteToolWidget::slotToOverlay()
 {
 
@@ -675,6 +692,7 @@ void CRouteToolWidget::slotToOverlay()
     CMegaMenu::self().switchByKeyWord("Overlay");
 }
 
+
 void CRouteToolWidget::slotToTrack()
 {
 
@@ -686,7 +704,6 @@ void CRouteToolWidget::slotToTrack()
 
         QVector<CRoute::pt_t>& rtepts = route->getSecRtePoints().isEmpty() ? route->getPriRtePoints() : route->getSecRtePoints();
 
-
         double dist, d, delta = 10.0, a1 , a2;
         projXY pt1, pt2, ptx;
         CTrack::pt_t pt;
@@ -704,7 +721,6 @@ void CRouteToolWidget::slotToTrack()
         delta   = dlg.getDelta();
         eleMode = dlg.getEleMode();
 
-
         if(delta == -1)
         {
 
@@ -733,7 +749,6 @@ void CRouteToolWidget::slotToTrack()
             pt._lat = pt.lat;
             *track << pt;
 
-
             pt1.u = pt1.u * DEG_TO_RAD;
             pt1.v = pt1.v * DEG_TO_RAD;
 
@@ -745,7 +760,6 @@ void CRouteToolWidget::slotToTrack()
                 pt2.u = pt2.u * DEG_TO_RAD;
                 pt2.v = pt2.v * DEG_TO_RAD;
 
-
                 // all points from pt1 -> pt2, with 10m steps
                 dist = ::distance(pt1, pt2, a1, a2);
                 a1 *= DEG_TO_RAD;
@@ -791,6 +805,7 @@ void CRouteToolWidget::slotToTrack()
 
 }
 
+
 void CRouteToolWidget::slotZoomToFit()
 {
     QRectF r;
@@ -812,11 +827,13 @@ void CRouteToolWidget::slotZoomToFit()
     }
 }
 
+
 void CRouteToolWidget::slotTimeout()
 {
     QMessageBox::warning(0,tr("Failed..."), tr("Route request timed out. Please try again later."), QMessageBox::Abort);
 }
 
+
 const QByteArray keyMapQuest = "Fmjtd%7Cluu2n16t2h%2Crw%3Do5-haya0";
 
 void CRouteToolWidget::startMapQuest(CRoute& rte)
@@ -841,7 +858,6 @@ void CRouteToolWidget::startMapQuest(CRoute& rte)
     generalize.appendChild(xml.createTextNode("0"));
     options.appendChild(generalize);
 
-
     QDomElement unit = xml.createElement("unit");
     unit.appendChild(xml.createTextNode("k"));
     options.appendChild(unit);
@@ -908,7 +924,7 @@ void CRouteToolWidget::startMapQuest(CRoute& rte)
     queryItems << QPair<QByteArray, QByteArray>(QByteArray("xml"), QUrl::toPercentEncoding(xmlstr));
     url.setEncodedQueryItems(queryItems);
 
-//    qDebug() << url.toString();
+    //    qDebug() << url.toString();
 
     QNetworkRequest request;
     request.setUrl(url);
@@ -920,6 +936,7 @@ void CRouteToolWidget::startMapQuest(CRoute& rte)
     timer->start(20000);
 }
 
+
 void CRouteToolWidget::addMapQuestLocations(QDomDocument& xml, QDomElement& locations, CRoute& rte)
 {
     QVector<CRoute::pt_t> wpts = rte.getPriRtePoints();
