@@ -35,14 +35,17 @@ CSearchDB * CSearchDB::m_self;
 static const char google_api_key[] = "ABQIAAAAPztEvITCpkvDNrq-hFRvThQNZ4aRbgDVTL9C0r5u06RhgW2EtRR8yuKglxlHgpZfC5_TdLXlJvIWgA";
 
 CSearchDB::CSearchDB(QTabWidget * tb, QObject * parent)
-: IDB(tb,parent)
+: IDB(IDB::eTypeSrc, tb, parent)
 , tmpResult(0)
 {
     m_self      = this;
     toolview    = new CSearchToolWidget(tb);
 
     networkAccessManager.setProxy(QNetworkProxy(QNetworkProxy::DefaultProxy));
+
     connect(&networkAccessManager,SIGNAL(finished(QNetworkReply*)),this,SLOT(slotRequestFinished(QNetworkReply*)));
+    connect(&networkAccessManager, SIGNAL(proxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)),
+        this, SLOT(slotProxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)));
 }
 
 
@@ -54,10 +57,12 @@ CSearchDB::~CSearchDB()
 
 void CSearchDB::clear()
 {
+    if(results.isEmpty()) return;
     results.clear();
-    emit sigChanged();
+    emitSigChanged();
 }
 
+
 void CSearchDB::search(const QString& str, hosts_t host)
 {
     emit sigStatus(tr("start searching..."));
@@ -66,16 +71,16 @@ void CSearchDB::search(const QString& str, hosts_t host)
         case eOpenRouteService:
             startOpenRouteService(str);
             break;
-//        case eMapQuest:
-//            startMapQuest(str);
-//            break;
+            //        case eMapQuest:
+            //            startMapQuest(str);
+            //            break;
         case eGoogle:
             startGoogle(str);
             break;
         default:
             emit sigStatus(tr("Unknown host."));
             emit sigFinished();
-            emit sigChanged();
+            emitSigChanged();
     }
 }
 
@@ -96,6 +101,7 @@ void CSearchDB::startGoogle(const QString& str)
 
 }
 
+
 const QString CSearchDB::xls_ns = "http://www.opengis.net/xls";
 const QString CSearchDB::sch_ns = "http://www.ascc.net/xml/schematron";
 const QString CSearchDB::gml_ns = "http://www.opengis.net/gml";
@@ -144,7 +150,7 @@ void CSearchDB::startOpenRouteService(const QString& str)
     QDomText _freeFormAddress_ = xml.createTextNode(str);
     freeFormAddress.appendChild(_freeFormAddress_);
 
-//    qDebug() << xml.toString();
+    //    qDebug() << xml.toString();
 
     QByteArray array;
     QTextStream out(&array, QIODevice::WriteOnly);
@@ -162,6 +168,7 @@ void CSearchDB::startOpenRouteService(const QString& str)
 
 }
 
+
 void CSearchDB::startMapQuest(const QString& str)
 {
 
@@ -176,12 +183,11 @@ void CSearchDB::slotRequestFinished(QNetworkReply * reply)
         host = pendingRequests.take(reply);
     }
 
-
     if(reply->error() != QNetworkReply::NoError)
     {
         emit sigStatus(reply->errorString());
         emit sigFinished();
-        emit sigChanged();
+        emitSigChanged();
         reply->deleteLater();
         return;
     }
@@ -199,22 +205,22 @@ void CSearchDB::slotRequestFinished(QNetworkReply * reply)
         case eOpenRouteService:
             slotRequestFinishedOpenRouteService(data);
             break;
-//        case eMapQuest:
-//            slotRequestFinishedMapQuest(data);
-//            break;
+            //        case eMapQuest:
+            //            slotRequestFinishedMapQuest(data);
+            //            break;
         case eGoogle:
             slotRequestFinishedGoogle(data);
             break;
         default:
             emit sigStatus(tr("Unknown host."));
             emit sigFinished();
-            emit sigChanged();
+            emitSigChanged();
     }
 
-
     QApplication::restoreOverrideCursor();
 }
 
+
 void CSearchDB::slotRequestFinishedGoogle(QByteArray& data)
 {
 
@@ -276,16 +282,17 @@ void CSearchDB::slotRequestFinishedGoogle(QByteArray& data)
     }
 
     emit sigFinished();
-    emit sigChanged();
+    emitSigChanged();
 }
 
+
 void CSearchDB::slotRequestFinishedOpenRouteService(QByteArray& data)
 {
     QDomDocument xml;
     QString status = tr("finished");
 
     xml.setContent(data);
-//    qDebug() << xml.toString();
+    //    qDebug() << xml.toString();
 
     QDomElement root = xml.documentElement();
     QDomNodeList Results = root.elementsByTagName("xls:GeocodedAddress");
@@ -342,10 +349,11 @@ void CSearchDB::slotRequestFinishedOpenRouteService(QByteArray& data)
 
     emit sigStatus(status);
     emit sigFinished();
-    emit sigChanged();
+    emitSigChanged();
 
 }
 
+
 void CSearchDB::slotRequestFinishedMapQuest(QByteArray& data)
 {
     QDomDocument xml;
@@ -358,11 +366,23 @@ void CSearchDB::slotRequestFinishedMapQuest(QByteArray& data)
 
     emit sigStatus(status);
     emit sigFinished();
-    emit sigChanged();
+    emitSigChanged();
 
 }
 
 
+void CSearchDB::slotProxyAuthenticationRequired(const QNetworkProxy &prox, QAuthenticator *auth)
+{
+    QString user;
+    QString pwd;
+
+    CResources::self().getHttpProxyAuth(user,pwd);
+
+    auth->setUser(user);
+    auth->setPassword(pwd);
+}
+
+
 CSearch * CSearchDB::getResultByKey(const QString& key)
 {
     if(!results.contains(key)) return 0;
@@ -402,7 +422,7 @@ void CSearchDB::delResults(const QStringList& keys)
         results.remove(key);
     }
 
-    emit sigChanged();
+    emitSigChanged();
 
 }
 
@@ -416,9 +436,10 @@ void CSearchDB::add(const QString& label, double lon, double lat)
 
     results[item->getKey()] = item;
 
-    emit sigChanged();
+    emitSigChanged();
 }
 
+
 void CSearchDB::selSearchByKey(const QString& key)
 {
     CSearchToolWidget * t = qobject_cast<CSearchToolWidget*>(toolview);
@@ -428,6 +449,3 @@ void CSearchDB::selSearchByKey(const QString& key)
         gainFocus();
     }
 }
-
-
-
