@@ -23,16 +23,15 @@
 #include "CSearch.h"
 
 #include <QMap>
+#include <QtNetwork>
 
-
-#include <QNetworkAccessManager>
 class QNetworkReply;
 
 /// search database
 class CSearchDB : public IDB
 {
     Q_OBJECT
-    public:
+        public:
         virtual ~CSearchDB();
 
         //         struct result_t
@@ -46,7 +45,7 @@ class CSearchDB : public IDB
 
         enum hosts_t
         {
-             eOpenRouteService
+            eOpenRouteService
             ,eMapQuest
             ,eGoogle
             ,eNoHost
@@ -91,6 +90,7 @@ class CSearchDB : public IDB
         void slotRequestFinishedGoogle(QByteArray& data);
         void slotRequestFinishedOpenRouteService(QByteArray& data);
         void slotRequestFinishedMapQuest(QByteArray& data);
+        void slotProxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*);
 
     private:
         friend class CMainWindow;
