@@ -27,6 +27,7 @@
 #include <QDateTime>
 #include <QMap>
 #include <QList>
+#include <QtNetwork>
 #include <QPointer>
 #include "CWpt.h"
 #include "IItem.h"
@@ -71,7 +72,8 @@ class CTrack : public IItem
 
         virtual ~CTrack();
         int ref;
-        enum type_e {eEnd,eBase,eTrkPts,eTrain,eTrkExt1,eTrkGpxExt,eTrkShdw};
+        enum type_e {eEnd,eBase,eTrkPts,eTrain,eTrkExt1,eTrkGpxExt,eTrkShdw, eTrkShdw2, eTrkPts2};
+        enum type_select_e{eErase, eNoErase, e3Way};
 
 #ifdef GPX_EXTENSIONS
         CGpxExtTr tr_ext;        //TODO: CGpxExtPt -> tr_ext
@@ -92,7 +94,7 @@ class CTrack : public IItem
                 ascend(0), descend(0), heartReateBpm(-1), cadenceRpm(-1), slope(0), timeSinceStart(0),
                 fix(""), sat(0), velocity(WPT_NOFLOAT), heading(WPT_NOFLOAT),
                 vdop(WPT_NOFLOAT), hdop(WPT_NOFLOAT), pdop(WPT_NOFLOAT),
-                _lon(WPT_NOFLOAT),_lat(WPT_NOFLOAT),_ele(WPT_NOFLOAT),
+                _lon(WPT_NOFLOAT),_lat(WPT_NOFLOAT),_ele(WPT_NOFLOAT), _timestamp(0), _timestamp_msec(0),
                 flags(0), px_valid(FALSE), dem(WPT_NOFLOAT), editItem(NULL){}
 
             bool operator==(const pt_t& pt) const {return pt.idx == idx;}
@@ -161,6 +163,8 @@ class CTrack : public IItem
             float   _lat;
             /// elevation [m]
             float   _ele;
+            quint32 _timestamp;
+            quint32 _timestamp_msec;
 
             /// display flags
             CFlags flags;
@@ -184,7 +188,6 @@ class CTrack : public IItem
             pt_t trkpt;
         };
 
-
         /// set color by id
         void setColor(unsigned i);
         void setColor(const QColor& c);
@@ -213,9 +216,9 @@ class CTrack : public IItem
         /// get the total time while moving around
         quint32 getTotalTimeMoving() const {return totalTimeMoving;}
         /// select tarckpoint by index
-        void setPointOfFocus(int idx, bool eraseSelection, bool moveMap);
+        void setPointOfFocus(int idx, type_select_e typeSelect, bool moveMap);
         /// set point of focus to a point with a given distance from start
-        pt_t * getPointOfFocus(double dist);
+        void getPointOfFocus(QList<pt_t>& points);
         ///
         QDateTime getStartTimestamp();
         ///
@@ -225,9 +228,14 @@ class CTrack : public IItem
         /// get the descend in [m]
         double getDescend() const {return totalDescend;}
         /// get information string for a particular trackpoint
-        QString getTrkPtInfo(pt_t& trkpt);
+        QString getTrkPtInfo1(pt_t& trkpt);
+        QString getTrkPtInfo2(pt_t& trkpt);
+        QString getFocusInfo();
         /// get the bounding rectangular that fits the track
         QRectF getBoundingRectF();
+
+        const QString& getTimezone(){return timezone;}
+
         /// sort trackpoints by timestamp
         void sortByTimestamp();
         /// combine tracks
@@ -261,13 +269,24 @@ class CTrack : public IItem
         const QList<wpt_t>& getStageWaypoints(){return waypoints;}
 
         /// smooth profile with a median filter
-        void medianFilter(quint32 len, QProgressDialog &progress);
+        void medianFilter(qint32 len, QProgressDialog &progress);
 
         /// reset all smoothed and purged data to it's original state
         void reset();
 
         quint32 getMedianFilterCount() const {return cntMedianFilterApplied;}
 
+        void offsetElevation(double offset);
+
+        void changeStartTime(QDateTime& time);
+
+        void changeSpeed(double speed);
+
+        bool unifyTimestamps(quint32 delta);
+
+        void setupIterators(QList<pt_t>::iterator& begin, QList<pt_t>::iterator& end);
+
+
         signals:
         void sigChanged();
 
@@ -275,10 +294,8 @@ class CTrack : public IItem
         void slotScaleWpt2Track();
 
     private slots:
-        void slotRequestStarted(int );
-        void slotRequestFinished(int , bool error);
-
-
+        void slotRequestFinished(QNetworkReply * reply);
+        void slotProxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*);
 
     private:
         friend class CTrackDB;
@@ -302,9 +319,9 @@ class CTrack : public IItem
         bool highlight;
 
         /// total time covered by all track points
-        quint32 totalTime;
+        double totalTime;
         /// total time moving
-        quint32 totalTimeMoving;
+        double totalTimeMoving;
         /// total distance of track [m]
         double  totalDistance;
 
@@ -331,9 +348,8 @@ class CTrack : public IItem
 
         quint32 doScaleWpt2Track;
 
-        QHttp * geonames;
-
-        QMap<int,int> id2idx;
+        QNetworkAccessManager * networkAccessManager;
+        QMap<QNetworkReply*,int> reply2idx;
 
         quint32 visiblePointCount;
 
@@ -343,6 +359,11 @@ class CTrack : public IItem
 
         bool replaceOrigData;
 
+        enum state_select_e {eNoSel, e1stSel, e2ndSel};
+        state_select_e stateSelect;
+
+        QString timezone;
+
 };
 
 QDataStream& operator >>(QDataStream& s, CTrack& track);
