@@ -18,6 +18,7 @@
 
 **********************************************************************************************/
 #include <stdio.h>
+#include <limits>
 
 #include "CTrackDB.h"
 #include "CTrack.h"
@@ -55,6 +56,7 @@ bool CTrackDB::keyLessThanAlpha(CTrackDB::keys_t&  s1, CTrackDB::keys_t&  s2)
     return s1.name.toLower() < s2.name.toLower();
 }
 
+
 bool CTrackDB::keyLessThanTime(keys_t&  s1, keys_t&  s2)
 {
     return s1.time < s2.time;
@@ -62,7 +64,7 @@ bool CTrackDB::keyLessThanTime(keys_t&  s1, keys_t&  s2)
 
 
 CTrackDB::CTrackDB(QTabWidget * tb, QObject * parent)
-: IDB(tb,parent)
+: IDB(IDB::eTypeTrk, tb, parent)
 , cnt(0)
 , showBullets(true)
 , showMinMax(true)
@@ -75,6 +77,8 @@ CTrackDB::CTrackDB(QTabWidget * tb, QObject * parent)
     toolview    = new CTrackToolWidget(tb);
     undoStack   = CUndoStackModel::getInstance();
 
+
+    connect(&CMapDB::self(), SIGNAL(sigChanged()), this, SLOT(slotMapChanged()));
 }
 
 
@@ -88,11 +92,13 @@ CTrackDB::~CTrackDB()
 
 void CTrackDB::clear()
 {
+    if(tracks.isEmpty()) return;
+
     cnt = 0;
     delTracks(tracks.keys());
     CTrack::resetKeyCnt();
     emit sigHighlightTrack(0);
-    emit sigChanged();
+    emitSigChanged();
 }
 
 
@@ -123,8 +129,6 @@ QRectF CTrackDB::getBoundingRectF()
 }
 
 
-
-
 void CTrackDB::loadQLB(CQlb& qlb, bool newKey)
 {
     QDataStream stream(&qlb.tracks(),QIODevice::ReadOnly);
@@ -143,7 +147,7 @@ void CTrackDB::loadQLB(CQlb& qlb, bool newKey)
 
     if(qlb.tracks().size())
     {
-        emit sigChanged();
+        emitSigChanged();
     }
 
 }
@@ -284,6 +288,9 @@ void CTrackDB::loadGPX(CGpx& gpx)
                 {
                     QString timetext = tmpelem.text();
                     (void)parseTimestamp(timetext, pt.timestamp, pt.timestamp_msec);
+
+                    pt._timestamp = pt.timestamp;
+                    pt._timestamp_msec = pt.timestamp_msec;
                 }
 
                 tmpelem = trkptmap.value("fix");
@@ -429,7 +436,7 @@ void CTrackDB::loadGPX(CGpx& gpx)
     CTrack::resetKeyCnt();
     if(hasItems)
     {
-        emit sigChanged();
+        emitSigChanged();
     }
 }
 
@@ -533,7 +540,6 @@ void CTrackDB::saveGPX(CGpx& gpx, const QStringList& keys)
             QDomText _time_ = gpx.createTextNode(t.toString("yyyy-MM-dd'T'hh:mm:ss.zzz'Z'"));
             time.appendChild(_time_);
 
-
             if(pt->hdop != WPT_NOFLOAT)
             {
                 QDomElement hdop = gpx.createElement("hdop");
@@ -578,7 +584,6 @@ void CTrackDB::saveGPX(CGpx& gpx, const QStringList& keys)
                 bool hasExtensions = false;
                 QDomElement extensions = gpx.createElement("extensions");
 
-
                 if(pt->flags.flag() != 0)
                 {
                     QDomElement flags = gpx.createElement("ql:flags");
@@ -634,8 +639,8 @@ void CTrackDB::addTrack(CTrack* track, bool silent)
     connect(track,SIGNAL(sigChanged()),SIGNAL(sigChanged()));
     if(!silent)
     {
-        emit sigChanged();
-        emit sigModified();
+        emitSigChanged();
+        emitSigModified();
     }
 }
 
@@ -658,8 +663,8 @@ void CTrackDB::delTracks(const QStringList& keys)
     undoStack->endMacro();
     if(!keys.isEmpty())
     {
-        emit sigChanged();
-        emit sigModified();
+        emitSigChanged();
+        emitSigModified();
     }
 }
 
@@ -681,7 +686,7 @@ void CTrackDB::highlightTrack(const QString& key)
 
     if(tracks.contains(key))
     {
-        tracks[key]->setHighlight(true);      
+        tracks[key]->setHighlight(true);
         emit sigHighlightTrack(tracks[key]);
     }
     else
@@ -689,7 +694,7 @@ void CTrackDB::highlightTrack(const QString& key)
         emit sigHighlightTrack(0);
     }
 
-    emit sigChanged();
+    emitSigChanged();
 
 }
 
@@ -710,7 +715,7 @@ void CTrackDB::hideTrack(const QStringList& keys, bool hide)
             }
         }
     }
-    emit sigChanged();
+    emitSigChanged();
 }
 
 
@@ -771,8 +776,8 @@ void CTrackDB::download()
         }
     }
 
-    emit sigChanged();
-    emit sigModified();
+    emitSigChanged();
+    emitSigModified();
 }
 
 
@@ -814,10 +819,11 @@ void CTrackDB::splitTrack(int idx)
     addTrack(track2, true);
     delTrack(theTrack->getKey(), true);
 
-    emit sigChanged();
-    emit sigModified();
+    emitSigChanged();
+    emitSigModified();
 }
 
+
 void CTrackDB::drawLine(const QPolygon& line, const QRect& extViewport, QPainter& p)
 {
     QPolygon subline;
@@ -868,6 +874,7 @@ void CTrackDB::drawLine(const QPolygon& line, const QRect& extViewport, QPainter
 
 }
 
+
 static void drawMarker(QPainter& p, const QString& text, CTrack::pt_t& pt)
 {
     IMap& map = CMapDB::self().getMap();
@@ -895,6 +902,7 @@ static void drawMarker(QPainter& p, const QString& text, CTrack::pt_t& pt)
 
 }
 
+
 void CTrackDB::drawArrows(const QPolygon& line, const QRect& viewport, QPainter& p)
 {
     QPointF arrow[4] =
@@ -921,10 +929,9 @@ void CTrackDB::drawArrows(const QPolygon& line, const QRect& viewport, QPainter&
     t_paint.drawPolygon(arrow, 4);
     t_paint.end();
 
-
     foreach(pt,line)
     {
-        if(start)        // no arrow on  the first loop
+        if(start)                // no arrow on  the first loop
         {
             start = false;
         }
@@ -932,13 +939,15 @@ void CTrackDB::drawArrows(const QPolygon& line, const QRect& viewport, QPainter&
         {
             if(!viewport.contains(pt))
             {
+                pt1 = pt;
                 continue;
             }
             if((abs(pt.x() - pt1.x()) + abs(pt.y() - pt1.y())) < 7)
             {
+                pt1 = pt;
                 continue;
             }
-                         // keep distance
+            // keep distance
             if((abs(pt.x() - ptt.x()) + abs(pt.y() - ptt.y())) > 100)
             {
                 if(0 != pt.x() - pt1.x() && (pt.y() - pt1.y()))
@@ -951,7 +960,7 @@ void CTrackDB::drawArrows(const QPolygon& line, const QRect& viewport, QPainter&
                     p.rotate(heading);
                     p.drawImage(-11, -7, arrow_pic);
                     p.restore();
-                         //remember last point
+                    //remember last point
                     ptt = pt;
                 }
             }
@@ -969,7 +978,6 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
     QVector<QPoint> selected;
     IMap& map = CMapDB::self().getMap();
 
-
     //     QMap<QString,CTrack*> tracks                = CTrackDB::self().getTracks();
     QMap<QString,CTrack*>::iterator track       = tracks.begin();
     QMap<QString,CTrack*>::iterator highlighted = tracks.end();
@@ -1092,7 +1100,6 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
         p.setPen(pen2);
         drawLine(line, extRect, p);
 
-
         if(showBullets)
         {
             foreach(pt,line)
@@ -1123,8 +1130,33 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
             p.setPen(Qt::red);
             p.drawLine(focus + QPoint(0,-20),focus + QPoint(0,20));
             p.drawLine(focus + QPoint(-20,0),focus + QPoint(20,0));
-        }
 
+            QString str = (*track)->getFocusInfo();
+            //-----------------------------------------------------------------------------------------------------------
+            if (str != "")
+            {
+                QFont           f = CResources::self().getMapFont();
+                QFontMetrics    fm(f);
+                QRect           r1 = fm.boundingRect(QRect(0,0,300,0), Qt::AlignLeft|Qt::AlignTop, str);
+
+                r1.moveTopLeft(focus + QPoint(15,15));
+
+                QRect           r2 = r1;
+                r2.setWidth(r1.width() + 20);
+                r2.moveLeft(r1.left() - 10);
+                r2.setHeight(r1.height() + 10);
+                r2.moveTop(r1.top() - 5);
+
+                p.setPen(QPen(CCanvas::penBorderBlue));
+                p.setBrush(CCanvas::brushBackWhite);
+                PAINT_ROUNDED_RECT(p,r2);
+
+                p.setFont(CResources::self().getMapFont());
+                p.setPen(Qt::darkBlue);
+                p.drawText(r1, Qt::AlignLeft|Qt::AlignTop,str);
+            }
+
+        }
 
         QString val, unit;
 
@@ -1220,7 +1252,7 @@ void CTrackDB::pasteFromClipboard()
         qlb.load(&buffer);
         loadQLB(qlb, true);
 
-        emit sigModified();
+        emitSigModified();
     }
 }
 
@@ -1231,8 +1263,8 @@ CTrack *CTrackDB::take(const QString& key, bool silent)
 
     if (!silent)
     {
-        emit sigChanged();
-        emit sigModified();
+        emitSigChanged();
+        emitSigModified();
     }
     return track;
 }
@@ -1243,24 +1275,18 @@ void CTrackDB::insert(const QString& key, CTrack *track, bool silent)
     tracks.insert(key,track);
     if (!silent)
     {
-        emit sigChanged();
-        emit sigModified();
+        emitSigChanged();
+        emitSigModified();
     }
 }
 
 
-void CTrackDB::emitSigChanged()
-{
-    emit sigChanged();
-}
-
-
 void CTrackDB::emitSigModified()
 {
-    emit sigModified();
+    IDB::emitSigModified();
     if(highlightedTrack())
     {
-        emit sigModified(highlightedTrack()->getKey());
+        IDB::emitSigModified(highlightedTrack()->getKey());
     }
 }
 
@@ -1292,6 +1318,7 @@ void CTrackDB::revertTrack(const QString& key)
 
 }
 
+
 QList<CTrackDB::keys_t> CTrackDB::keys()
 {
     QList<keys_t> k;
@@ -1317,7 +1344,6 @@ QList<CTrackDB::keys_t> CTrackDB::keys()
             k2.time     = track->track.first().timestamp;
         }
 
-
         icon.fill(track->getColor());
         k2.icon     = icon;
 
@@ -1339,6 +1365,7 @@ QList<CTrackDB::keys_t> CTrackDB::keys()
     return k;
 }
 
+
 CTrack * CTrackDB::getTrackByKey(const QString& key)
 {
     if(!tracks.contains(key)) return 0;
@@ -1347,6 +1374,7 @@ CTrack * CTrackDB::getTrackByKey(const QString& key)
 
 }
 
+
 void CTrackDB::makeVisible(const QStringList& keys)
 {
     QRectF r;
@@ -1390,6 +1418,8 @@ void CTrackDB::setPointOfFocusByDist(double distance)
     QList<CTrack::pt_t>& trkpts = track->getTrackPoints();
     QList<CTrack::pt_t>::iterator trkpt = trkpts.begin();
 
+    int idx  = -1;
+    double d = WPT_NOFLOAT;
     while(trkpt != trkpts.end())
     {
         if(trkpt->flags & CTrack::pt_t::eDeleted)
@@ -1397,15 +1427,17 @@ void CTrackDB::setPointOfFocusByDist(double distance)
             ++trkpt; continue;
         }
 
-        if(distance < trkpt->distance)
+        if(fabs(distance - trkpt->distance) < d)
         {
-            emit sigPointOfFocus(trkpt->idx);
-            return;
+            d   = fabs(distance - trkpt->distance);
+            idx = trkpt->idx;
         }
         ++trkpt;
     }
+    emit sigPointOfFocus(idx);
 }
 
+
 void CTrackDB::setPointOfFocusByTime(quint32 timestamp)
 {
     CTrack * track = highlightedTrack();
@@ -1417,6 +1449,8 @@ void CTrackDB::setPointOfFocusByTime(quint32 timestamp)
     QList<CTrack::pt_t>& trkpts = track->getTrackPoints();
     QList<CTrack::pt_t>::iterator trkpt = trkpts.begin();
 
+    int idx = -1;
+    int d   = 0x7FFFFFFF;
     while(trkpt != trkpts.end())
     {
         if(trkpt->flags & CTrack::pt_t::eDeleted)
@@ -1424,15 +1458,18 @@ void CTrackDB::setPointOfFocusByTime(quint32 timestamp)
             ++trkpt; continue;
         }
 
-        if(timestamp < trkpt->timestamp)
+        quint32 timestamp_diff = (timestamp > trkpt->timestamp)?(timestamp - trkpt->timestamp):(trkpt->timestamp - timestamp);
+        if(timestamp_diff < d)
         {
-            emit sigPointOfFocus(trkpt->idx);
-            return;
+            d   = timestamp_diff;
+            idx = trkpt->idx;
         }
         ++trkpt;
     }
+    emit sigPointOfFocus(idx);
 }
 
+
 void CTrackDB::setPointOfFocusByIdx(qint32 idx)
 {
     CTrack * track = highlightedTrack();
@@ -1447,3 +1484,89 @@ void CTrackDB::setPointOfFocusByIdx(qint32 idx)
         emit sigPointOfFocus(idx);
     }
 }
+
+
+bool CTrackDB::getClosestPoint2Position(double &lon, double &lat, quint32& timestamp, double maxDelta)
+{
+    double delta = WPT_NOFLOAT;
+    const CTrack::pt_t * selTrkPt = 0;
+    double d, a1, a2;
+    projUV p1, p2;
+
+    p1.u = lon*DEG_TO_RAD;
+    p1.v = lat*DEG_TO_RAD;
+
+    foreach(CTrack * track, tracks)
+    {
+        QList<CTrack::pt_t>& trkpts = track->getTrackPoints();
+
+        foreach(const CTrack::pt_t& trkpt, trkpts)
+        {
+            p2.u = trkpt.lon*DEG_TO_RAD;
+            p2.v = trkpt.lat*DEG_TO_RAD;
+            d = distance(p1, p2, a1, a2);
+
+            if(d < delta)
+            {
+                delta = d;
+                if(delta < maxDelta)
+                {
+                    selTrkPt = &trkpt;
+                }
+            }
+        }
+    }
+
+    if(selTrkPt)
+    {
+        lon         = selTrkPt->lon;
+        lat         = selTrkPt->lat;
+        timestamp   = selTrkPt->timestamp;
+        return true;
+    }
+
+    return false;
+}
+
+
+bool CTrackDB::getClosestPoint2Timestamp(quint32 timestamp, quint32 maxDelta, double& lon, double& lat)
+{
+    quint32 delta = std::numeric_limits<quint32>::max();
+    const CTrack::pt_t * selTrkPt = 0;
+
+    foreach(CTrack * track, tracks)
+    {
+        QList<CTrack::pt_t>& trkpts = track->getTrackPoints();
+
+        foreach(const CTrack::pt_t& trkpt, trkpts)
+        {
+            quint32 delta_trkpt = (timestamp > trkpt.timestamp)?(timestamp - trkpt.timestamp):(trkpt.timestamp - timestamp);
+            if(delta_trkpt < delta)
+            {
+                delta = delta_trkpt;
+                if(delta < maxDelta)
+                {
+                    selTrkPt = &trkpt;
+                }
+            }
+        }
+    }
+
+    if(selTrkPt)
+    {
+        lon = selTrkPt->lon;
+        lat = selTrkPt->lat;
+        return true;
+    }
+
+    return false;
+}
+
+
+void CTrackDB::slotMapChanged()
+{
+    foreach(CTrack * track, tracks)
+    {
+        track->rebuild(false);
+    }
+}
