@@ -41,6 +41,7 @@
 
 #include <QtGui>
 
+#include <tzdata.h>
 
 #ifdef Q_WS_MAC
 #include <CoreFoundation/CoreFoundation.h>
@@ -48,31 +49,32 @@
 template<class T>
 class CFType
 {
-public:
-    CFType(const T & t) : ref(t) { }
-    ~CFType() { CFRelease(ref); }
-    operator T() const { return ref; }
+    public:
+        CFType(const T & t) : ref(t) { }
+        ~CFType() { CFRelease(ref); }
+        operator T() const { return ref; }
 
-private:
-    T ref;
+    private:
+        T ref;
 };
 
 static QString CFStringToQString(const CFStringRef & str)
 {
     CFIndex length = CFStringGetLength(str);
     const UniChar * chars = CFStringGetCharactersPtr(str);
-    if (chars == 0) {
+    if (chars == 0)
+    {
         UniChar buffer[length];
         CFStringGetCharacters(str, CFRangeMake(0, length), buffer);
         return QString(reinterpret_cast<const QChar *>(buffer), length);
-    } else {
+    }
+    else
+    {
         return QString(reinterpret_cast<const QChar *>(chars), length);
     }
 }
-
 #endif
 
-
 bool CTrackTreeWidgetItem::operator< ( const QTreeWidgetItem & other ) const
 {
     const QString speed("/h");
@@ -252,6 +254,7 @@ void CTrackEditWidget::keyPressEvent(QKeyEvent * e)
     }
 }
 
+
 void CTrackEditWidget::resizeEvent(QResizeEvent * e)
 {
     QWidget::resizeEvent(e);
@@ -264,6 +267,7 @@ void CTrackEditWidget::resizeEvent(QResizeEvent * e)
     oldSize = e->size();
 }
 
+
 void CTrackEditWidget::slotContextMenu(const QPoint& pos)
 {
     int cnt = treePoints->selectedItems().count();
@@ -272,7 +276,6 @@ void CTrackEditWidget::slotContextMenu(const QPoint& pos)
 
         actSplit->setEnabled(cnt == 1);
 
-
         QPoint p = treePoints->mapToGlobal(pos);
         contextMenu->exec(p);
     }
@@ -280,6 +283,35 @@ void CTrackEditWidget::slotContextMenu(const QPoint& pos)
 }
 
 
+void CTrackEditWidget::slotResetAllZoom()
+{
+    if(!trackStatProfileDist.isNull())
+    {
+        trackStatProfileDist->getPlot()->resetZoom();
+    }
+    if(!trackStatSpeedDist.isNull())
+    {
+        trackStatSpeedDist->getPlot()->resetZoom();
+    }
+    if(!trackStatProfileTime.isNull())
+    {
+        trackStatProfileTime->getPlot()->resetZoom();
+    }
+    if(!trackStatSpeedTime.isNull())
+    {
+        trackStatSpeedTime->getPlot()->resetZoom();
+    }
+    if(!trackStatDistanceTime.isNull())
+    {
+        trackStatDistanceTime->getPlot()->resetZoom();
+    }
+    if(!trackStatTrainee.isNull())
+    {
+        trackStatTrainee->getPlot()->resetZoom();
+    }
+}
+
+
 void CTrackEditWidget::slotSplit()
 {
     QList<QTreeWidgetItem *> items = treePoints->selectedItems();
@@ -306,7 +338,6 @@ void CTrackEditWidget::slotSetTrack(CTrack * t)
         disconnect(track,SIGNAL(sigChanged()), this, SLOT(slotUpdate()));
         disconnect(track,SIGNAL(destroyed(QObject*)), this, SLOT(deleteLater()));
 
-
 #ifdef GPX_EXTENSIONS
         //delete all extension tabs and reset tab status
         int num_of_tabs  = trackStatExtensions.size();
@@ -323,7 +354,8 @@ void CTrackEditWidget::slotSetTrack(CTrack * t)
 
         //delete extensions columns in table
         //get names and number of extensions
-        QList<QString> names_of_ext = track->tr_ext.set.toList();                                 //Anzahl der Extensions
+                                 //Anzahl der Extensions
+        QList<QString> names_of_ext = track->tr_ext.set.toList();
         int num_of_ext              = names_of_ext.size();
         for(int i=0; i < num_of_ext; ++i)
         {
@@ -363,7 +395,8 @@ void CTrackEditWidget::slotSetTrack(CTrack * t)
 #ifdef GPX_EXTENSIONS
 
     //get names and number of extensions
-    QList<QString> names_of_ext = track->tr_ext.set.toList();                                 //Anzahl der Extensions
+                                 //Anzahl der Extensions
+    QList<QString> names_of_ext = track->tr_ext.set.toList();
     int num_of_ext              = names_of_ext.size();
 
     if (num_of_ext)
@@ -417,7 +450,7 @@ void CTrackEditWidget::slotSetTrack(CTrack * t)
             font.setStyleStrategy(QFont::PreferDefault);
             label->setFont(font);
             label->setAlignment(Qt::AlignCenter);
-             //keine extensions Elemente in dieser Datei
+            //keine extensions Elemente in dieser Datei
             label->setText(tr("no extensions elements in this file"));
             verticalLayout_Extensions->addWidget(label);
             no_ext_info_stat = 1;
@@ -484,25 +517,29 @@ void CTrackEditWidget::slotSetTrack(CTrack * t)
 }
 
 
-
 void CTrackEditWidget::slotUpdate()
 {
     int i;
 
     if (track->hasTraineeData())
+    {
         traineeGraph->setEnabled(true);
+    }
     else
     {
         traineeGraph->setEnabled(false);
         if (!trackStatTrainee.isNull())
+        {
             delete trackStatTrainee;
+        }
     }
 
 #ifdef GPX_EXTENSIONS
     //TODO: endable ext. sym. only when there are exts
 
     //get names and number of extensions
-    QList<QString> names_of_ext = track->tr_ext.set.toList();                                 //Anzahl der Extensions
+                                 //Anzahl der Extensions
+    QList<QString> names_of_ext = track->tr_ext.set.toList();
     int num_of_ext              = names_of_ext.size();
 
     if (num_of_ext == 0)
@@ -535,6 +572,12 @@ void CTrackEditWidget::slotUpdate()
     CFDateFormatterSetFormat(df, CFSTR("EEE MMM d HH:mm:ss yyyy"));
 #endif
 
+    treePoints->setUpdatesEnabled(false);
+    treePoints->blockSignals(true);
+    treePoints->model()->blockSignals(true);
+
+    QString timezone = track->getTimezone();
+
     while(trkpt != trkpts.end())
     {
         CTrackTreeWidgetItem * item;
@@ -568,7 +611,7 @@ void CTrackEditWidget::slotUpdate()
         {
             //item->setFlags((item->flags() & ~Qt::ItemIsEnabled) | Qt::ItemIsTristate);
 #ifdef GPX_EXTENSIONS
-            for(i = 0; i < eMaxColumn+num_of_ext; ++i)
+            for(i = 0; i < (eMaxColumn + num_of_ext); ++i)
 #else
             for(i = 0; i < eMaxColumn; ++i)
 #endif
@@ -580,7 +623,7 @@ void CTrackEditWidget::slotUpdate()
         {
             //item->setFlags(item->flags() | Qt::ItemIsEnabled | Qt::ItemIsTristate);
 #ifdef GPX_EXTENSIONS
-            for(i = 0; i < eMaxColumn+num_of_ext; ++i)
+            for(i = 0; i < (eMaxColumn + num_of_ext); ++i)
 #else
             for(i = 0; i < eMaxColumn; ++i)
 #endif
@@ -598,12 +641,16 @@ void CTrackEditWidget::slotUpdate()
         if(trkpt->flags & CTrack::pt_t::eSelected)
         {
             if ( !item->isSelected() )
+            {
                 item->setSelected(true);
+            }
         }
         else
         {
             if ( item->isSelected() )
+            {
                 item->setSelected(false);
+            }
         }
 
         // point number
@@ -611,9 +658,13 @@ void CTrackEditWidget::slotUpdate()
 
         // timestamp
         if(trkpt->timestamp != 0x00000000 && trkpt->timestamp != 0xFFFFFFFF)
-        {
+        {            
             QDateTime time = QDateTime::fromTime_t(trkpt->timestamp);
-            time.setTimeSpec(Qt::LocalTime);
+            if(!timezone.isEmpty())
+            {
+                time = TimeStamp(trkpt->timestamp).toZone(timezone).toDateTime();
+            }
+
 #ifdef Q_WS_MAC
             CFType<CFDateRef> cfdate(CFDateCreate(NULL, time.toTime_t() - kCFAbsoluteTimeIntervalSince1970));
             CFType<CFStringRef> cfstr(CFDateFormatterCreateStringWithDate(NULL, df, cfdate));
@@ -676,12 +727,10 @@ void CTrackEditWidget::slotUpdate()
         }
         item->setText(eSpeed,str);
 
-
         // position
         GPS_Math_Deg_To_Str(trkpt->lon, trkpt->lat, str);
         item->setText(ePosition,str);
 
-
 #ifdef GPX_EXTENSIONS
         //fill cells of tracklist with extensions
         for(int i=0; i < num_of_ext; ++i)
@@ -711,10 +760,13 @@ void CTrackEditWidget::slotUpdate()
         //--------------------------------------------------------------------------------------------------
 
         trkpt->flags.setChanged(false);
-
         ++trkpt;
     }
 
+    treePoints->model()->blockSignals(false);
+    treePoints->blockSignals(false);
+    treePoints->setUpdatesEnabled(true);
+
     // adjust column sizes to fit
     treePoints->header()->setResizeMode(0,QHeaderView::Interactive);
 
@@ -725,7 +777,6 @@ void CTrackEditWidget::slotUpdate()
         treePoints->scrollToItem(focus);
     }
     treePoints->setSelectionMode(QAbstractItemView::ExtendedSelection);
-    treePoints->setUpdatesEnabled(true);
 }
 
 
@@ -766,7 +817,7 @@ void CTrackEditWidget::slotPointSelection(QTreeWidgetItem * item)
     if(track.isNull()) return;
 
     originator = true;
-    track->setPointOfFocus(item->data(0,Qt::UserRole).toInt(), false, true);
+    track->setPointOfFocus(item->data(0,Qt::UserRole).toInt(), CTrack::eNoErase, true);
     originator = false;
 }
 
@@ -823,10 +874,10 @@ void CTrackEditWidget::slotShowProfile()
     theMainWindow->getCanvasTab()->setCurrentWidget(trackStatProfileDist);
 }
 
+
 void CTrackEditWidget::slotToggleStatDistance()
 {
 
-
     if(trackStatSpeedDist.isNull())
     {
         trackStatSpeedDist = new CTrackStatSpeedWidget(ITrackStat::eOverDistance, this);
@@ -924,7 +975,8 @@ void CTrackEditWidget::slotToggleExtensionsGraph()
 
             //add tab
             theMainWindow->getCanvasTab()->addTab(tab, name+"/t");
-            trackStatExtensions.insert(i, tab); //add Tab index to list for further handling
+                                 //add Tab index to list for further handling
+            trackStatExtensions.insert(i, tab);
         }
         connect(theMainWindow->getCanvasTab(),SIGNAL(tabCloseRequested(int)),this,SLOT(slotKillTab(int)));
         tabstat = 1;
@@ -945,7 +997,6 @@ void CTrackEditWidget::slotToggleExtensionsGraph()
         trackStatExtensions.clear();
     }
 
-
     //Tab Settings
     theMainWindow->getCanvasTab()->setTabPosition(QTabWidget::South);
     theMainWindow->getCanvasTab()->setMovable(true);
@@ -1044,7 +1095,6 @@ void CTrackEditWidget::slotSetColumnsExt(bool checked)
 }
 #endif
 
-
 //TODO: Show Track in Google Maps
 void CTrackEditWidget::slotGoogleMaps()
 {
@@ -1123,6 +1173,7 @@ void CTrackEditWidget::slotKillTab(int index)
     }
 }
 
+
 void CTrackEditWidget::slotColorChanged(int idx)
 {
     if(track.isNull()) return;
@@ -1136,6 +1187,7 @@ void CTrackEditWidget::slotColorChanged(int idx)
     }
 }
 
+
 void CTrackEditWidget::slotNameChanged(const QString& name)
 {
     if(track.isNull()) return;
@@ -1152,6 +1204,7 @@ void CTrackEditWidget::slotNameChanged(const QString& name)
     lineName->setPalette(palette);
 }
 
+
 void CTrackEditWidget::slotNameChanged()
 {
     if(track.isNull()) return;
@@ -1170,7 +1223,6 @@ void CTrackEditWidget::slotNameChanged()
         palette.setColor(QPalette::Base, QColor(128, 255, 128));
     }
 
-
     lineName->setPalette(palette);
 }
 
@@ -1179,16 +1231,15 @@ void CTrackEditWidget::slotReset()
 {
     if(track.isNull()) return;
     track->reset();
+    track->rebuild(true);
     track->slotScaleWpt2Track();
-    emit CTrackDB::self().sigModified();
-    emit CTrackDB::self().sigModified(track->getKey());
+    CTrackDB::self().emitSigModified();
 }
 
+
 void CTrackEditWidget::slotDelete()
 {
     if(track.isNull()) return;
-    originator = true;
-
     if(QMessageBox::warning(0,tr("Remove track points ...")
         ,tr("You are about to remove hidden track points permanently. If you press 'yes', all information will be lost.")
         ,QMessageBox::Yes|QMessageBox::No) == QMessageBox::No)
@@ -1196,22 +1247,16 @@ void CTrackEditWidget::slotDelete()
         return;
     }
 
-    QList<CTrack::pt_t>& trkpts           = track->getTrackPoints();
-    QList<CTrack::pt_t>::iterator trkpt   = trkpts.begin();
-    while(trkpt != trkpts.end())
-    {
+    QList<CTrack::pt_t>& trkpts = track->getTrackPoints();
+    QList<CTrack::pt_t>::iterator trkpt, end;
+    track->setupIterators(trkpt, end);
 
+    originator = true;
+    while(trkpt != end && trkpt != trkpts.end())
+    {
         if(trkpt->flags & CTrack::pt_t::eDeleted)
         {
-            if ( trkpt->editItem )
-            {
-                int idx = treePoints->indexOfTopLevelItem((CTrackTreeWidgetItem *)trkpt->editItem.data());
-                if ( idx != -1 )
-                {
-                    treePoints->takeTopLevelItem(idx);
-                }
-                delete (CTrackTreeWidgetItem *)trkpt->editItem.data();
-            }
+            delete trkpt->editItem;
             trkpt = trkpts.erase(trkpt);
         }
         else
@@ -1226,6 +1271,7 @@ void CTrackEditWidget::slotDelete()
     CTrackDB::self().emitSigModified();
 }
 
+
 void CTrackEditWidget::slotCurrentChanged(int idx)
 {
     if(idx == eStages)
@@ -1241,6 +1287,7 @@ void CTrackEditWidget::slotStagesChanged(int state)
     track->setDoScaleWpt2Track((Qt::CheckState)state);
 }
 
+
 void CTrackEditWidget::slotStagesChanged()
 {
     textStages->clear();
@@ -1262,12 +1309,13 @@ void CTrackEditWidget::slotStagesChanged()
 
 }
 
+
 void CTrackEditWidget::slotPointOfFocus(const int idx)
 {
     int cnt = 0;
 
     const QList<CTrack::wpt_t>& wpts = track->getStageWaypoints();
-    if(idx < 0 || wpts.isEmpty() || track.isNull())
+    if(idx < 0 || wpts.isEmpty() || track.isNull() || !CResources::self().showTrackProfileEleInfo())
     {
         textStages->slotHighlightArea("");
         if(trackStatProfileDist)
@@ -1282,7 +1330,7 @@ void CTrackEditWidget::slotPointOfFocus(const int idx)
 
     foreach(const CTrack::wpt_t& wpt, wpts)
     {
-//        qDebug() << idx << wpt.trkpt.idx;
+        //        qDebug() << idx << wpt.trkpt.idx;
 
         x2 = wpt.trkpt.distance;
 
@@ -1291,8 +1339,8 @@ void CTrackEditWidget::slotPointOfFocus(const int idx)
             textStages->slotHighlightArea(QString("stage%1").arg(cnt));
             if(trackStatProfileDist)
             {
-                double x = track->getTrackPoints()[idx].distance;
-                trackStatProfileDist->getPlot()->slotHighlightSection(x1,x);
+//                double x = track->getTrackPoints()[idx].distance;
+                trackStatProfileDist->getPlot()->slotHighlightSection(x1,x2);
             }
             return;
         }
@@ -1307,13 +1355,14 @@ void CTrackEditWidget::slotPointOfFocus(const int idx)
 
         if(trackStatProfileDist && track)
         {
-            double x = track->getTrackPoints()[idx].distance;
-            trackStatProfileDist->getPlot()->slotHighlightSection(x1,x);
+//            double x = track->getTrackPoints()[idx].distance;
+            trackStatProfileDist->getPlot()->slotHighlightSection(x1,track->getTrackPoints().last().distance);
         }
 
     }
 }
 
+
 void CTrackEditWidget::slotHighlightArea(const QString& key)
 {
     if(lastStageKey == key)
@@ -1337,11 +1386,11 @@ void CTrackEditWidget::slotHighlightArea(const QString& key)
     }
 }
 
+
 #define CHAR_PER_LINE 120
 #define ROOT_FRAME_MARGIN 5
 #define BASE_FONT_SIZE  9
 
-
 void CTrackEditWidget::updateStages()
 {
     textStages->clear();
@@ -1368,7 +1417,6 @@ void CTrackEditWidget::updateStages()
     f.setPointSize(pointSize);
     textStages->setFont(f);
 
-
     // copied from CDiaryEdit
     QTextCharFormat fmtCharStandard;
     fmtCharStandard.setFont(f);
@@ -1383,7 +1431,6 @@ void CTrackEditWidget::updateStages()
     fmtCharHeader.setFontWeight(QFont::Bold);
     fmtCharHeader.setForeground(Qt::white);
 
-
     QTextBlockFormat fmtBlockStandard;
     fmtBlockStandard.setTopMargin(10);
     fmtBlockStandard.setBottomMargin(10);
@@ -1420,11 +1467,11 @@ void CTrackEditWidget::updateStages()
 
     QVector<QTextLength> constraints;
     constraints << QTextLength(QTextLength::FixedLength, 32);
-//    constraints << QTextLength(QTextLength::VariableLength, 50);
-//    constraints << QTextLength(QTextLength::VariableLength, 30);
-//    constraints << QTextLength(QTextLength::VariableLength, 30);
-//    constraints << QTextLength(QTextLength::VariableLength, 30);
-//    constraints << QTextLength(QTextLength::VariableLength, 100);
+    //    constraints << QTextLength(QTextLength::VariableLength, 50);
+    //    constraints << QTextLength(QTextLength::VariableLength, 30);
+    //    constraints << QTextLength(QTextLength::VariableLength, 30);
+    //    constraints << QTextLength(QTextLength::VariableLength, 30);
+    //    constraints << QTextLength(QTextLength::VariableLength, 100);
     fmtTableStandard.setColumnWidthConstraints(constraints);
 
     doc->rootFrame()->setFrameFormat(fmtFrameRoot);
@@ -1439,7 +1486,6 @@ void CTrackEditWidget::updateStages()
         table->cellAt(1,i).setFormat(fmtCharHeader);
     }
 
-
     // header -------------------------
     table->mergeCells(0, eEleWpt, 1, 2);
     table->cellAt(0,eEleWpt).firstCursorPosition().setBlockFormat(fmtBlockCenter);
@@ -1480,7 +1526,6 @@ void CTrackEditWidget::updateStages()
     table->cellAt(1,eTotalDesc).firstCursorPosition().setBlockFormat(fmtBlockCenter);
     table->cellAt(1,eTotalDesc).firstCursorPosition().insertText(QChar(0x2198));
 
-
     // first entry -------------------------
     stage_t stage;
     QString val, unit;
@@ -1668,7 +1713,6 @@ void CTrackEditWidget::updateStages()
 
     // prepare data -------------------------------
 
-
     QString eleTrk;
     {
         QString valTrk, unitTrk;
