@@ -88,7 +88,7 @@ void CTrackStatProfileWidget::slotChanged()
 
     QPolygonF lineElev;
     QPolygonF marksElev;
-    QPointF   focusElev;
+    QList<QPointF> focusElev;
 
     float basefactor = IUnit::self().basefactor;
 
@@ -112,13 +112,12 @@ void CTrackStatProfileWidget::slotChanged()
         }
         else
         {
-//            lineElev.clear();
-//            lineDEM.clear();
-//            marksElev.clear();
-//            break;
+            //            lineElev.clear();
+            //            lineDEM.clear();
+            //            marksElev.clear();
+            //            break;
         }
 
-
         if(trkpt->flags & CTrack::pt_t::eSelected)
         {
             marksElev  << QPointF(type == eOverDistance ? trkpt->distance : (double)trkpt->timestamp, trkpt->ele * basefactor);
@@ -126,7 +125,7 @@ void CTrackStatProfileWidget::slotChanged()
 
         if(trkpt->flags & CTrack::pt_t::eFocus)
         {
-            focusElev  = QPointF(type == eOverDistance ? trkpt->distance : (double)trkpt->timestamp, trkpt->ele * basefactor);
+            focusElev  << QPointF(type == eOverDistance ? trkpt->distance : (double)trkpt->timestamp, trkpt->ele * basefactor);
         }
 
         ++trkpt;
