@@ -27,6 +27,8 @@
 #include <QtGui>
 #include <QtXml>
 
+#include <tzdata.h>
+
 #ifndef _MKSTR_1
 #define _MKSTR_1(x)    #x
 #define _MKSTR(x)      _MKSTR_1(x)
@@ -44,7 +46,7 @@ const QString CWpt::html =  ""
 "       <style type='text/css'>"
 "           p, li { white-space: pre-wrap; }"
 "           td {padding-top: 10px;}"
-"           th {background-color: lightBlue;}"
+"           th {background-color: darkBlue; color: white;}"
 "           h1 {color: #1E5E8F; font-size: 1.2em;}"
 "           h2 {color: #226AA0; font-size: 1em;}"
 "           body {color: #626262; font-size: 1em;}"
@@ -70,7 +72,6 @@ const QString CWpt::htmlFrame = ""
 "%1"
 "</div></div></div></div></div></div></div></div>";
 
-
 struct wpt_head_entry_t
 {
     wpt_head_entry_t() : type(CWpt::eEnd), offset(0) {}
@@ -138,6 +139,15 @@ QDataStream& operator >>(QDataStream& s, CWpt& wpt)
                 s1 >> wpt.parentWpt;
                 s1 >> wpt.selected;
 
+                if(!s1.atEnd())
+                {
+                    s1 >> wpt.dir;
+                }
+                else
+                {
+                    wpt.dir = WPT_NOFLOAT;
+                }
+
                 wpt.setIcon(icon);
                 wpt.setKey(key);
                 break;
@@ -258,6 +268,7 @@ QDataStream& operator <<(QDataStream& s, CWpt& wpt)
     s1 << wpt.type;
     s1 << wpt.getParentWpt();
     s1 << wpt.selected;
+    s1 << wpt.dir;
 
     entries << entryBase;
 
@@ -424,6 +435,7 @@ CWpt::CWpt(QObject * parent)
 , lon(1000)
 , ele(WPT_NOFLOAT)
 , prx(WPT_NOFLOAT)
+, dir(WPT_NOFLOAT)
 {
     setIcon("Small City");
 }
@@ -431,15 +443,17 @@ CWpt::CWpt(QObject * parent)
 
 CWpt::~CWpt()
 {
-//    qDebug() << "CWpt::~CWpt()";
+    //    qDebug() << "CWpt::~CWpt()";
 }
 
+
 void CWpt::setIcon(const QString& str)
 {
     iconString = str;
     iconPixmap = getWptIconByName(str);
 }
 
+
 QPixmap CWpt::getIcon() const
 {
     if(geocache.hasData)
@@ -461,6 +475,7 @@ QPixmap CWpt::getIcon() const
     return iconPixmap;
 }
 
+
 bool CWpt::hasHiddenInformation()
 {
     if(isGeoCache())
@@ -471,6 +486,7 @@ bool CWpt::hasHiddenInformation()
     return false;
 }
 
+
 QString CWpt::getInfo()
 {
     QString str = getName();
@@ -483,8 +499,13 @@ QString CWpt::getInfo()
     if(timestamp != 0x00000000 && timestamp != 0xFFFFFFFF)
     {
         if(str.count()) str += "\n";
+
+        QString timezone = GPS_Timezone(lon, lat);
         QDateTime time = QDateTime::fromTime_t(timestamp);
-        time.setTimeSpec(Qt::LocalTime);
+        if(!timezone.isEmpty())
+        {
+            time = TimeStamp(timestamp).toZone(timezone).toDateTime();
+        }
         str += time.toString();
     }
 
@@ -496,6 +517,12 @@ QString CWpt::getInfo()
         str += tr("elevation: %1 %2").arg(val).arg(unit);
     }
 
+    if(dir != WPT_NOFLOAT)
+    {
+        if(str.count()) str += "\n";
+        str += tr("direction: %1%2").arg(dir).arg(QChar('\260'));
+    }
+
     if(prx != WPT_NOFLOAT)
     {
         if(str.count()) str += "\n";
@@ -558,6 +585,7 @@ QString CWpt::getInfo()
     return str;
 }
 
+
 const QString CWpt::filename(const QDir& dir)
 {
     QDateTime ts;
@@ -571,6 +599,7 @@ const QString CWpt::filename(const QDir& dir)
     return dir.filePath(str);
 }
 
+
 QString CWpt::getEntry(const QString& tag, const QDomNode& parent)
 {
     if(parent.namedItem(tag).isElement())
@@ -581,6 +610,7 @@ QString CWpt::getEntry(const QString& tag, const QDomNode& parent)
     return "";
 }
 
+
 QString CWpt::getEntryHtml(const QString& tag, const QDomNode& parent)
 {
     const QDomNode node = parent.namedItem(tag);
@@ -600,6 +630,7 @@ QString CWpt::getEntryHtml(const QString& tag, const QDomNode& parent)
     return "";
 }
 
+
 void CWpt::loadGpxExt(const QDomNode& wpt)
 {
     geocache = geocache_t();
@@ -623,6 +654,7 @@ void CWpt::loadGpxExt(const QDomNode& wpt)
     }
 }
 
+
 void CWpt::loadGcExt(const QDomNode& gpxCache)
 {
     geocache.service = eGC;
@@ -683,6 +715,7 @@ void CWpt::loadGcExt(const QDomNode& gpxCache)
     geocache.hasData = true;
 }
 
+
 void CWpt::loadTwoNavExt(const QDomNode& gpxCache)
 {
     geocache.service = eGC;
@@ -717,7 +750,6 @@ void CWpt::loadTwoNavExt(const QDomNode& gpxCache)
     geocache.shortDesc  = getEntryHtml("groundspeak:short_description",gpxCache);
     geocache.longDesc   = getEntryHtml("groundspeak:long_description",gpxCache);
 
-
     const QDomNodeList& logs = gpxCache.toElement().elementsByTagName("groundspeak:log");
     uint N = logs.count();
 
@@ -764,7 +796,6 @@ void CWpt::loadOcExt(const QDomNode& gpxCache)
         geocache.archived  = true;
     }
 
-
     geocache.name       = getEntry("name",gpxCache);
     geocache.owner      = getEntry("owner",gpxCache);
     {
@@ -822,6 +853,7 @@ void CWpt::setEntry(const QString& tag, const QString& val, QDomDocument& gpx, Q
     }
 }
 
+
 void CWpt::setEntryHtml(const QString& tag, const QString& val, QDomDocument& gpx, QDomElement& parent)
 {
     if(!val.isEmpty())
@@ -834,6 +866,7 @@ void CWpt::setEntryHtml(const QString& tag, const QString& val, QDomDocument& gp
     }
 }
 
+
 QString CWpt::insertBuddies(const QString& html)
 {
     QString _html_ = html;
@@ -854,6 +887,7 @@ QString CWpt::insertBuddies(const QString& html)
     return _html_;
 }
 
+
 void CWpt::saveGpxExt(QDomNode& wpt, bool isExport)
 {
     if(!geocache.hasData)
@@ -861,7 +895,6 @@ void CWpt::saveGpxExt(QDomNode& wpt, bool isExport)
         return;
     }
 
-
     QDomDocument gpx = wpt.ownerDocument();
 
     if(geocache.service == eGC)
@@ -890,9 +923,9 @@ void CWpt::saveGpxExt(QDomNode& wpt, bool isExport)
         wpt.appendChild(extensions);
     }
 
-
 }
 
+
 void CWpt::saveGcExt(QDomElement& gpxCache, bool isExport)
 {
     QString str;
@@ -964,12 +997,12 @@ void CWpt::saveGcExt(QDomElement& gpxCache, bool isExport)
     }
 }
 
+
 void CWpt::saveTwoNavExt(QDomElement& gpxCache, bool isExport)
 {
     QString str;
     QDomDocument gpx  = gpxCache.ownerDocument();
 
-
     gpxCache.setAttribute("xmlns:groundspeak", "http://www.groundspeak.com/cache/1/0");
     gpxCache.setAttribute("id", geocache.id);
     gpxCache.setAttribute("archived", geocache.archived ? "True" : "False");
@@ -1118,7 +1151,6 @@ QString CWpt::getExtInfo(bool showHidden)
             info += "<p><b>Hint:</b> " + geocache.hint + "</p>";
         }
 
-
         info += geocache.longDesc;
 
         foreach(const geocachelog_t& log, geocache.logs)
@@ -1140,11 +1172,12 @@ QString CWpt::getExtInfo(bool showHidden)
     QString cpytext = html.arg(QUrl::fromLocalFile(dirWeb.path()).toString());
     cpytext = cpytext.replace("${info}", info);
     cpytext.replace("&deg;","\260");
-//    qDebug() << cpytext;
+    //    qDebug() << cpytext;
 
     return cpytext;
 }
 
+
 QString CWpt::htmlScale(float val)
 {
     return QString("<div class='scale1' style='width: %1px;'>&nbsp;</div><div class='scale0' style='width: %2px;'>&nbsp;</div>").arg(val*16).arg((5-val)*16);
@@ -1159,12 +1192,10 @@ void CWpt::showBuddies(bool show)
     {
         bool isKnown;
 
-
         int p           = 0;
         quint32 cnt     = 0;
         QString html    = getExtInfo(false);
 
-
         while ((p = rx.indexIn(html, p)) != -1)
         {
             buddy_t buddy;
@@ -1221,6 +1252,7 @@ void CWpt::showBuddies(bool show)
     }
 }
 
+
 bool CWpt::hasBuddies()
 {
     int p = 0;
