@@ -76,7 +76,6 @@ CWptToolWidget::CWptToolWidget(QTabWidget * parent)
 
     connect(listWpts,SIGNAL(customContextMenuRequested(const QPoint&)),this,SLOT(slotContextMenu(const QPoint&)));
 
-
     toolSortAlpha->setIcon(QPixmap(":/icons/iconDec16x16.png"));
     toolSortComment->setIcon(QPixmap(":/icons/iconText16x16.png"));
     toolSortIcon->setIcon(QPixmap(":/icons/iconWaypoint16x16.png"));
@@ -89,7 +88,6 @@ CWptToolWidget::CWptToolWidget(QTabWidget * parent)
     connect(toolSortPosition, SIGNAL(clicked()), SIGNAL(sigChanged()));
     connect(toolSortTime, SIGNAL(clicked()), SIGNAL(sigChanged()));
 
-
     connect(linePosition, SIGNAL(textChanged(const QString&)), this, SLOT(slotPosTextChanged(const QString&)));
 
     SETTINGS;
@@ -114,6 +112,7 @@ CWptToolWidget::~CWptToolWidget()
     cfg.setValue("waypoint/position", linePosition->text());
 }
 
+
 void CWptToolWidget::collectSelectedWaypoints(QList<CWpt*>& selWpts)
 {
     CWptDB::keys_t key;
@@ -130,6 +129,7 @@ void CWptToolWidget::collectSelectedWaypoints(QList<CWpt*>& selWpts)
     }
 }
 
+
 void CWptToolWidget::keyPressEvent(QKeyEvent * e)
 {
     if(e->key() == Qt::Key_Delete)
@@ -148,8 +148,6 @@ void CWptToolWidget::keyPressEvent(QKeyEvent * e)
 }
 
 
-
-
 void CWptToolWidget::slotDBChanged()
 {
     listWpts->clear();
@@ -239,6 +237,7 @@ void CWptToolWidget::slotItemDoubleClicked(QListWidgetItem* item)
     }
 }
 
+
 void CWptToolWidget::slotItemClicked(QListWidgetItem* item)
 {
     CWpt * wpt = CWptDB::self().getWptByKey(item->data(Qt::UserRole).toString());
@@ -312,6 +311,7 @@ void CWptToolWidget::slotDelete()
     CWptDB::self().delWpt(keys, false);
 }
 
+
 void CWptToolWidget::slotDeleteNonSel()
 {
     QStringList nonSelWpts;
@@ -331,6 +331,7 @@ void CWptToolWidget::slotDeleteNonSel()
     CWptDB::self().delWpt(nonSelWpts);
 }
 
+
 void CWptToolWidget::slotDeleteBy()
 {
     CDlgDelWpt dlg(this);
@@ -371,24 +372,27 @@ void CWptToolWidget::slotZoomToFit()
 void CWptToolWidget::selWptByKey(const QStringList& keys)
 {
 
+    qDebug() << keys;
+
     QListWidgetItem * item = 0;
     listWpts->setUpdatesEnabled(false);
     for(int i=0; i<listWpts->count(); ++i)
     {
-        item = listWpts->item(i);
-        if(!item)
+        QListWidgetItem * item1 = listWpts->item(i);
+        if(!item1)
         {
             continue;
         }
 
-        QString key = item->data(Qt::UserRole).toString();
+        QString key = item1->data(Qt::UserRole).toString();
 
         if(keys.contains(key))
         {
             CWpt * wpt = CWptDB::self().getWptByKey(key);
             if(wpt)
             {
-                item->setCheckState(wpt->selected ? Qt::Checked : Qt::Unchecked);
+                item1->setCheckState(wpt->selected ? Qt::Checked : Qt::Unchecked);
+                item = item1;
             }
 
         }
@@ -509,6 +513,7 @@ void CWptToolWidget::slotPosTextChanged(const QString& text)
     }
 }
 
+
 void CWptToolWidget::slotShowNames()
 {
     CWptDB::self().setShowNames(!CWptDB::self().getShowNames());
@@ -530,6 +535,7 @@ void CWptToolWidget::slotResetSel()
     theMainWindow->getCanvas()->update();
 }
 
+
 void CWptToolWidget::slotParentWpt()
 {
     QString parentWpt;
