@@ -18,9 +18,11 @@
 **********************************************************************************************/
 
 #include "GeoMath.h"
+#include "CResources.h"
 #include <stdlib.h>
 #include <QtGui>
 #include <limits>
+#include <tzdata.h>
 
 #include <math.h>
 
@@ -37,6 +39,393 @@ const double WGS84_a = 6378137.0;
 const double WGS84_b = 6356752.314245;
 const double WGS84_f = 1.0/298.257223563;
 
+const char * tblTimezone[] = {
+"Africa/Abidjan",
+"Africa/Accra",
+"Africa/Addis_Ababa",
+"Africa/Algiers",
+"Africa/Asmara",
+"Africa/Bamako",
+"Africa/Bangui",
+"Africa/Banjul",
+"Africa/Bissau",
+"Africa/Blantyre",
+"Africa/Brazzaville",
+"Africa/Bujumbura",
+"Africa/Cairo",
+"Africa/Casablanca",
+"Africa/Conakry",
+"Africa/Dakar",
+"Africa/Dar_es_Salaam",
+"Africa/Djibouti",
+"Africa/Douala",
+"Africa/El_Aaiun",
+"Africa/Freetown",
+"Africa/Gaborone",
+"Africa/Harare",
+"Africa/Johannesburg",
+"Africa/Kampala",
+"Africa/Khartoum",
+"Africa/Kigali",
+"Africa/Kinshasa",
+"Africa/Lagos",
+"Africa/Libreville",
+"Africa/Lome",
+"Africa/Luanda",
+"Africa/Lubumbashi",
+"Africa/Lusaka",
+"Africa/Malabo",
+"Africa/Maputo",
+"Africa/Maseru",
+"Africa/Mbabane",
+"Africa/Mogadishu",
+"Africa/Monrovia",
+"Africa/Nairobi",
+"Africa/Ndjamena",
+"Africa/Niamey",
+"Africa/Nouakchott",
+"Africa/Ouagadougou",
+"Africa/Porto-Novo",
+"Africa/Sao_Tome",
+"Africa/Tripoli",
+"Africa/Tunis",
+"Africa/Windhoek",
+"America/Adak",
+"America/Anguilla",
+"America/Antigua",
+"America/Araguaina",
+"America/Argentina/Buenos_Aires",
+"America/Argentina/Catamarca",
+"America/Argentina/Cordoba",
+"America/Argentina/Jujuy",
+"America/Argentina/La_Rioja",
+"America/Argentina/Mendoza",
+"America/Argentina/Rio_Gallegos",
+"America/Argentina/San_Juan",
+"America/Argentina/San_Luis",
+"America/Argentina/Tucuman",
+"America/Argentina/Ushuaia",
+"America/Aruba",
+"America/Asuncion",
+"America/Atikokan",
+"America/Bahia",
+"America/Barbados",
+"America/Belem",
+"America/Belize",
+"America/Blanc-Sablon",
+"America/Boa_Vista",
+"America/Bogota",
+"America/Boise",
+"America/Cambridge_Bay",
+"America/Campo_Grande",
+"America/Cancun",
+"America/Caracas",
+"America/Cayenne",
+"America/Cayman",
+"America/Chicago",
+"America/Chihuahua",
+"America/Coral_Harbour",
+"America/Costa_Rica",
+"America/Cuiaba",
+"America/Curacao",
+"America/Dawson",
+"America/Dawson_Creek",
+"America/Denver",
+"America/Dominica",
+"America/Edmonton",
+"America/Eirunepe",
+"America/El_Salvador",
+"America/Fortaleza",
+"America/Glace_Bay",
+"America/Goose_Bay",
+"America/Grand_Turk",
+"America/Grenada",
+"America/Guadeloupe",
+"America/Guatemala",
+"America/Guayaquil",
+"America/Guyana",
+"America/Halifax",
+"America/Havana",
+"America/Hermosillo",
+"America/Indiana/Indianapolis",
+"America/Indiana/Knox",
+"America/Indiana/Marengo",
+"America/Indiana/Petersburg",
+"America/Indiana/Vevay",
+"America/Indiana/Vincennes",
+"America/Indiana/Winamac",
+"America/Inuvik",
+"America/Iqaluit",
+"America/Jamaica",
+"America/Juneau",
+"America/Kentucky/Louisville",
+"America/Kentucky/Monticello",
+"America/La_Paz",
+"America/Lima",
+"America/Los_Angeles",
+"America/Maceio",
+"America/Managua",
+"America/Manaus",
+"America/Marigot",
+"America/Martinique",
+"America/Mazatlan",
+"America/Menominee",
+"America/Merida",
+"America/Mexico_City",
+"America/Miquelon",
+"America/Moncton",
+"America/Monterrey",
+"America/Montevideo",
+"America/Montreal",
+"America/Montserrat",
+"America/Nassau",
+"America/New_York",
+"America/Nipigon",
+"America/Noronha",
+"America/North_Dakota/Center",
+"America/North_Dakota/Salem",
+"America/Panama",
+"America/Pangnirtung",
+"America/Paramaribo",
+"America/Phoenix",
+"America/Port-au-Prince",
+"America/Port_of_Spain",
+"America/Porto_Velho",
+"America/Puerto_Rico",
+"America/Rainy_River",
+"America/Rankin_Inlet",
+"America/Recife",
+"America/Regina",
+"America/Resolute",
+"America/Rio_Branco",
+"America/Santarem",
+"America/Santiago",
+"America/Santo_Domingo",
+"America/Sao_Paulo",
+"America/St_Barthelemy",
+"America/St_Johns",
+"America/St_Kitts",
+"America/St_Lucia",
+"America/St_Thomas",
+"America/St_Vincent",
+"America/Tegucigalpa",
+"America/Thunder_Bay",
+"America/Tijuana",
+"America/Toronto",
+"America/Tortola",
+"America/Vancouver",
+"America/Whitehorse",
+"America/Winnipeg",
+"America/Yellowknife",
+"Ameriica/Swift_Current",
+"Arctic/Longyearbyen",
+"Asia/Aden",
+"Asia/Almaty",
+"Asia/Amman",
+"Asia/Anadyr",
+"Asia/Aqtau",
+"Asia/Aqtobe",
+"Asia/Ashgabat",
+"Asia/Baghdad",
+"Asia/Bahrain",
+"Asia/Baku",
+"Asia/Bangkok",
+"Asia/Beirut",
+"Asia/Bishkek",
+"Asia/Brunei",
+"Asia/Choibalsan",
+"Asia/Chongqing",
+"Asia/Colombo",
+"Asia/Damascus",
+"Asia/Dhaka",
+"Asia/Dili",
+"Asia/Dubai",
+"Asia/Dushanbe",
+"Asia/Gaza",
+"Asia/Harbin",
+"Asia/Ho_Chi_Minh",
+"Asia/Hong_Kong",
+"Asia/Hovd",
+"Asia/Irkutsk",
+"Asia/Jakarta",
+"Asia/Jayapura",
+"Asia/Jerusalem",
+"Asia/Kabul",
+"Asia/Kamchatka",
+"Asia/Karachi",
+"Asia/Kashgar",
+"Asia/Katmandu",
+"Asia/Kolkata",
+"Asia/Krasnoyarsk",
+"Asia/Kuala_Lumpur",
+"Asia/Kuching",
+"Asia/Kuwait",
+"Asia/Macau",
+"Asia/Magadan",
+"Asia/Makassar",
+"Asia/Manila",
+"Asia/Muscat",
+"Asia/Nicosia",
+"Asia/Novosibirsk",
+"Asia/Omsk",
+"Asia/Oral",
+"Asia/Phnom_Penh",
+"Asia/Pontianak",
+"Asia/Pyongyang",
+"Asia/Qatar",
+"Asia/Qyzylorda",
+"Asia/Rangoon",
+"Asia/Riyadh",
+"Asia/Sakhalin",
+"Asia/Samarkand",
+"Asia/Seoul",
+"Asia/Shanghai",
+"Asia/Singapore",
+"Asia/Taipei",
+"Asia/Tashkent",
+"Asia/Tbilisi",
+"Asia/Tehran",
+"Asia/Thimphu",
+"Asia/Tokyo",
+"Asia/Ulaanbaatar",
+"Asia/Urumqi",
+"Asia/Vientiane",
+"Asia/Vladivostok",
+"Asia/Yakutsk",
+"Asia/Yekaterinburg",
+"Asia/Yerevan",
+"Atlantic/Azores",
+"Atlantic/Bermuda",
+"Atlantic/Canary",
+"Atlantic/Cape_Verde",
+"Atlantic/Faroe",
+"Atlantic/Madeira",
+"Atlantic/Reykjavik",
+"Atlantic/South_Georgia",
+"Atlantic/St_Helena",
+"Atlantic/Stanley",
+"Australia/Adelaide",
+"Australia/Brisbane",
+"Australia/Broken_Hill",
+"Australia/Currie",
+"Australia/Darwin",
+"Australia/Eucla",
+"Australia/Hobart",
+"Australia/Lindeman",
+"Australia/Lord_Howe",
+"Australia/Melbourne",
+"Australia/Perth",
+"Australia/Sydney",
+"Europe/Amsterdam",
+"Europe/Andorra",
+"Europe/Athens",
+"Europe/Belgrade",
+"Europe/Berlin",
+"Europe/Bratislava",
+"Europe/Brussels",
+"Europe/Bucharest",
+"Europe/Budapest",
+"Europe/Chisinau",
+"Europe/Copenhagen",
+"Europe/Dublin",
+"Europe/Gibraltar",
+"Europe/Guernsey",
+"Europe/Helsinki",
+"Europe/Isle_of_Man",
+"Europe/Istanbul",
+"Europe/Jersey",
+"Europe/Kaliningrad",
+"Europe/Kiev",
+"Europe/Lisbon",
+"Europe/Ljubljana",
+"Europe/London",
+"Europe/Luxembourg",
+"Europe/Madrid",
+"Europe/Malta",
+"Europe/Marienhamn",
+"Europe/Minsk",
+"Europe/Monaco",
+"Europe/Moscow",
+"Europe/Oslo",
+"Europe/Paris",
+"Europe/Podgorica",
+"Europe/Prague",
+"Europe/Riga",
+"Europe/Rome",
+"Europe/Samara",
+"Europe/San_Marino",
+"Europe/Sarajevo",
+"Europe/Simferopol",
+"Europe/Skopje",
+"Europe/Sofia",
+"Europe/Stockholm",
+"Europe/Tallinn",
+"Europe/Tirane",
+"Europe/Uzhgorod",
+"Europe/Vaduz",
+"Europe/Vatican",
+"Europe/Vienna",
+"Europe/Vilnius",
+"Europe/Volgograd",
+"Europe/Warsaw",
+"Europe/Zagreb",
+"Europe/Zaporozhye",
+"Europe/Zurich",
+"Indian/Antananarivo",
+"Indian/Chagos",
+"Indian/Christmas",
+"Indian/Cocos",
+"Indian/Comoro",
+"Indian/Kerguelen",
+"Indian/Mahe",
+"Indian/Maldives",
+"Indian/Mauritius",
+"Indian/Mayotte",
+"Indian/Reunion",
+"Pacific/Apia",
+"Pacific/Auckland",
+"Pacific/Chatham",
+"Pacific/Easter",
+"Pacific/Efate",
+"Pacific/Enderbury",
+"Pacific/Fakaofo",
+"Pacific/Fiji",
+"Pacific/Funafuti",
+"Pacific/Galapagos",
+"Pacific/Gambier",
+"Pacific/Guadalcanal",
+"Pacific/Guam",
+"Pacific/Honolulu",
+"Pacific/Johnston",
+"Pacific/Kiritimati",
+"Pacific/Kosrae",
+"Pacific/Kwajalein",
+"Pacific/Majuro",
+"Pacific/Marquesas",
+"Pacific/Midway",
+"Pacific/Nauru",
+"Pacific/Niue",
+"Pacific/Norfolk",
+"Pacific/Noumea",
+"Pacific/Pago_Pago",
+"Pacific/Palau",
+"Pacific/Pitcairn",
+"Pacific/Ponape",
+"Pacific/Port_Moresby",
+"Pacific/Rarotonga",
+"Pacific/Saipan",
+"Pacific/Tahiti",
+"Pacific/Tarawa",
+"Pacific/Tongatapu",
+"Pacific/Truk",
+"Pacific/Wake",
+"Pacific/Wallis",
+0
+};
+
+const int N_TIMEZONES = sizeof(tblTimezone)/sizeof(const char*);
+
+
 bool GPS_Math_Deg_To_DegMin(float v, int32_t *d, float *m)
 {
     bool sign = v < 0;
@@ -62,6 +451,7 @@ void GPS_Math_DegMin_To_Deg(bool sign, const int32_t d, const float m, float& de
     return;
 }
 
+
 void GPS_Math_DegMinSec_To_Deg(bool sign, const int32_t d, const int32_t m, const int32_t s, float& deg)
 {
 
@@ -74,22 +464,24 @@ void GPS_Math_DegMinSec_To_Deg(bool sign, const int32_t d, const int32_t m, cons
     return;
 }
 
+
 namespace GeoMath
 {
-QRegExp reCoord1("^\\s*([N|S]){1}\\W*([0-9]+)\\W*([0-9]+\\.[0-9]+)\\s+([E|W|O]){1}\\W*([0-9]+)\\W*([0-9]+\\.[0-9]+)\\s*$");
+    QRegExp reCoord1("^\\s*([N|S]){1}\\W*([0-9]+)\\W*([0-9]+\\.[0-9]+)\\s+([E|W|O]){1}\\W*([0-9]+)\\W*([0-9]+\\.[0-9]+)\\s*$");
 
-QRegExp reCoord2("^\\s*([N|S]){1}\\s*([0-9]+\\.[0-9]+)\\W*\\s+([E|W|O]){1}\\s*([0-9]+\\.[0-9]+)\\W*\\s*$");
+    QRegExp reCoord2("^\\s*([N|S]){1}\\s*([0-9]+\\.[0-9]+)\\W*\\s+([E|W|O]){1}\\s*([0-9]+\\.[0-9]+)\\W*\\s*$");
 
-QRegExp reCoord3("^\\s*([-0-9]+\\.[0-9]+)\\s+([-0-9]+\\.[0-9]+)\\s*$");
+    QRegExp reCoord3("^\\s*([-0-9]+\\.[0-9]+)\\s+([-0-9]+\\.[0-9]+)\\s*$");
 
-QRegExp reCoord4("^\\s*([N|S]){1}\\s*([0-9]+)\\W+([0-9]+)\\W+([0-9]+)\\W*([E|W|O]){1}\\W*([0-9]+)\\W+([0-9]+)\\W+([0-9]+)\\W*\\s*$");
+    QRegExp reCoord4("^\\s*([N|S]){1}\\s*([0-9]+)\\W+([0-9]+)\\W+([0-9]+)\\W*([E|W|O]){1}\\W*([0-9]+)\\W+([0-9]+)\\W+([0-9]+)\\W*\\s*$");
 
-QRegExp reCoord5("^\\s*([-0-9]+\\.[0-9]+)([N|S])\\s+([-0-9]+\\.[0-9]+)([W|E])\\s*$");
+    QRegExp reCoord5("^\\s*([-0-9]+\\.[0-9]+)([N|S])\\s+([-0-9]+\\.[0-9]+)([W|E])\\s*$");
 }
 
+
 using namespace GeoMath;
 
-//49.03196968ºN 12.10440376ºE
+//49.03196968N 12.10440376E
 
 bool GPS_Math_Str_To_Deg(const QString& str, float& lon, float& lat, bool silent)
 {
@@ -140,7 +532,6 @@ bool GPS_Math_Str_To_Deg(const QString& str, float& lon, float& lat, bool silent
 
         GPS_Math_DegMinSec_To_Deg(signLon, degLon, minLon, secLon, lon);
 
-
     }
     else if(reCoord5.exactMatch(str))
     {
@@ -209,7 +600,7 @@ bool testPointInPolygon(const projXY& pt, const QVector<projXY>& poly1)
     bool    c = false;
     int     npol;
     int     i = 0, j = 0;
-    projXY      p1, p2;              // the two points of the polyline close to pt
+    projXY      p1, p2;          // the two points of the polyline close to pt
     float  x = pt.u;
     float  y = pt.v;
 
@@ -437,8 +828,6 @@ bool GPS_Math_Str_To_LongLat(const QString& str, float& lon, float& lat, const Q
     lon = u;
     lat = v;
 
-
-
     if(pjSrc) pj_free(pjSrc);
     if(pjTar) pj_free(pjTar);
     return true;
@@ -462,7 +851,7 @@ projXY GPS_Math_Wpt_Projection(const projXY& pt1, double distance, double bearin
 }
 
 
-extern void GPS_Math_SubPolyline( const QPoint& pt1, const QPoint& pt2, int threshold, const QPolygon& line1, QPolygon& line2)
+void GPS_Math_SubPolyline( const QPoint& pt1, const QPoint& pt2, int threshold, const QPolygon& line1, QPolygon& line2)
 {
     int i, len;
     projXY p1, p2;
@@ -470,7 +859,7 @@ extern void GPS_Math_SubPolyline( const QPoint& pt1, const QPoint& pt2, int thre
     double d_p1_p2;              // distance between p1 and p2
     double u;                    // ratio u the tangent point will divide d_p1_p2
     double x,y;                  // coord. (x,y) of the point on line defined by [p1,p2] close to pt
-    double distance;     // the distance to the polyline
+    double distance;             // the distance to the polyline
     double shortest1 = threshold;
     double shortest2 = threshold;
     int idx11 = -1, idx21 = -1, idx12 = -1;
@@ -494,7 +883,6 @@ extern void GPS_Math_SubPolyline( const QPoint& pt1, const QPoint& pt2, int thre
         dy = p2.v - p1.v;
         d_p1_p2 = sqrt(dx * dx + dy * dy);
 
-
         // find point on line closest to pt1
         u = ((pt1.x() - p1.u) * dx + (pt1.y() - p1.v) * dy) / (d_p1_p2 * d_p1_p2);
 
@@ -515,7 +903,6 @@ extern void GPS_Math_SubPolyline( const QPoint& pt1, const QPoint& pt2, int thre
             }
         }
 
-
         // find point on line closest to pt2
         u = ((pt2.x() - p1.u) * dx + (pt2.y() - p1.v) * dy) / (d_p1_p2 * d_p1_p2);
 
@@ -584,7 +971,7 @@ extern void GPS_Math_SubPolyline( const QPoint& pt1, const QPoint& pt2, int thre
         }
     }
 
-//    qDebug() << line1.size() << idx11 << idx12 << idx21 << pt1 << pt2 << pt11 << pt21;
+    //    qDebug() << line1.size() << idx11 << idx12 << idx21 << pt1 << pt2 << pt11 << pt21;
 
     // copy segment of line 1 to line2
     if(idx11 != -1 && idx21 != -1)
@@ -622,7 +1009,8 @@ extern void GPS_Math_SubPolyline( const QPoint& pt1, const QPoint& pt2, int thre
     }
 }
 
-extern bool GPS_Math_LineCrossesRect(const QPoint& p1, const QPoint& p2, const QRect& rect)
+
+bool GPS_Math_LineCrossesRect(const QPoint& p1, const QPoint& p2, const QRect& rect)
 {
 
     // the trival case
@@ -647,3 +1035,127 @@ extern bool GPS_Math_LineCrossesRect(const QPoint& p1, const QPoint& p2, const Q
 
     return true;
 }
+
+
+double GPS_Math_distPointLine3D(point3D& x1, point3D& x2, point3D& x0)
+{
+
+    point3D v1, v2, v3, v1x2;
+
+    double a1x2, a3;
+
+    // (x0 - x1)
+    v1.x    = x0.x - x1.x;
+    v1.y    = x0.y - x1.y;
+    v1.z    = x0.z - x1.z;
+
+    // (x0 - x2)
+    v2.x    = x0.x - x2.x;
+    v2.y    = x0.y - x2.y;
+    v2.z    = x0.z - x2.z;
+
+    // (x2 - x1)
+    v3.x    = x2.x - x1.x;
+    v3.y    = x2.y - x1.y;
+    v3.z    = x2.z - x1.z;
+
+    // (x0 - x1)x(x0 - x2)
+    v1x2.x  = v1.y * v2.z - v1.z * v2.y;
+    v1x2.y  = v1.z * v2.x - v1.x * v2.z;
+    v1x2.z  = v1.x * v2.y - v1.y * v2.x;
+
+    // |(x0 - x1)x(x0 - x2)|
+    a1x2    = sqrt(v1x2.x*v1x2.x + v1x2.y*v1x2.y + v1x2.z*v1x2.z);
+    // |(x2 - x1)|
+    a3      = sqrt(v3.x*v3.x + v3.y*v3.y + v3.z*v3.z);
+
+    return a1x2/a3;
+}
+
+
+struct segment
+{
+    segment(): idx1(0), idx2(0){}
+    segment(qint32 idx1, quint32 idx2) : idx1(idx1), idx2(idx2) {}
+    qint32 idx1;
+    qint32 idx2;
+};
+
+void GPS_Math_DouglasPeucker(QVector<pointDP> &line, double d)
+{
+    if(line.count() < 3) return;
+
+    QStack<segment> stack;
+    stack << segment(0, line.size() - 1);
+
+    while(!stack.isEmpty())
+    {
+        int idx = -1;
+        segment seg = stack.pop();
+
+        pointDP& x1 = line[seg.idx1];
+        pointDP& x2 = line[seg.idx2];
+
+        for(int i = seg.idx1 + 1; i < seg.idx2; i++)
+        {
+            double distance = GPS_Math_distPointLine3D(x1, x2, line[i]);
+            if(distance > d)
+            {
+                idx = i;
+                break;
+            }
+        }
+
+        if(idx > 0)
+        {
+            stack << segment(seg.idx1, idx);
+            stack << segment(idx, seg.idx2);
+        }
+        else
+        {
+            for(int i = seg.idx1 + 1; i < seg.idx2; i++)
+            {
+                line[i].used = false;
+            }
+        }
+    }
+}
+
+
+const char * GPS_Timezone(double lon, double lat)
+{
+    CResources::TimezoneMode_e mode = CResources::self().getTimezoneMode();
+
+    if(mode == CResources::eTZUtc)
+    {
+        return "UTC";
+    }
+    else if(mode == CResources::eTZLocal)
+    {
+        return TimeStamp::defaultZone().toAscii();
+    }
+    else if(mode == CResources::eTZSelected)
+    {
+        return CResources::self().getSelectedTimezone().toAscii();
+    }
+
+    static QImage imgTimezone = QPixmap(":/pics/timezones.png").toImage();
+
+    int x = qRound(2048.0 / 360.0 * (180.0 + lon));
+    int y = qRound(1024.0 / 180.0 * (90.0  - lat));
+
+    QRgb rgb = imgTimezone.pixel(x,y);
+
+    if(qRed(rgb) == 0 && qGreen(rgb) == 0)
+    {
+        return "UTC";
+    }
+
+    int tz   = ((qRed(rgb) & 248) << 1) + ((qGreen(rgb) >> 4) & 15);
+    if(tz >= N_TIMEZONES)
+    {
+        return 0;
+    }
+
+    return tblTimezone[tz];
+}
