@@ -113,9 +113,39 @@ extern double parallel_distance(const projXY& p1, const projXY& p2);
 */
 extern projXY GPS_Math_Wpt_Projection(const projXY& pt1, double distance, double bearing);
 
-
 extern void GPS_Math_SubPolyline(const QPoint& p1, const QPoint& p2, int threshold, const QPolygon& line1, QPolygon& line2);
 
 extern bool GPS_Math_LineCrossesRect(const QPoint& p1, const QPoint& p2, const QRect& rect);
 
+struct point3D
+{
+    double x;
+    double y;
+    double z;
+};
+
+/// calculate the distance of a point to a line
+/**
+    The line is defined by the points x1 and x2. The point is x0
+
+    @param x1 first point on the line
+    @param x2 second point on the line
+    @param x0 the point itself
+
+    @return the distance between point and line.
+*/
+extern double GPS_Math_distPointLine3D(point3D& x1, point3D& x2, point3D& x0);
+
+struct pointDP : public point3D
+{
+    pointDP():used(true){}
+    bool used;
+};
+
+extern void GPS_Math_DouglasPeucker(QVector<pointDP>& line, double d);
+
+extern const char * GPS_Timezone(double lon, double lat);
+
+extern const char * tblTimezone[];
+
 #endif                           //GEOMATH_H
