@@ -30,6 +30,7 @@ IItem::IItem(QObject * parent)
 
 }
 
+
 IItem::~IItem()
 {
 
@@ -46,6 +47,7 @@ QString IItem::getKey()
     return key;
 }
 
+
 void IItem::genKey()
 {
     key = QString("%1%2%3").arg(timestamp).arg(name).arg(keycnt++);
@@ -54,7 +56,7 @@ void IItem::genKey()
 
 void IItem::removeHtml(QString &str)
 {
-    str.remove(QRegExp("<head.*[^>]*><\\/head>"));
-    str.remove(QRegExp("<[^>]*>"));
-    str = str.simplified();
+    QTextDocument html;
+    html.setHtml(str);
+    str = html.toPlainText();
 }
