@@ -35,6 +35,7 @@
 #include "CSearch.h"
 #include "CSearchDB.h"
 #include "IMapSelection.h"
+#include "CImageViewer.h"
 #include <QtGui>
 
 QPointer<IOverlay> IMouse::selOverlay;
@@ -84,8 +85,8 @@ void IMouse::resizeRect(const QPoint& p, bool normalize)
     if (normalize)
     {
         QPoint p0(rect.topLeft());
-        rect.setCoords(std::min(p.x(), p0.x()), std::min(p.y(), p0.y()),
-                       std::max(p.x(), p0.x()), std::max(p.y(), p0.y()));
+        rect.setCoords(qMin(p.x(), p0.x()), qMin(p.y(), p0.y()),
+            qMax(p.x(), p0.x()), qMax(p.y(), p0.y()));
     }
     else
     {
@@ -132,6 +133,7 @@ void IMouse::drawPos1(QPainter& p)
     CCanvas::drawText(fi.fileName(), p, QRect(u,v, LENGTH, 20));
 }
 
+
 void IMouse::drawSelWpt(QPainter& p)
 {
     IMap& map = CMapDB::self().getMap();
@@ -143,7 +145,6 @@ void IMouse::drawSelWpt(QPainter& p)
 
         QPixmap icon = selWpt->getIcon().scaled(16,16, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
 
-
         p.setPen(CCanvas::penBorderBlue);
         p.setBrush(CCanvas::brushBackWhite);
         p.drawEllipse(u - 35, v - 35, 70, 70);
@@ -168,7 +169,7 @@ void IMouse::drawSelWpt(QPainter& p)
 
         p.drawPixmap(rectEditWpt, QPixmap(":/icons/iconEdit16x16.png"));
         p.drawPixmap(rectCopyWpt, QPixmap(":/icons/iconClipboard16x16.png"));
-        if(!selWpt->images.isEmpty() && !selWpt->images[0].filePath.isEmpty())
+        if(!selWpt->images.isEmpty() /*&& !selWpt->images[0].filePath.isEmpty()*/)
         {
             p.drawPixmap(rectViewWpt, QPixmap(":/icons/iconRaster16x16.png"));
         }
@@ -233,6 +234,27 @@ void IMouse::drawSelWpt(QPainter& p)
 
         p.restore();
 
+        if(selWpt->dir != WPT_NOFLOAT)
+        {
+#define ARROWDIR_H 15
+#define ARROWDIR_W 20
+
+            p.save();
+            p.setPen(CCanvas::penBorderBlue);
+            p.setBrush(CCanvas::brushBackWhite);
+
+            p.translate(u, v);
+            p.rotate(selWpt->dir);
+            p.translate(0,  - 37 - ARROWDIR_H/2);
+
+            QPolygon arrow;
+            arrow << QPoint(0, -ARROWDIR_H/2) << QPoint(-ARROWDIR_W/2, ARROWDIR_H/2) << QPoint(0, ARROWDIR_H/3) << QPoint(ARROWDIR_W/2, ARROWDIR_H/2);
+
+            p.drawPolygon(arrow);
+
+            p.restore();
+        }
+
     }
 }
 
@@ -274,7 +296,7 @@ void IMouse::drawSelTrkPt(QPainter& p)
             return;
         }
 
-        QString val, unit;
+        QString str;
         double u = selTrkPt->lon * DEG_TO_RAD;
         double v = selTrkPt->lat * DEG_TO_RAD;
         map.convertRad2Pt(u,v);
@@ -283,7 +305,7 @@ void IMouse::drawSelTrkPt(QPainter& p)
         p.setBrush(CCanvas::brushBackWhite);
         p.drawEllipse(QRect(u - 5,  v - 5, 11, 11));
 
-        QString str = track-> getTrkPtInfo(*selTrkPt);
+        str = track->getTrkPtInfo1(*selTrkPt);
         //-----------------------------------------------------------------------------------------------------------
         if (str != "")
         {
@@ -298,7 +320,6 @@ void IMouse::drawSelTrkPt(QPainter& p)
             r2.setHeight(r1.height() + 20);
             r2.moveTop(r1.top() - 10);
 
-
             p.setPen(QPen(CCanvas::penBorderBlue));
             p.setBrush(CCanvas::brushBackWhite);
             PAINT_ROUNDED_RECT(p,r2);
@@ -307,9 +328,36 @@ void IMouse::drawSelTrkPt(QPainter& p)
             p.setPen(Qt::darkBlue);
             p.drawText(r1, Qt::AlignLeft|Qt::AlignTop|Qt::TextWordWrap,str);
         }
+
+        str = track->getTrkPtInfo2(*selTrkPt);
+        //-----------------------------------------------------------------------------------------------------------
+        if (str != "")
+        {
+            QFont           f = CResources::self().getMapFont();
+            QFontMetrics    fm(f);
+            QRect           r1 = fm.boundingRect(QRect(0,0,300,0), Qt::AlignLeft|Qt::AlignTop, str);
+
+            QRect r = theMainWindow->getCanvas()->rect();
+            r1.moveTopLeft(QPoint((r.width() - r1.width())/2, 20));
+
+            QRect           r2 = r1;
+            r2.setWidth(r1.width() + 20);
+            r2.moveLeft(r1.left() - 10);
+            r2.setHeight(r1.height() + 10);
+            r2.moveTop(r1.top() - 5);
+
+            p.setPen(QPen(CCanvas::penBorderBlue));
+            p.setBrush(CCanvas::brushBackWhite);
+            PAINT_ROUNDED_RECT(p,r2);
+
+            p.setFont(CResources::self().getMapFont());
+            p.setPen(Qt::darkBlue);
+            p.drawText(r1, Qt::AlignLeft|Qt::AlignTop,str);
+        }
     }
 }
 
+
 void IMouse::drawSelRtePt(QPainter& p)
 {
     IMap& map = CMapDB::self().getMap();
@@ -335,7 +383,6 @@ void IMouse::drawSelRtePt(QPainter& p)
         r2.setHeight(r1.height() + 20);
         r2.moveTop(r1.top() - 10);
 
-
         p.setPen(QPen(CCanvas::penBorderBlue));
         p.setBrush(CCanvas::brushBackWhite);
         PAINT_ROUNDED_RECT(p,r2);
@@ -347,7 +394,6 @@ void IMouse::drawSelRtePt(QPainter& p)
 }
 
 
-
 void IMouse::mouseMoveEventWpt(QMouseEvent * e)
 {
     QPoint pos      = e->pos();
@@ -543,9 +589,10 @@ void IMouse::mousePressEventWpt(QMouseEvent * e)
         selWpt = 0;
         canvas->update();
     }
-    else if(rectViewWpt.contains(pt) && !selWpt->images.isEmpty() && !selWpt->images[0].filePath.isEmpty())
+    else if(rectViewWpt.contains(pt) && !selWpt->images.isEmpty() /*&& !selWpt->images[0].filePath.isEmpty()*/)
     {
-        QDesktopServices::openUrl(QUrl("file:///" + selWpt->images[0].filePath));
+        CImageViewer view(selWpt->images, 0, theMainWindow);
+        view.exec();
     }
     else if(rectMarkWpt.contains(pt))
     {
@@ -604,7 +651,6 @@ void IMouse::mousePressEventSearch(QMouseEvent * e)
 }
 
 
-
 void IMouse::mouseMoveEventTrack(QMouseEvent * e)
 {
     CTrack * track = CTrackDB::self().highlightedTrack();
@@ -648,6 +694,7 @@ void IMouse::mouseMoveEventTrack(QMouseEvent * e)
     }
 }
 
+
 void IMouse::mouseMoveEventRoute(QMouseEvent * e)
 {
     CRoute * route = CRouteDB::self().highlightedRoute();
@@ -733,6 +780,7 @@ void IMouse::mouseMoveEventOverlay(QMouseEvent * e)
     }
 }
 
+
 void IMouse::mouseMoveEventMapSel(QMouseEvent * e)
 {
 
@@ -755,7 +803,6 @@ void IMouse::mouseMoveEventMapSel(QMouseEvent * e)
         theMainWindow->getCanvas()->setMouseMode(CCanvas::eMouseMoveArea);
     }
 
-
     if(selMap != oldSel)
     {
         canvas->update();
@@ -763,6 +810,7 @@ void IMouse::mouseMoveEventMapSel(QMouseEvent * e)
 
 }
 
+
 void IMouse::slotSetPos1()
 {
     IMap& map = CMapDB::self().getMap();
